# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/model.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13gateway/model.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe3\x05\n\x05Model\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x64\x65scription\x18\x14 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12+\n\x05state\x18\x06 \x01(\x0e\x32\x14.gateway.Model.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x07 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12)\n\x04kind\x18\x04 \x01(\x0e\x32\x13.gateway.Model.KindB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1d\n\rdeployment_id\x18\x0f \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x17\n\ngithub_url\x18\x15 \x01(\tB\x03\xe0\x41\x01\x12\x1d\n\x10hugging_face_url\x18\x16 \x01(\tB\x03\xe0\x41\x01\x12=\n\x12\x62\x61se_model_details\x18\x17 \x01(\x0b\x32\x19.gateway.BaseModelDetailsB\x06\xe0\x41\x01\xe0\x41\x05\x12\x32\n\x0cpeft_details\x18\x10 \x01(\x0b\x32\x14.gateway.PEFTDetailsB\x06\xe0\x41\x01\xe0\x41\x05\x12\x32\n\x0cteft_details\x18\x11 \x01(\x0b\x32\x14.gateway.TEFTDetailsB\x06\xe0\x41\x01\xe0\x41\x05\x12\x13\n\x06public\x18\x13 \x01(\x08\x42\x03\xe0\x41\x01\"k\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\r\n\tUPLOADING\x10\x01\x12\x0e\n\nUNDEPLOYED\x10\x02\x12\x0f\n\x0bUNDEPLOYING\x10\x03\x12\r\n\tDEPLOYING\x10\x04\x12\x0c\n\x08\x44\x45PLOYED\x10\x05\"U\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x11\n\rHF_BASE_MODEL\x10\x01\x12\x11\n\rHF_PEFT_ADDON\x10\x02\x12\x11\n\rHF_TEFT_ADDON\x10\x03\"\xf4\x01\n\x10\x42\x61seModelDetails\x12\x1a\n\nworld_size\x18\x01 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12M\n\x11\x63heckpoint_format\x18\x02 \x01(\x0e\x32*.gateway.BaseModelDetails.CheckpointFormatB\x06\xe0\x41\x01\xe0\x41\x05\x12!\n\x11huggingface_files\x18\x03 \x03(\tB\x06\xe0\x41\x01\xe0\x41\x05\"R\n\x10\x43heckpointFormat\x12!\n\x1d\x43HECKPOINT_FORMAT_UNSPECIFIED\x10\x00\x12\n\n\x06NATIVE\x10\x01\x12\x0f\n\x0bHUGGINGFACE\x10\x02\"\\\n\x0bPEFTDetails\x12\x1a\n\nbase_model\x18\x01 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x11\n\x01r\x18\x02 \x01(\x05\x42\x06\xe0\x41\x02\xe0\x41\x05\x12\x1e\n\x0etarget_modules\x18\x03 \x03(\tB\x06\xe0\x41\x02\xe0\x41\x05\"$\n\x0bTEFTDetails\x12\x15\n\x08has_teft\x18\x01 \x01(\x08\x42\x03\xe0\x41\x02\"d\n\x12\x43reateModelRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\"\n\x05model\x18\x02 \x01(\x0b\x32\x0e.gateway.ModelB\x03\xe0\x41\x02\x12\x15\n\x08model_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"$\n\x0fGetModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"C\n\x12\x44\x65ployModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x1a\n\rdeployment_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\")\n\x14UndeployModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\xc4\x01\n\x1dGetModelUploadEndpointRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12Y\n\x10\x66ilename_to_size\x18\x02 \x03(\x0b\x32:.gateway.GetModelUploadEndpointRequest.FilenameToSizeEntryB\x03\xe0\x41\x02\x1a\x35\n\x13\x46ilenameToSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xc1\x01\n\x1eGetModelUploadEndpointResponse\x12\x62\n\x17\x66ilename_to_signed_urls\x18\x05 \x03(\x0b\x32\x41.gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x1aValidateModelUploadRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x85\x01\n\x11ListModelsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"a\n\x12ListModelsResponse\x12\x1e\n\x06models\x18\x01 \x03(\x0b\x32\x0e.gateway.Model\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"8\n\x12UpdateModelRequest\x12\"\n\x05model\x18\x01 \x01(\x0b\x32\x0e.gateway.ModelB\x03\xe0\x41\x02\"\'\n\x12\x44\x65leteModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[gateway_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_MODEL_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='gateway.Model.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPLOADING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNDEPLOYED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNDEPLOYING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEPLOYING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEPLOYED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=666,
  serialized_end=773,
)
_sym_db.RegisterEnumDescriptor(_MODEL_STATE)

_MODEL_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='gateway.Model.Kind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KIND_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HF_BASE_MODEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HF_PEFT_ADDON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HF_TEFT_ADDON', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=775,
  serialized_end=860,
)
_sym_db.RegisterEnumDescriptor(_MODEL_KIND)

_BASEMODELDETAILS_CHECKPOINTFORMAT = _descriptor.EnumDescriptor(
  name='CheckpointFormat',
  full_name='gateway.BaseModelDetails.CheckpointFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHECKPOINT_FORMAT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NATIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUGGINGFACE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1025,
  serialized_end=1107,
)
_sym_db.RegisterEnumDescriptor(_BASEMODELDETAILS_CHECKPOINTFORMAT)


_MODEL = _descriptor.Descriptor(
  name='Model',
  full_name='gateway.Model',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.Model.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.Model.display_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='gateway.Model.description', index=2,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.Model.create_time', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='gateway.Model.state', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.Model.status', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='gateway.Model.kind', index=6,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deployment_id', full_name='gateway.Model.deployment_id', index=7,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='github_url', full_name='gateway.Model.github_url', index=8,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hugging_face_url', full_name='gateway.Model.hugging_face_url', index=9,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_model_details', full_name='gateway.Model.base_model_details', index=10,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peft_details', full_name='gateway.Model.peft_details', index=11,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teft_details', full_name='gateway.Model.teft_details', index=12,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public', full_name='gateway.Model.public', index=13,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MODEL_STATE,
    _MODEL_KIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=860,
)


_BASEMODELDETAILS = _descriptor.Descriptor(
  name='BaseModelDetails',
  full_name='gateway.BaseModelDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='world_size', full_name='gateway.BaseModelDetails.world_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoint_format', full_name='gateway.BaseModelDetails.checkpoint_format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='huggingface_files', full_name='gateway.BaseModelDetails.huggingface_files', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BASEMODELDETAILS_CHECKPOINTFORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=863,
  serialized_end=1107,
)


_PEFTDETAILS = _descriptor.Descriptor(
  name='PEFTDetails',
  full_name='gateway.PEFTDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_model', full_name='gateway.PEFTDetails.base_model', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='r', full_name='gateway.PEFTDetails.r', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_modules', full_name='gateway.PEFTDetails.target_modules', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1109,
  serialized_end=1201,
)


_TEFTDETAILS = _descriptor.Descriptor(
  name='TEFTDetails',
  full_name='gateway.TEFTDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_teft', full_name='gateway.TEFTDetails.has_teft', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1203,
  serialized_end=1239,
)


_CREATEMODELREQUEST = _descriptor.Descriptor(
  name='CreateModelRequest',
  full_name='gateway.CreateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateModelRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='gateway.CreateModelRequest.model', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='gateway.CreateModelRequest.model_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1241,
  serialized_end=1341,
)


_GETMODELREQUEST = _descriptor.Descriptor(
  name='GetModelRequest',
  full_name='gateway.GetModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetModelRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1379,
)


_DEPLOYMODELREQUEST = _descriptor.Descriptor(
  name='DeployModelRequest',
  full_name='gateway.DeployModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeployModelRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deployment_id', full_name='gateway.DeployModelRequest.deployment_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1381,
  serialized_end=1448,
)


_UNDEPLOYMODELREQUEST = _descriptor.Descriptor(
  name='UndeployModelRequest',
  full_name='gateway.UndeployModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.UndeployModelRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1450,
  serialized_end=1491,
)


_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY = _descriptor.Descriptor(
  name='FilenameToSizeEntry',
  full_name='gateway.GetModelUploadEndpointRequest.FilenameToSizeEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.GetModelUploadEndpointRequest.FilenameToSizeEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.GetModelUploadEndpointRequest.FilenameToSizeEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1637,
  serialized_end=1690,
)

_GETMODELUPLOADENDPOINTREQUEST = _descriptor.Descriptor(
  name='GetModelUploadEndpointRequest',
  full_name='gateway.GetModelUploadEndpointRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetModelUploadEndpointRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename_to_size', full_name='gateway.GetModelUploadEndpointRequest.filename_to_size', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1494,
  serialized_end=1690,
)


_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY = _descriptor.Descriptor(
  name='FilenameToSignedUrlsEntry',
  full_name='gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1827,
  serialized_end=1886,
)

_GETMODELUPLOADENDPOINTRESPONSE = _descriptor.Descriptor(
  name='GetModelUploadEndpointResponse',
  full_name='gateway.GetModelUploadEndpointResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename_to_signed_urls', full_name='gateway.GetModelUploadEndpointResponse.filename_to_signed_urls', index=0,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1693,
  serialized_end=1886,
)


_VALIDATEMODELUPLOADREQUEST = _descriptor.Descriptor(
  name='ValidateModelUploadRequest',
  full_name='gateway.ValidateModelUploadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.ValidateModelUploadRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1888,
  serialized_end=1935,
)


_LISTMODELSREQUEST = _descriptor.Descriptor(
  name='ListModelsRequest',
  full_name='gateway.ListModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListModelsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListModelsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListModelsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListModelsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListModelsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1938,
  serialized_end=2071,
)


_LISTMODELSRESPONSE = _descriptor.Descriptor(
  name='ListModelsResponse',
  full_name='gateway.ListModelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='models', full_name='gateway.ListModelsResponse.models', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListModelsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListModelsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2073,
  serialized_end=2170,
)


_UPDATEMODELREQUEST = _descriptor.Descriptor(
  name='UpdateModelRequest',
  full_name='gateway.UpdateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='gateway.UpdateModelRequest.model', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2172,
  serialized_end=2228,
)


_DELETEMODELREQUEST = _descriptor.Descriptor(
  name='DeleteModelRequest',
  full_name='gateway.DeleteModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteModelRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2230,
  serialized_end=2269,
)

_MODEL.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MODEL.fields_by_name['state'].enum_type = _MODEL_STATE
_MODEL.fields_by_name['status'].message_type = gateway_dot_status__pb2._STATUS
_MODEL.fields_by_name['kind'].enum_type = _MODEL_KIND
_MODEL.fields_by_name['base_model_details'].message_type = _BASEMODELDETAILS
_MODEL.fields_by_name['peft_details'].message_type = _PEFTDETAILS
_MODEL.fields_by_name['teft_details'].message_type = _TEFTDETAILS
_MODEL_STATE.containing_type = _MODEL
_MODEL_KIND.containing_type = _MODEL
_BASEMODELDETAILS.fields_by_name['checkpoint_format'].enum_type = _BASEMODELDETAILS_CHECKPOINTFORMAT
_BASEMODELDETAILS_CHECKPOINTFORMAT.containing_type = _BASEMODELDETAILS
_CREATEMODELREQUEST.fields_by_name['model'].message_type = _MODEL
_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY.containing_type = _GETMODELUPLOADENDPOINTREQUEST
_GETMODELUPLOADENDPOINTREQUEST.fields_by_name['filename_to_size'].message_type = _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY
_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY.containing_type = _GETMODELUPLOADENDPOINTRESPONSE
_GETMODELUPLOADENDPOINTRESPONSE.fields_by_name['filename_to_signed_urls'].message_type = _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY
_LISTMODELSRESPONSE.fields_by_name['models'].message_type = _MODEL
_UPDATEMODELREQUEST.fields_by_name['model'].message_type = _MODEL
DESCRIPTOR.message_types_by_name['Model'] = _MODEL
DESCRIPTOR.message_types_by_name['BaseModelDetails'] = _BASEMODELDETAILS
DESCRIPTOR.message_types_by_name['PEFTDetails'] = _PEFTDETAILS
DESCRIPTOR.message_types_by_name['TEFTDetails'] = _TEFTDETAILS
DESCRIPTOR.message_types_by_name['CreateModelRequest'] = _CREATEMODELREQUEST
DESCRIPTOR.message_types_by_name['GetModelRequest'] = _GETMODELREQUEST
DESCRIPTOR.message_types_by_name['DeployModelRequest'] = _DEPLOYMODELREQUEST
DESCRIPTOR.message_types_by_name['UndeployModelRequest'] = _UNDEPLOYMODELREQUEST
DESCRIPTOR.message_types_by_name['GetModelUploadEndpointRequest'] = _GETMODELUPLOADENDPOINTREQUEST
DESCRIPTOR.message_types_by_name['GetModelUploadEndpointResponse'] = _GETMODELUPLOADENDPOINTRESPONSE
DESCRIPTOR.message_types_by_name['ValidateModelUploadRequest'] = _VALIDATEMODELUPLOADREQUEST
DESCRIPTOR.message_types_by_name['ListModelsRequest'] = _LISTMODELSREQUEST
DESCRIPTOR.message_types_by_name['ListModelsResponse'] = _LISTMODELSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateModelRequest'] = _UPDATEMODELREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelRequest'] = _DELETEMODELREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Model = _reflection.GeneratedProtocolMessageType('Model', (_message.Message,), {
  'DESCRIPTOR' : _MODEL,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.Model)
  })
_sym_db.RegisterMessage(Model)

BaseModelDetails = _reflection.GeneratedProtocolMessageType('BaseModelDetails', (_message.Message,), {
  'DESCRIPTOR' : _BASEMODELDETAILS,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.BaseModelDetails)
  })
_sym_db.RegisterMessage(BaseModelDetails)

PEFTDetails = _reflection.GeneratedProtocolMessageType('PEFTDetails', (_message.Message,), {
  'DESCRIPTOR' : _PEFTDETAILS,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.PEFTDetails)
  })
_sym_db.RegisterMessage(PEFTDetails)

TEFTDetails = _reflection.GeneratedProtocolMessageType('TEFTDetails', (_message.Message,), {
  'DESCRIPTOR' : _TEFTDETAILS,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.TEFTDetails)
  })
_sym_db.RegisterMessage(TEFTDetails)

CreateModelRequest = _reflection.GeneratedProtocolMessageType('CreateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateModelRequest)
  })
_sym_db.RegisterMessage(CreateModelRequest)

GetModelRequest = _reflection.GeneratedProtocolMessageType('GetModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetModelRequest)
  })
_sym_db.RegisterMessage(GetModelRequest)

DeployModelRequest = _reflection.GeneratedProtocolMessageType('DeployModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeployModelRequest)
  })
_sym_db.RegisterMessage(DeployModelRequest)

UndeployModelRequest = _reflection.GeneratedProtocolMessageType('UndeployModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNDEPLOYMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UndeployModelRequest)
  })
_sym_db.RegisterMessage(UndeployModelRequest)

GetModelUploadEndpointRequest = _reflection.GeneratedProtocolMessageType('GetModelUploadEndpointRequest', (_message.Message,), {

  'FilenameToSizeEntry' : _reflection.GeneratedProtocolMessageType('FilenameToSizeEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY,
    '__module__' : 'gateway.model_pb2'
    # @@protoc_insertion_point(class_scope:gateway.GetModelUploadEndpointRequest.FilenameToSizeEntry)
    })
  ,
  'DESCRIPTOR' : _GETMODELUPLOADENDPOINTREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetModelUploadEndpointRequest)
  })
_sym_db.RegisterMessage(GetModelUploadEndpointRequest)
_sym_db.RegisterMessage(GetModelUploadEndpointRequest.FilenameToSizeEntry)

GetModelUploadEndpointResponse = _reflection.GeneratedProtocolMessageType('GetModelUploadEndpointResponse', (_message.Message,), {

  'FilenameToSignedUrlsEntry' : _reflection.GeneratedProtocolMessageType('FilenameToSignedUrlsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY,
    '__module__' : 'gateway.model_pb2'
    # @@protoc_insertion_point(class_scope:gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry)
    })
  ,
  'DESCRIPTOR' : _GETMODELUPLOADENDPOINTRESPONSE,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetModelUploadEndpointResponse)
  })
_sym_db.RegisterMessage(GetModelUploadEndpointResponse)
_sym_db.RegisterMessage(GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry)

ValidateModelUploadRequest = _reflection.GeneratedProtocolMessageType('ValidateModelUploadRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEMODELUPLOADREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ValidateModelUploadRequest)
  })
_sym_db.RegisterMessage(ValidateModelUploadRequest)

ListModelsRequest = _reflection.GeneratedProtocolMessageType('ListModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListModelsRequest)
  })
_sym_db.RegisterMessage(ListModelsRequest)

ListModelsResponse = _reflection.GeneratedProtocolMessageType('ListModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSRESPONSE,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListModelsResponse)
  })
_sym_db.RegisterMessage(ListModelsResponse)

UpdateModelRequest = _reflection.GeneratedProtocolMessageType('UpdateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UpdateModelRequest)
  })
_sym_db.RegisterMessage(UpdateModelRequest)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType('DeleteModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteModelRequest)
  })
_sym_db.RegisterMessage(DeleteModelRequest)


DESCRIPTOR._options = None
_MODEL.fields_by_name['name']._options = None
_MODEL.fields_by_name['display_name']._options = None
_MODEL.fields_by_name['description']._options = None
_MODEL.fields_by_name['create_time']._options = None
_MODEL.fields_by_name['state']._options = None
_MODEL.fields_by_name['status']._options = None
_MODEL.fields_by_name['kind']._options = None
_MODEL.fields_by_name['deployment_id']._options = None
_MODEL.fields_by_name['github_url']._options = None
_MODEL.fields_by_name['hugging_face_url']._options = None
_MODEL.fields_by_name['base_model_details']._options = None
_MODEL.fields_by_name['peft_details']._options = None
_MODEL.fields_by_name['teft_details']._options = None
_MODEL.fields_by_name['public']._options = None
_BASEMODELDETAILS.fields_by_name['world_size']._options = None
_BASEMODELDETAILS.fields_by_name['checkpoint_format']._options = None
_BASEMODELDETAILS.fields_by_name['huggingface_files']._options = None
_PEFTDETAILS.fields_by_name['base_model']._options = None
_PEFTDETAILS.fields_by_name['r']._options = None
_PEFTDETAILS.fields_by_name['target_modules']._options = None
_TEFTDETAILS.fields_by_name['has_teft']._options = None
_CREATEMODELREQUEST.fields_by_name['parent']._options = None
_CREATEMODELREQUEST.fields_by_name['model']._options = None
_CREATEMODELREQUEST.fields_by_name['model_id']._options = None
_GETMODELREQUEST.fields_by_name['name']._options = None
_DEPLOYMODELREQUEST.fields_by_name['name']._options = None
_DEPLOYMODELREQUEST.fields_by_name['deployment_id']._options = None
_UNDEPLOYMODELREQUEST.fields_by_name['name']._options = None
_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY._options = None
_GETMODELUPLOADENDPOINTREQUEST.fields_by_name['name']._options = None
_GETMODELUPLOADENDPOINTREQUEST.fields_by_name['filename_to_size']._options = None
_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY._options = None
_VALIDATEMODELUPLOADREQUEST.fields_by_name['name']._options = None
_LISTMODELSREQUEST.fields_by_name['parent']._options = None
_LISTMODELSREQUEST.fields_by_name['page_size']._options = None
_LISTMODELSREQUEST.fields_by_name['page_token']._options = None
_LISTMODELSREQUEST.fields_by_name['filter']._options = None
_LISTMODELSREQUEST.fields_by_name['order_by']._options = None
_UPDATEMODELREQUEST.fields_by_name['model']._options = None
_DELETEMODELREQUEST.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)
