# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/wandb.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/wandb.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13gateway/wandb.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\"\x95\x01\n\x0bWandbConfig\x12\x15\n\x07\x65nabled\x18\x01 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x15\n\x07\x61pi_key\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x15\n\x07project\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x65ntity\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x06run_id\x18\x05 \x01(\tB\x06\x18\x01\xe2\x41\x01\x01\x12\x13\n\x03url\x18\x06 \x01(\tB\x06\xe2\x41\x03\x03\x05\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.wandb_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_WANDBCONFIG'].fields_by_name['enabled']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['enabled']._serialized_options = b'\342A\001\001'
  _globals['_WANDBCONFIG'].fields_by_name['api_key']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['api_key']._serialized_options = b'\342A\001\001'
  _globals['_WANDBCONFIG'].fields_by_name['project']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['project']._serialized_options = b'\342A\001\001'
  _globals['_WANDBCONFIG'].fields_by_name['entity']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['entity']._serialized_options = b'\342A\001\001'
  _globals['_WANDBCONFIG'].fields_by_name['run_id']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['run_id']._serialized_options = b'\030\001\342A\001\001'
  _globals['_WANDBCONFIG'].fields_by_name['url']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['url']._serialized_options = b'\342A\003\003\005\001'
  _globals['_WANDBCONFIG']._serialized_start=66
  _globals['_WANDBCONFIG']._serialized_end=215
# @@protoc_insertion_point(module_scope)
