# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/deployment.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/deployment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gateway/deployment.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc9\x1a\n\nDeployment\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x0b\xe2\x41\x01\x01\xbaH\x04r\x02\x18?\x12!\n\x0b\x64\x65scription\x18\x08 \x01(\tB\x0c\xe2\x41\x01\x01\xbaH\x05r\x03\x18\xe7\x07\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0b\x65xpire_time\x18\x38 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\x35\n\npurge_time\x18\x36 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x36\n\x0b\x64\x65lete_time\x18= \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x1d \x01(\tB\x05\xe2\x41\x02\x03\x05\x12/\n\x05state\x18\x05 \x01(\x0e\x32\x19.gateway.Deployment.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12U\n\x0b\x61nnotations\x18@ \x03(\x0b\x32$.gateway.Deployment.AnnotationsEntryB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12+\n\x11min_replica_count\x18\r \x01(\x05\x42\x10\xe2\x41\x02\x01\x05\xbaH\x04\x1a\x02(\x00\xa8\xf1\x04\x01\x12.\n\x11max_replica_count\x18\x0e \x01(\x05\x42\x13\xe2\x41\x02\x01\x05\xbaH\x07\x1a\x05\x18\xe8\x07(\x00\xa8\xf1\x04\x01\x12 \n\rreplica_count\x18# \x01(\x05\x42\t\xe2\x41\x02\x03\x05\xa8\xf1\x04\x01\x12=\n\x12\x61utoscaling_policy\x18& \x01(\x0b\x32\x1a.gateway.AutoscalingPolicyB\x05\xe2\x41\x02\x01\x05\x12\x19\n\nbase_model\x18\x12 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12&\n\x11\x61\x63\x63\x65lerator_count\x18* \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12\x38\n\x10\x61\x63\x63\x65lerator_type\x18+ \x01(\x0e\x32\x18.gateway.AcceleratorTypeB\x04\xe2\x41\x01\x01\x12\x36\n\tprecision\x18. \x01(\x0e\x32\x1d.gateway.Deployment.PrecisionB\x04\xe2\x41\x01\x01\x12\x35\n\nworld_size\x18\x18 \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12:\n\x0fgenerator_count\x18\x1a \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12H\n\x1b\x64isaggregated_prefill_count\x18\x13 \x01(\x05\x42#\xe2\x41\x01\x01\xbaH\x06\x1a\x04\x18\x10(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12K\n disaggregated_prefill_world_size\x18\x19 \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12=\n\x0emax_batch_size\x18\x14 \x01(\x05\x42%\xe2\x41\x02\x01\x05\xbaH\x07\x1a\x05\x18\x80\x08(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x0f\n\x07\x63luster\x18\x34 \x01(\t\x12\x1f\n\renable_addons\x18\x31 \x01(\x08\x42\x08\xe2\x41\x01\x01\xa8\xf1\x04\x01\x12.\n\nlive_merge\x18; \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12&\n\x11\x64raft_token_count\x18\x1b \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12\x19\n\x0b\x64raft_model\x18\" \x01(\tB\x04\xe2\x41\x01\x01\x12&\n\x18ngram_speculation_length\x18\x32 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12>\n\x13max_peft_batch_size\x18\x1e \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12@\n\x13kv_cache_memory_pct\x18\x1f \x01(\x05\x42#\xe2\x41\x01\x01\xbaH\x06\x1a\x04\x18Z(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12<\n\x17\x65nable_session_affinity\x18  \x01(\x08\x42\x1b\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x11\x12\x0f\x45NTERPRISE_ONLY\x12:\n\x15\x64irect_route_api_keys\x18, \x03(\tB\x1b\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x11\x12\x0f\x45NTERPRISE_ONLY\x12-\n\timage_tag\x18! \x01(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12+\n\x16num_peft_device_cached\x18\x30 \x01(\x05\x42\x0b\xe2\x41\x01\x03\xbaH\x04\x1a\x02(\x00\x12P\n\x11\x64irect_route_type\x18\x35 \x01(\x0e\x32\x18.gateway.DirectRouteTypeB\x1b\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x11\x12\x0f\x45NTERPRISE_ONLY\x12\x39\n\x13\x64irect_route_handle\x18\x39 \x01(\tB\x1c\xe2\x41\x02\x01\x03\xfa\xd2\xe4\x93\x02\x11\x12\x0f\x45NTERPRISE_ONLY\x12#\n\x13\x64\x65ployment_template\x18\' \x01(\tB\x04\xe2\x41\x01\x01H\x00\x12,\n\tauto_tune\x18( \x01(\x0b\x32\x11.gateway.AutoTuneB\x04\xe2\x41\x01\x01H\x00\x12&\n\x06region\x18\x33 \x01(\x0e\x32\x0f.gateway.RegionB\x05\xe2\x41\x02\x01\x05\x12\x36\n\x12\x64isable_accounting\x18\x37 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12.\n\nextra_args\x18: \x03(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12=\n\x12max_context_length\x18\x43 \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12V\n\x0c\x65xtra_values\x18< \x03(\x0b\x32$.gateway.Deployment.ExtraValuesEntryB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x30\n\x06\x65ngine\x18\x42 \x01(\x0e\x32\x1a.gateway.Deployment.EngineB\x04\xe2\x41\x01\x01\x12\x35\n\x0bupdate_time\x18? \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x1a\n\x0c\x66or_training\x18\x41 \x01(\x08\x42\x04\xe2\x41\x01\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x45xtraValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"l\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\x12\x0b\n\x07\x44\x45LETED\x10\x06\"\xac\x01\n\tPrecision\x12\x19\n\x15PRECISION_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46P16\x10\x01\x12\x07\n\x03\x46P8\x10\x02\x12\n\n\x06\x46P8_MM\x10\x03\x12\n\n\x06\x46P8_AR\x10\x04\x12\x12\n\x0e\x46P8_MM_KV_ATTN\x10\x05\x12\n\n\x06\x46P8_KV\x10\x06\x12\r\n\tFP8_MM_V2\x10\x07\x12\n\n\x06\x46P8_V2\x10\x08\x12\x15\n\x11\x46P8_MM_KV_ATTN_V2\x10\t\x12\x07\n\x03NF4\x10\n\"F\n\x06\x45ngine\x12\x16\n\x12\x45NGINE_UNSPECIFIED\x10\x00\x12\x11\n\rFIREATTENTION\x10\x01\x12\x08\n\x04VLLM\x10\x02\x12\x07\n\x03NIM\x10\x03:\xef\x03\xea\x41g\n\x1b\x61pi.fireworks.ai/Deployment\x12/accounts/{AccountId}/deployments/{DeploymentId}*\x0b\x64\x65ployments2\ndeployment\xbaH\xf2\x02\x1a\xc9\x01\n:deployment.max_replica_count.larger_than_min_replica_count\x12:min_replica_count cannot be greater than max_replica_count\x1aOthis.max_replica_count == 0 || this.min_replica_count <= this.max_replica_count\x1a\xa3\x01\n>deployment.max_peft_batch_size.not_greater_than_max_batch_size\x12\x30max_peft_batch_size cannot exceed max_batch_size\x1a/this.max_peft_batch_size <= this.max_batch_size\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\x42\x0b\n\tpreconfig\"%\n\x08\x41utoTune\x12\x19\n\x0blong_prompt\x18\x01 \x01(\x08\x42\x04\xe2\x41\x01\x01\"\xfc\x03\n\x11\x41utoscalingPolicy\x12@\n\x0fscale_up_window\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xe2\x41\x01\x01\xbaH\x05\xaa\x01\x02\x32\x00\x12\x42\n\x11scale_down_window\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xe2\x41\x01\x01\xbaH\x05\xaa\x01\x02\x32\x00\x12\xe3\x01\n\x14scale_to_zero_window\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\xa9\x01\xe2\x41\x01\x01\xbaH\xa1\x01\xba\x01\x9d\x01\n8autoscaling_policy.scale_to_zero_window.duration.minimum\x12/scale_to_zero_window must be at least 5 minutes\x1a\x30this == duration(\'0s\') || this >= duration(\'5m\')\x12G\n\x0cload_targets\x18\x04 \x03(\x0b\x32+.gateway.AutoscalingPolicy.LoadTargetsEntryB\x04\xe2\x41\x01\x01\x1a\x32\n\x10LoadTargetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xca\x01\n\x17\x43reateDeploymentRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12-\n\ndeployment\x18\x02 \x01(\x0b\x32\x13.gateway.DeploymentB\x04\xe2\x41\x01\x02\x12!\n\x13\x64isable_auto_deploy\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12*\n\x1c\x64isable_speculative_decoding\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x1b\n\rdeployment_id\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01\"*\n\x14GetDeploymentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xc2\x01\n\x16ListDeploymentsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x0cshow_deleted\x18\x06 \x01(\x08\x12\x1b\n\rshow_internal\x18\x07 \x01(\x08\x42\x04\xe2\x41\x01\x01\"p\n\x17ListDeploymentsResponse\x12(\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32\x13.gateway.Deployment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x7f\n\x17UpdateDeploymentRequest\x12-\n\ndeployment\x18\x01 \x01(\x0b\x32\x13.gateway.DeploymentB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"^\n\x17\x44\x65leteDeploymentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x12\n\x04hard\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x1b\n\rignore_checks\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\"/\n\x19UndeleteDeploymentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"I\n\x16ScaleDeploymentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1b\n\rreplica_count\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\"E\n\x1bGetDeploymentMetricsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x12\n\ntime_range\x18\x02 \x01(\t\"\x93\x01\n\x1cGetDeploymentMetricsResponse\x12\x43\n\x07metrics\x18\x01 \x03(\x0b\x32\x32.gateway.GetDeploymentMetricsResponse.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"M\n!GetDeploymentPrerequisitesRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x12\n\x04name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\"\\\n\x17\x44\x65ploymentPrerequisites\x12\x41\n\x13\x61\x63\x63\x65lerator_configs\x18\x01 \x03(\x0b\x32$.gateway.DeploymentAcceleratorConfig\"\xc4\x01\n\x1b\x44\x65ploymentAcceleratorConfig\x12\x32\n\x10\x61\x63\x63\x65lerator_type\x18\x01 \x01(\x0e\x32\x18.gateway.AcceleratorType\x12\x30\n\tprecision\x18\x02 \x01(\x0e\x32\x1d.gateway.Deployment.Precision\x12\x1d\n\x15min_accelerator_count\x18\x03 \x01(\x05\x12 \n\x07regions\x18\x04 \x03(\x0e\x32\x0f.gateway.Region*\xf0\x02\n\x06Region\x12\x16\n\x12REGION_UNSPECIFIED\x10\x00\x12\r\n\tUS_IOWA_1\x10\x01\x12\x11\n\rUS_VIRGINIA_1\x10\x02\x12\x11\n\rUS_VIRGINIA_2\x10\x03\x12\x11\n\rUS_ILLINOIS_1\x10\x04\x12\x0e\n\nAP_TOKYO_1\x10\x05\x12\x13\n\x0b\x45U_LONDON_1\x10\x06\x1a\x02\x08\x01\x12\x10\n\x0cUS_ARIZONA_1\x10\x07\x12\x0e\n\nUS_TEXAS_1\x10\x08\x12\x11\n\rUS_ILLINOIS_2\x10\t\x12\x12\n\x0e\x45U_FRANKFURT_1\x10\n\x12\x0e\n\nUS_TEXAS_2\x10\x0b\x12\x12\n\nEU_PARIS_1\x10\x0c\x1a\x02\x08\x01\x12\x11\n\rEU_HELSINKI_1\x10\x0e\x12\x13\n\x0bUS_NEVADA_1\x10\x0f\x1a\x02\x08\x01\x12\x10\n\x0c\x45U_ICELAND_1\x10\x10\x12\x10\n\x0c\x45U_ICELAND_2\x10\x11\x12\x13\n\x0fUS_WASHINGTON_1\x10\x12\x12\x13\n\x0fUS_WASHINGTON_2\x10\x13*\xe3\x01\n\x0f\x41\x63\x63\x65leratorType\x12 \n\x1c\x41\x43\x43\x45LERATOR_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10NVIDIA_A100_80GB\x10\x01\x12\x14\n\x10NVIDIA_H100_80GB\x10\x02\x12\x14\n\x10\x41MD_MI300X_192GB\x10\x03\x12\x14\n\x10NVIDIA_A10G_24GB\x10\x04\x12\x14\n\x10NVIDIA_A100_40GB\x10\x05\x12\x12\n\x0eNVIDIA_L4_24GB\x10\x06\x12\x15\n\x11NVIDIA_H200_141GB\x10\x07\x12\x15\n\x11NVIDIA_B200_180GB\x10\x08*x\n\x0f\x44irectRouteType\x12!\n\x1d\x44IRECT_ROUTE_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08INTERNET\x10\x01\x12\x1f\n\x1bGCP_PRIVATE_SERVICE_CONNECT\x10\x02\x12\x13\n\x0f\x41WS_PRIVATELINK\x10\x03\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.deployment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_REGION'].values_by_name["EU_LONDON_1"]._loaded_options = None
  _globals['_REGION'].values_by_name["EU_LONDON_1"]._serialized_options = b'\010\001'
  _globals['_REGION'].values_by_name["EU_PARIS_1"]._loaded_options = None
  _globals['_REGION'].values_by_name["EU_PARIS_1"]._serialized_options = b'\010\001'
  _globals['_REGION'].values_by_name["US_NEVADA_1"]._loaded_options = None
  _globals['_REGION'].values_by_name["US_NEVADA_1"]._serialized_options = b'\010\001'
  _globals['_DEPLOYMENT_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_DEPLOYMENT_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_DEPLOYMENT_EXTRAVALUESENTRY']._loaded_options = None
  _globals['_DEPLOYMENT_EXTRAVALUESENTRY']._serialized_options = b'8\001'
  _globals['_DEPLOYMENT'].fields_by_name['name']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYMENT'].fields_by_name['display_name']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['display_name']._serialized_options = b'\342A\001\001\272H\004r\002\030?'
  _globals['_DEPLOYMENT'].fields_by_name['description']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['description']._serialized_options = b'\342A\001\001\272H\005r\003\030\347\007'
  _globals['_DEPLOYMENT'].fields_by_name['create_time']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYMENT'].fields_by_name['expire_time']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['expire_time']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENT'].fields_by_name['purge_time']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['purge_time']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYMENT'].fields_by_name['delete_time']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['delete_time']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYMENT'].fields_by_name['created_by']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYMENT'].fields_by_name['state']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYMENT'].fields_by_name['status']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYMENT'].fields_by_name['annotations']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['annotations']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['min_replica_count']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['min_replica_count']._serialized_options = b'\342A\002\001\005\272H\004\032\002(\000\250\361\004\001'
  _globals['_DEPLOYMENT'].fields_by_name['max_replica_count']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['max_replica_count']._serialized_options = b'\342A\002\001\005\272H\007\032\005\030\350\007(\000\250\361\004\001'
  _globals['_DEPLOYMENT'].fields_by_name['replica_count']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['replica_count']._serialized_options = b'\342A\002\003\005\250\361\004\001'
  _globals['_DEPLOYMENT'].fields_by_name['autoscaling_policy']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['autoscaling_policy']._serialized_options = b'\342A\002\001\005'
  _globals['_DEPLOYMENT'].fields_by_name['base_model']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['base_model']._serialized_options = b'\342A\002\002\005'
  _globals['_DEPLOYMENT'].fields_by_name['accelerator_count']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['accelerator_count']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_DEPLOYMENT'].fields_by_name['accelerator_type']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['accelerator_type']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENT'].fields_by_name['precision']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['precision']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENT'].fields_by_name['world_size']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['world_size']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['generator_count']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['generator_count']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['disaggregated_prefill_count']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['disaggregated_prefill_count']._serialized_options = b'\342A\001\001\272H\006\032\004\030\020(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['disaggregated_prefill_world_size']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['disaggregated_prefill_world_size']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['max_batch_size']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['max_batch_size']._serialized_options = b'\342A\002\001\005\272H\007\032\005\030\200\010(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['enable_addons']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['enable_addons']._serialized_options = b'\342A\001\001\250\361\004\001'
  _globals['_DEPLOYMENT'].fields_by_name['live_merge']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['live_merge']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['draft_token_count']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['draft_token_count']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_DEPLOYMENT'].fields_by_name['draft_model']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['draft_model']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENT'].fields_by_name['ngram_speculation_length']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['ngram_speculation_length']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENT'].fields_by_name['max_peft_batch_size']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['max_peft_batch_size']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['kv_cache_memory_pct']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['kv_cache_memory_pct']._serialized_options = b'\342A\001\001\272H\006\032\004\030Z(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['enable_session_affinity']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['enable_session_affinity']._serialized_options = b'\342A\001\001\372\322\344\223\002\021\022\017ENTERPRISE_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['direct_route_api_keys']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['direct_route_api_keys']._serialized_options = b'\342A\001\001\372\322\344\223\002\021\022\017ENTERPRISE_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['image_tag']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['image_tag']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['num_peft_device_cached']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['num_peft_device_cached']._serialized_options = b'\342A\001\003\272H\004\032\002(\000'
  _globals['_DEPLOYMENT'].fields_by_name['direct_route_type']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['direct_route_type']._serialized_options = b'\342A\001\001\372\322\344\223\002\021\022\017ENTERPRISE_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['direct_route_handle']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['direct_route_handle']._serialized_options = b'\342A\002\001\003\372\322\344\223\002\021\022\017ENTERPRISE_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['deployment_template']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['deployment_template']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENT'].fields_by_name['auto_tune']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['auto_tune']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENT'].fields_by_name['region']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['region']._serialized_options = b'\342A\002\001\005'
  _globals['_DEPLOYMENT'].fields_by_name['disable_accounting']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['disable_accounting']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['extra_args']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['extra_args']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['max_context_length']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['max_context_length']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['extra_values']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['extra_values']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DEPLOYMENT'].fields_by_name['engine']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['engine']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENT'].fields_by_name['update_time']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_DEPLOYMENT'].fields_by_name['for_training']._loaded_options = None
  _globals['_DEPLOYMENT'].fields_by_name['for_training']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENT']._loaded_options = None
  _globals['_DEPLOYMENT']._serialized_options = b'\352Ag\n\033api.fireworks.ai/Deployment\022/accounts/{AccountId}/deployments/{DeploymentId}*\013deployments2\ndeployment\272H\362\002\032\311\001\n:deployment.max_replica_count.larger_than_min_replica_count\022:min_replica_count cannot be greater than max_replica_count\032Othis.max_replica_count == 0 || this.min_replica_count <= this.max_replica_count\032\243\001\n>deployment.max_peft_batch_size.not_greater_than_max_batch_size\0220max_peft_batch_size cannot exceed max_batch_size\032/this.max_peft_batch_size <= this.max_batch_size\202\361\004\013\n\007Account\030\001'
  _globals['_AUTOTUNE'].fields_by_name['long_prompt']._loaded_options = None
  _globals['_AUTOTUNE'].fields_by_name['long_prompt']._serialized_options = b'\342A\001\001'
  _globals['_AUTOSCALINGPOLICY_LOADTARGETSENTRY']._loaded_options = None
  _globals['_AUTOSCALINGPOLICY_LOADTARGETSENTRY']._serialized_options = b'8\001'
  _globals['_AUTOSCALINGPOLICY'].fields_by_name['scale_up_window']._loaded_options = None
  _globals['_AUTOSCALINGPOLICY'].fields_by_name['scale_up_window']._serialized_options = b'\342A\001\001\272H\005\252\001\0022\000'
  _globals['_AUTOSCALINGPOLICY'].fields_by_name['scale_down_window']._loaded_options = None
  _globals['_AUTOSCALINGPOLICY'].fields_by_name['scale_down_window']._serialized_options = b'\342A\001\001\272H\005\252\001\0022\000'
  _globals['_AUTOSCALINGPOLICY'].fields_by_name['scale_to_zero_window']._loaded_options = None
  _globals['_AUTOSCALINGPOLICY'].fields_by_name['scale_to_zero_window']._serialized_options = b'\342A\001\001\272H\241\001\272\001\235\001\n8autoscaling_policy.scale_to_zero_window.duration.minimum\022/scale_to_zero_window must be at least 5 minutes\0320this == duration(\'0s\') || this >= duration(\'5m\')'
  _globals['_AUTOSCALINGPOLICY'].fields_by_name['load_targets']._loaded_options = None
  _globals['_AUTOSCALINGPOLICY'].fields_by_name['load_targets']._serialized_options = b'\342A\001\001'
  _globals['_CREATEDEPLOYMENTREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEDEPLOYMENTREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDEPLOYMENTREQUEST'].fields_by_name['deployment']._loaded_options = None
  _globals['_CREATEDEPLOYMENTREQUEST'].fields_by_name['deployment']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDEPLOYMENTREQUEST'].fields_by_name['disable_auto_deploy']._loaded_options = None
  _globals['_CREATEDEPLOYMENTREQUEST'].fields_by_name['disable_auto_deploy']._serialized_options = b'\342A\001\001'
  _globals['_CREATEDEPLOYMENTREQUEST'].fields_by_name['disable_speculative_decoding']._loaded_options = None
  _globals['_CREATEDEPLOYMENTREQUEST'].fields_by_name['disable_speculative_decoding']._serialized_options = b'\342A\001\001'
  _globals['_CREATEDEPLOYMENTREQUEST'].fields_by_name['deployment_id']._loaded_options = None
  _globals['_CREATEDEPLOYMENTREQUEST'].fields_by_name['deployment_id']._serialized_options = b'\342A\001\001'
  _globals['_GETDEPLOYMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDEPLOYMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['show_internal']._loaded_options = None
  _globals['_LISTDEPLOYMENTSREQUEST'].fields_by_name['show_internal']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEDEPLOYMENTREQUEST'].fields_by_name['deployment']._loaded_options = None
  _globals['_UPDATEDEPLOYMENTREQUEST'].fields_by_name['deployment']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEDEPLOYMENTREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEDEPLOYMENTREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEDEPLOYMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEDEPLOYMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DELETEDEPLOYMENTREQUEST'].fields_by_name['hard']._loaded_options = None
  _globals['_DELETEDEPLOYMENTREQUEST'].fields_by_name['hard']._serialized_options = b'\342A\001\001'
  _globals['_DELETEDEPLOYMENTREQUEST'].fields_by_name['ignore_checks']._loaded_options = None
  _globals['_DELETEDEPLOYMENTREQUEST'].fields_by_name['ignore_checks']._serialized_options = b'\342A\001\001'
  _globals['_UNDELETEDEPLOYMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UNDELETEDEPLOYMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_SCALEDEPLOYMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_SCALEDEPLOYMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_SCALEDEPLOYMENTREQUEST'].fields_by_name['replica_count']._loaded_options = None
  _globals['_SCALEDEPLOYMENTREQUEST'].fields_by_name['replica_count']._serialized_options = b'\342A\001\001'
  _globals['_GETDEPLOYMENTMETRICSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDEPLOYMENTMETRICSREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETDEPLOYMENTMETRICSRESPONSE_METRICSENTRY']._loaded_options = None
  _globals['_GETDEPLOYMENTMETRICSRESPONSE_METRICSENTRY']._serialized_options = b'8\001'
  _globals['_GETDEPLOYMENTPREREQUISITESREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_GETDEPLOYMENTPREREQUISITESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_GETDEPLOYMENTPREREQUISITESREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDEPLOYMENTPREREQUISITESREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_REGION']._serialized_start=5756
  _globals['_REGION']._serialized_end=6124
  _globals['_ACCELERATORTYPE']._serialized_start=6127
  _globals['_ACCELERATORTYPE']._serialized_end=6354
  _globals['_DIRECTROUTETYPE']._serialized_start=6356
  _globals['_DIRECTROUTETYPE']._serialized_end=6476
  _globals['_DEPLOYMENT']._serialized_start=300
  _globals['_DEPLOYMENT']._serialized_end=3701
  _globals['_DEPLOYMENT_ANNOTATIONSENTRY']._serialized_start=2731
  _globals['_DEPLOYMENT_ANNOTATIONSENTRY']._serialized_end=2781
  _globals['_DEPLOYMENT_EXTRAVALUESENTRY']._serialized_start=2783
  _globals['_DEPLOYMENT_EXTRAVALUESENTRY']._serialized_end=2833
  _globals['_DEPLOYMENT_STATE']._serialized_start=2835
  _globals['_DEPLOYMENT_STATE']._serialized_end=2943
  _globals['_DEPLOYMENT_PRECISION']._serialized_start=2946
  _globals['_DEPLOYMENT_PRECISION']._serialized_end=3118
  _globals['_DEPLOYMENT_ENGINE']._serialized_start=3120
  _globals['_DEPLOYMENT_ENGINE']._serialized_end=3190
  _globals['_AUTOTUNE']._serialized_start=3703
  _globals['_AUTOTUNE']._serialized_end=3740
  _globals['_AUTOSCALINGPOLICY']._serialized_start=3743
  _globals['_AUTOSCALINGPOLICY']._serialized_end=4251
  _globals['_AUTOSCALINGPOLICY_LOADTARGETSENTRY']._serialized_start=4201
  _globals['_AUTOSCALINGPOLICY_LOADTARGETSENTRY']._serialized_end=4251
  _globals['_CREATEDEPLOYMENTREQUEST']._serialized_start=4254
  _globals['_CREATEDEPLOYMENTREQUEST']._serialized_end=4456
  _globals['_GETDEPLOYMENTREQUEST']._serialized_start=4458
  _globals['_GETDEPLOYMENTREQUEST']._serialized_end=4500
  _globals['_LISTDEPLOYMENTSREQUEST']._serialized_start=4503
  _globals['_LISTDEPLOYMENTSREQUEST']._serialized_end=4697
  _globals['_LISTDEPLOYMENTSRESPONSE']._serialized_start=4699
  _globals['_LISTDEPLOYMENTSRESPONSE']._serialized_end=4811
  _globals['_UPDATEDEPLOYMENTREQUEST']._serialized_start=4813
  _globals['_UPDATEDEPLOYMENTREQUEST']._serialized_end=4940
  _globals['_DELETEDEPLOYMENTREQUEST']._serialized_start=4942
  _globals['_DELETEDEPLOYMENTREQUEST']._serialized_end=5036
  _globals['_UNDELETEDEPLOYMENTREQUEST']._serialized_start=5038
  _globals['_UNDELETEDEPLOYMENTREQUEST']._serialized_end=5085
  _globals['_SCALEDEPLOYMENTREQUEST']._serialized_start=5087
  _globals['_SCALEDEPLOYMENTREQUEST']._serialized_end=5160
  _globals['_GETDEPLOYMENTMETRICSREQUEST']._serialized_start=5162
  _globals['_GETDEPLOYMENTMETRICSREQUEST']._serialized_end=5231
  _globals['_GETDEPLOYMENTMETRICSRESPONSE']._serialized_start=5234
  _globals['_GETDEPLOYMENTMETRICSRESPONSE']._serialized_end=5381
  _globals['_GETDEPLOYMENTMETRICSRESPONSE_METRICSENTRY']._serialized_start=5335
  _globals['_GETDEPLOYMENTMETRICSRESPONSE_METRICSENTRY']._serialized_end=5381
  _globals['_GETDEPLOYMENTPREREQUISITESREQUEST']._serialized_start=5383
  _globals['_GETDEPLOYMENTPREREQUISITESREQUEST']._serialized_end=5460
  _globals['_DEPLOYMENTPREREQUISITES']._serialized_start=5462
  _globals['_DEPLOYMENTPREREQUISITES']._serialized_end=5554
  _globals['_DEPLOYMENTACCELERATORCONFIG']._serialized_start=5557
  _globals['_DEPLOYMENTACCELERATORCONFIG']._serialized_end=5753
# @@protoc_insertion_point(module_scope)
