# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/snapshot.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/snapshot.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gateway/snapshot.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf9\x03\n\x08Snapshot\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x36\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12-\n\x05state\x18\x03 \x01(\x0e\x32\x17.gateway.Snapshot.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x04 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x18\n\timage_ref\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04:\xa4\x01\xea\x41\x8f\x01\n\x19\x61pi.fireworks.ai/Snapshot\x12]accounts/{AccountId}/clusters/{ClusterId}/environments/{EnvironmentId}/snapshots/{SnapshotId}*\tsnapshots2\x08snapshot\x82\xf1\x04\r\n\x0b\x45nvironment\"X\n\x15\x43reateSnapshotRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12)\n\x08snapshot\x18\x02 \x01(\x0b\x32\x11.gateway.SnapshotB\x04\xe2\x41\x01\x02\"(\n\x12GetSnapshotRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x8d\x01\n\x14ListSnapshotsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"j\n\x15ListSnapshotsResponse\x12$\n\tsnapshots\x18\x01 \x03(\x0b\x32\x11.gateway.Snapshot\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"+\n\x15\x44\x65leteSnapshotRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.snapshot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_SNAPSHOT'].fields_by_name['name']._loaded_options = None
  _globals['_SNAPSHOT'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_SNAPSHOT'].fields_by_name['create_time']._loaded_options = None
  _globals['_SNAPSHOT'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_SNAPSHOT'].fields_by_name['state']._loaded_options = None
  _globals['_SNAPSHOT'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_SNAPSHOT'].fields_by_name['status']._loaded_options = None
  _globals['_SNAPSHOT'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_SNAPSHOT'].fields_by_name['image_ref']._loaded_options = None
  _globals['_SNAPSHOT'].fields_by_name['image_ref']._serialized_options = b'\342A\002\003\005'
  _globals['_SNAPSHOT'].fields_by_name['update_time']._loaded_options = None
  _globals['_SNAPSHOT'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_SNAPSHOT']._loaded_options = None
  _globals['_SNAPSHOT']._serialized_options = b'\352A\217\001\n\031api.fireworks.ai/Snapshot\022]accounts/{AccountId}/clusters/{ClusterId}/environments/{EnvironmentId}/snapshots/{SnapshotId}*\tsnapshots2\010snapshot\202\361\004\r\n\013Environment'
  _globals['_CREATESNAPSHOTREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATESNAPSHOTREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATESNAPSHOTREQUEST'].fields_by_name['snapshot']._loaded_options = None
  _globals['_CREATESNAPSHOTREQUEST'].fields_by_name['snapshot']._serialized_options = b'\342A\001\002'
  _globals['_GETSNAPSHOTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETSNAPSHOTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTSNAPSHOTSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTSNAPSHOTSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTSNAPSHOTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSNAPSHOTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTSNAPSHOTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSNAPSHOTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTSNAPSHOTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSNAPSHOTSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTSNAPSHOTSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTSNAPSHOTSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETESNAPSHOTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETESNAPSHOTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_SNAPSHOT']._serialized_start=174
  _globals['_SNAPSHOT']._serialized_end=679
  _globals['_SNAPSHOT_STATE']._serialized_start=431
  _globals['_SNAPSHOT_STATE']._serialized_end=512
  _globals['_CREATESNAPSHOTREQUEST']._serialized_start=681
  _globals['_CREATESNAPSHOTREQUEST']._serialized_end=769
  _globals['_GETSNAPSHOTREQUEST']._serialized_start=771
  _globals['_GETSNAPSHOTREQUEST']._serialized_end=811
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_start=814
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_end=955
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_start=957
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_end=1063
  _globals['_DELETESNAPSHOTREQUEST']._serialized_start=1065
  _globals['_DELETESNAPSHOTREQUEST']._serialized_end=1108
# @@protoc_insertion_point(module_scope)
