# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/evaluation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/evaluation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gateway/evaluation.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe3\x03\n\nEvaluation\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x36\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x03 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12%\n\x06status\x18\x04 \x01(\x0b\x32\x0f.gateway.StatusB\x04\xe2\x41\x01\x03\x12\x1d\n\x0f\x65valuation_type\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01\x12*\n\tproviders\x18\x08 \x03(\x0b\x32\x11.gateway.ProviderB\x04\xe2\x41\x01\x02\x12,\n\nassertions\x18\t \x03(\x0b\x32\x12.gateway.AssertionB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03:{\x18\x01\xea\x41g\n\x1b\x61pi.fireworks.ai/Evaluation\x12/accounts/{AccountId}/evaluations/{EvaluationId}*\x0b\x45valuations2\nEvaluation\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"\xa6\x02\n\tAssertion\x12>\n\x0e\x61ssertion_type\x18\x01 \x01(\x0e\x32 .gateway.Assertion.AssertionTypeB\x04\xe2\x41\x01\x02\x12,\n\rllm_assertion\x18\x02 \x01(\x0b\x32\x15.gateway.LLMAssertion\x12.\n\x0e\x63ode_assertion\x18\x03 \x01(\x0b\x32\x16.gateway.CodeAssertion\x12\x19\n\x0bmetric_name\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\"`\n\rAssertionType\x12\x1e\n\x1a\x41SSERTION_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x41SSERTION_TYPE_LLM\x10\x01\x12\x17\n\x13\x41SSERTION_TYPE_CODE\x10\x02\"\xaf\x01\n\x0cLLMAssertion\x12\"\n\x14llm_evaluator_prompt\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01\x12*\n\tproviders\x18\x02 \x03(\x0b\x32\x11.gateway.ProviderB\x04\xe2\x41\x01\x02\x12\x15\n\x07prompts\x18\x03 \x03(\tB\x04\xe2\x41\x01\x02\x12\x38\n\x10\x65valuate_options\x18\x04 \x01(\x0b\x32\x18.gateway.EvaluateOptionsB\x04\xe2\x41\x01\x01\"\xfb\x02\n\rCodeAssertion\x12\x16\n\x08language\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x12\n\x04\x63ode\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1d\n\x0f\x65xpected_output\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12>\n\x07options\x18\x04 \x01(\x0b\x32\'.gateway.CodeAssertion.ExecutionOptionsB\x04\xe2\x41\x01\x01\x1a\xde\x01\n\x10\x45xecutionOptions\x12#\n\ntimeout_ms\x18\x01 \x01(\x05\x42\x0f\xe2\x41\x01\x01\xbaH\x08\x1a\x06\x18\xe0\xa7\x12(\x00\x12\'\n\x0fmemory_limit_mb\x18\x02 \x01(\x05\x42\x0e\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\x80\x08(\x00\x12L\n\x08\x65nv_vars\x18\x03 \x03(\x0b\x32\x34.gateway.CodeAssertion.ExecutionOptions.EnvVarsEntryB\x04\xe2\x41\x01\x01\x1a.\n\x0c\x45nvVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x08Provider\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x03(\x0b\x32\x1d.gateway.Provider.ConfigEntry\x12\r\n\x05label\x18\x03 \x01(\t\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0f\x45valuateOptions\x12\x17\n\x0fmax_concurrency\x18\x01 \x01(\x05\x12\x0e\n\x06repeat\x18\x02 \x01(\x05\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\x05\"*\n\x14GetEvaluationRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"{\n\x17\x43reateEvaluationRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12-\n\nevaluation\x18\x02 \x01(\x0b\x32\x13.gateway.EvaluationB\x04\xe2\x41\x01\x02\x12\x1b\n\revaluation_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"\x8f\x01\n\x16ListEvaluationsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"p\n\x17ListEvaluationsResponse\x12(\n\x0b\x65valuations\x18\x01 \x03(\x0b\x32\x13.gateway.Evaluation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x93\x01\n\x17UpdateEvaluationRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12-\n\nevaluation\x18\x02 \x01(\x0b\x32\x13.gateway.EvaluationB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"-\n\x17\x44\x65leteEvaluationRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"w\n\x15TestEvaluationRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12-\n\nevaluation\x18\x02 \x01(\x0b\x32\x13.gateway.EvaluationB\x04\xe2\x41\x01\x02\x12\x19\n\x0bsample_data\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"_\n\x19ValidateAssertionsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12,\n\nassertions\x18\x02 \x03(\x0b\x32\x12.gateway.AssertionB\x04\xe2\x41\x01\x02\"\xa4\x02\n\x1aValidateAssertionsResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12Q\n\x10metric_to_errors\x18\x02 \x03(\x0b\x32\x37.gateway.ValidateAssertionsResponse.MetricToErrorsEntry\x1aq\n\x13MetricToErrorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.gateway.ValidateAssertionsResponse.ValidateAssertionError:\x02\x38\x01\x1a\x30\n\x16ValidateAssertionError\x12\x16\n\x0e\x65rror_messages\x18\x01 \x03(\t\"d\n\x18PreviewEvaluationRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0bsample_data\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0bmax_samples\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01\"\xe8\x01\n\x17PreviewEvaluationResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x11\n\x05score\x18\x03 \x01(\x01\x42\x02\x18\x01\x12)\n\x08messages\x18\x04 \x03(\x0b\x32\x17.google.protobuf.Struct\x12>\n\x07metrics\x18\x05 \x03(\x0b\x32-.gateway.PreviewEvaluationResult.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\x7f\n\x19PreviewEvaluationResponse\x12\x31\n\x07results\x18\x01 \x03(\x0b\x32 .gateway.PreviewEvaluationResult\x12\x15\n\rtotal_samples\x18\x02 \x01(\x05\x12\x18\n\x10total_runtime_ms\x18\x03 \x01(\x03\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.evaluation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_EVALUATION'].fields_by_name['name']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATION'].fields_by_name['create_time']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATION'].fields_by_name['created_by']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATION'].fields_by_name['status']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_EVALUATION'].fields_by_name['evaluation_type']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['evaluation_type']._serialized_options = b'\342A\001\002'
  _globals['_EVALUATION'].fields_by_name['description']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['description']._serialized_options = b'\342A\001\001'
  _globals['_EVALUATION'].fields_by_name['providers']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['providers']._serialized_options = b'\342A\001\002'
  _globals['_EVALUATION'].fields_by_name['assertions']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['assertions']._serialized_options = b'\342A\001\002'
  _globals['_EVALUATION'].fields_by_name['update_time']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_EVALUATION']._loaded_options = None
  _globals['_EVALUATION']._serialized_options = b'\030\001\352Ag\n\033api.fireworks.ai/Evaluation\022/accounts/{AccountId}/evaluations/{EvaluationId}*\013Evaluations2\nEvaluation\202\361\004\013\n\007Account\030\001'
  _globals['_ASSERTION'].fields_by_name['assertion_type']._loaded_options = None
  _globals['_ASSERTION'].fields_by_name['assertion_type']._serialized_options = b'\342A\001\002'
  _globals['_ASSERTION'].fields_by_name['metric_name']._loaded_options = None
  _globals['_ASSERTION'].fields_by_name['metric_name']._serialized_options = b'\342A\001\001'
  _globals['_LLMASSERTION'].fields_by_name['llm_evaluator_prompt']._loaded_options = None
  _globals['_LLMASSERTION'].fields_by_name['llm_evaluator_prompt']._serialized_options = b'\342A\001\001'
  _globals['_LLMASSERTION'].fields_by_name['providers']._loaded_options = None
  _globals['_LLMASSERTION'].fields_by_name['providers']._serialized_options = b'\342A\001\002'
  _globals['_LLMASSERTION'].fields_by_name['prompts']._loaded_options = None
  _globals['_LLMASSERTION'].fields_by_name['prompts']._serialized_options = b'\342A\001\002'
  _globals['_LLMASSERTION'].fields_by_name['evaluate_options']._loaded_options = None
  _globals['_LLMASSERTION'].fields_by_name['evaluate_options']._serialized_options = b'\342A\001\001'
  _globals['_CODEASSERTION_EXECUTIONOPTIONS_ENVVARSENTRY']._loaded_options = None
  _globals['_CODEASSERTION_EXECUTIONOPTIONS_ENVVARSENTRY']._serialized_options = b'8\001'
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['timeout_ms']._loaded_options = None
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['timeout_ms']._serialized_options = b'\342A\001\001\272H\010\032\006\030\340\247\022(\000'
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['memory_limit_mb']._loaded_options = None
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['memory_limit_mb']._serialized_options = b'\342A\001\001\272H\007\032\005\030\200\010(\000'
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['env_vars']._loaded_options = None
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['env_vars']._serialized_options = b'\342A\001\001'
  _globals['_CODEASSERTION'].fields_by_name['language']._loaded_options = None
  _globals['_CODEASSERTION'].fields_by_name['language']._serialized_options = b'\342A\001\002'
  _globals['_CODEASSERTION'].fields_by_name['code']._loaded_options = None
  _globals['_CODEASSERTION'].fields_by_name['code']._serialized_options = b'\342A\001\002'
  _globals['_CODEASSERTION'].fields_by_name['expected_output']._loaded_options = None
  _globals['_CODEASSERTION'].fields_by_name['expected_output']._serialized_options = b'\342A\001\001'
  _globals['_CODEASSERTION'].fields_by_name['options']._loaded_options = None
  _globals['_CODEASSERTION'].fields_by_name['options']._serialized_options = b'\342A\001\001'
  _globals['_PROVIDER_CONFIGENTRY']._loaded_options = None
  _globals['_PROVIDER_CONFIGENTRY']._serialized_options = b'8\001'
  _globals['_GETEVALUATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETEVALUATIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['evaluation']._loaded_options = None
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['evaluation']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['evaluation_id']._loaded_options = None
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['evaluation_id']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['evaluation']._loaded_options = None
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['evaluation']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEEVALUATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEEVALUATIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['evaluation']._loaded_options = None
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['evaluation']._serialized_options = b'\342A\001\002'
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['sample_data']._loaded_options = None
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['sample_data']._serialized_options = b'\342A\001\002'
  _globals['_VALIDATEASSERTIONSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_VALIDATEASSERTIONSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_VALIDATEASSERTIONSREQUEST'].fields_by_name['assertions']._loaded_options = None
  _globals['_VALIDATEASSERTIONSREQUEST'].fields_by_name['assertions']._serialized_options = b'\342A\001\002'
  _globals['_VALIDATEASSERTIONSRESPONSE_METRICTOERRORSENTRY']._loaded_options = None
  _globals['_VALIDATEASSERTIONSRESPONSE_METRICTOERRORSENTRY']._serialized_options = b'8\001'
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['sample_data']._loaded_options = None
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['sample_data']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['max_samples']._loaded_options = None
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['max_samples']._serialized_options = b'\342A\001\001'
  _globals['_PREVIEWEVALUATIONRESULT_METRICSENTRY']._loaded_options = None
  _globals['_PREVIEWEVALUATIONRESULT_METRICSENTRY']._serialized_options = b'8\001'
  _globals['_PREVIEWEVALUATIONRESULT'].fields_by_name['score']._loaded_options = None
  _globals['_PREVIEWEVALUATIONRESULT'].fields_by_name['score']._serialized_options = b'\030\001'
  _globals['_EVALUATION']._serialized_start=269
  _globals['_EVALUATION']._serialized_end=752
  _globals['_ASSERTION']._serialized_start=755
  _globals['_ASSERTION']._serialized_end=1049
  _globals['_ASSERTION_ASSERTIONTYPE']._serialized_start=953
  _globals['_ASSERTION_ASSERTIONTYPE']._serialized_end=1049
  _globals['_LLMASSERTION']._serialized_start=1052
  _globals['_LLMASSERTION']._serialized_end=1227
  _globals['_CODEASSERTION']._serialized_start=1230
  _globals['_CODEASSERTION']._serialized_end=1609
  _globals['_CODEASSERTION_EXECUTIONOPTIONS']._serialized_start=1387
  _globals['_CODEASSERTION_EXECUTIONOPTIONS']._serialized_end=1609
  _globals['_CODEASSERTION_EXECUTIONOPTIONS_ENVVARSENTRY']._serialized_start=1563
  _globals['_CODEASSERTION_EXECUTIONOPTIONS_ENVVARSENTRY']._serialized_end=1609
  _globals['_PROVIDER']._serialized_start=1612
  _globals['_PROVIDER']._serialized_end=1743
  _globals['_PROVIDER_CONFIGENTRY']._serialized_start=1698
  _globals['_PROVIDER_CONFIGENTRY']._serialized_end=1743
  _globals['_EVALUATEOPTIONS']._serialized_start=1745
  _globals['_EVALUATEOPTIONS']._serialized_end=1818
  _globals['_GETEVALUATIONREQUEST']._serialized_start=1820
  _globals['_GETEVALUATIONREQUEST']._serialized_end=1862
  _globals['_CREATEEVALUATIONREQUEST']._serialized_start=1864
  _globals['_CREATEEVALUATIONREQUEST']._serialized_end=1987
  _globals['_LISTEVALUATIONSREQUEST']._serialized_start=1990
  _globals['_LISTEVALUATIONSREQUEST']._serialized_end=2133
  _globals['_LISTEVALUATIONSRESPONSE']._serialized_start=2135
  _globals['_LISTEVALUATIONSRESPONSE']._serialized_end=2247
  _globals['_UPDATEEVALUATIONREQUEST']._serialized_start=2250
  _globals['_UPDATEEVALUATIONREQUEST']._serialized_end=2397
  _globals['_DELETEEVALUATIONREQUEST']._serialized_start=2399
  _globals['_DELETEEVALUATIONREQUEST']._serialized_end=2444
  _globals['_TESTEVALUATIONREQUEST']._serialized_start=2446
  _globals['_TESTEVALUATIONREQUEST']._serialized_end=2565
  _globals['_VALIDATEASSERTIONSREQUEST']._serialized_start=2567
  _globals['_VALIDATEASSERTIONSREQUEST']._serialized_end=2662
  _globals['_VALIDATEASSERTIONSRESPONSE']._serialized_start=2665
  _globals['_VALIDATEASSERTIONSRESPONSE']._serialized_end=2957
  _globals['_VALIDATEASSERTIONSRESPONSE_METRICTOERRORSENTRY']._serialized_start=2794
  _globals['_VALIDATEASSERTIONSRESPONSE_METRICTOERRORSENTRY']._serialized_end=2907
  _globals['_VALIDATEASSERTIONSRESPONSE_VALIDATEASSERTIONERROR']._serialized_start=2909
  _globals['_VALIDATEASSERTIONSRESPONSE_VALIDATEASSERTIONERROR']._serialized_end=2957
  _globals['_PREVIEWEVALUATIONREQUEST']._serialized_start=2959
  _globals['_PREVIEWEVALUATIONREQUEST']._serialized_end=3059
  _globals['_PREVIEWEVALUATIONRESULT']._serialized_start=3062
  _globals['_PREVIEWEVALUATIONRESULT']._serialized_end=3294
  _globals['_PREVIEWEVALUATIONRESULT_METRICSENTRY']._serialized_start=3248
  _globals['_PREVIEWEVALUATIONRESULT_METRICSENTRY']._serialized_end=3294
  _globals['_PREVIEWEVALUATIONRESPONSE']._serialized_start=3296
  _globals['_PREVIEWEVALUATIONRESPONSE']._serialized_end=3423
# @@protoc_insertion_point(module_scope)
