# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/supervised_fine_tuning_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/supervised_fine_tuning_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from . import wandb_pb2 as gateway_dot_wandb__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(gateway/supervised_fine_tuning_job.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x18gateway/deployment.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x13gateway/wandb.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe1\x0e\n\x17SupervisedFineTuningJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x39\n\x0e\x63ompleted_time\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x15\n\x07\x64\x61taset\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02\x12\'\n\x05state\x18\x05 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x07 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0coutput_model\x18\x08 \x01(\tB\x04\xe2\x41\x01\x01\x12\x18\n\nbase_model\x18\t \x01(\tB\x04\xe2\x41\x01\x01\x12\x1d\n\x0fwarm_start_from\x18\n \x01(\tB\x04\xe2\x41\x01\x01\x12\x1c\n\x0ejinja_template\x18\x0b \x01(\tB\x04\xe2\x41\x01\x01\x12\x18\n\nearly_stop\x18\x0c \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x1d\n\x06\x65pochs\x18\r \x01(\x05\x42\r\xe2\x41\x01\x01\xbaH\x06\x1a\x04\x18\x64(\x00\x12*\n\rlearning_rate\x18\x0e \x01(\x02\x42\x13\xe2\x41\x01\x01\xbaH\x0c\n\n\x1d\xcd\xcc\xcc=-\x00\x00\x00\x00\x12\'\n\x12max_context_length\x18\x0f \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12 \n\tlora_rank\x18\x10 \x01(\x05\x42\r\xe2\x41\x01\x01\xbaH\x06\x1a\x04\x18 (\x00\x12q\n\x1b\x62\x61se_model_weight_precision\x18\x11 \x01(\x0e\x32\x30.gateway.SupervisedFineTuningJob.WeightPrecisionB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x30\n\x0cwandb_config\x18\x12 \x01(\x0b\x32\x14.gateway.WandbConfigB\x04\xe2\x41\x01\x01\x12 \n\x12\x65valuation_dataset\x18\x13 \x01(\tB\x04\xe2\x41\x01\x01\x12N\n\x10\x61\x63\x63\x65lerator_type\x18\x14 \x01(\x0e\x32\x18.gateway.AcceleratorTypeB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x11\x61\x63\x63\x65lerator_count\x18\x15 \x01(\x05\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x16\n\x08is_turbo\x18\x16 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12 \n\x12\x65val_auto_carveout\x18\x18 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12%\n\x06region\x18\x19 \x01(\x0e\x32\x0f.gateway.RegionB\x04\xe2\x41\x01\x01\x12\x35\n\x0bupdate_time\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x13\n\x05nodes\x18\x1b \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x1f\n\nbatch_size\x18\x1c \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12\x19\n\x0bmtp_enabled\x18\x1d \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\"\n\x14mtp_num_draft_tokens\x18\x1e \x01(\x05\x42\x04\xe2\x41\x01\x01\x12#\n\x15mtp_freeze_base_model\x18\x1f \x01(\x08\x42\x04\xe2\x41\x01\x01\"T\n\x0fWeightPrecision\x12 \n\x1cWEIGHT_PRECISION_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x42\x46LOAT16\x10\x01\x12\x08\n\x04INT8\x10\x02\x12\x07\n\x03NF4\x10\x03:\xa5\x04\xea\x41\xa8\x01\n(api.fireworks.ai/SupervisedFineTuningJob\x12Iaccounts/{AccountId}/supervisedFineTuningJobs/{SupervisedFineTuningJobId}*\x18supervisedFineTuningJobs2\x17supervisedFineTuningJob\xbaH\xe6\x02\x1a\xb6\x01\n;supervised_fine_tuning_job.exactly_one_of_must_be_specified\x12>exactly one of base_model or warm_start_from must be specified\x1a\x37(this.base_model != \'\') != (this.warm_start_from != \'\')\x1a\xaa\x01\n<supervised_fine_tuning_job.batch_size_gte_max_context_length\x12>batch_size must be greater than or equal to max_context_length\x1a*this.batch_size >= this.max_context_length\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"7\n!GetSupervisedFineTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xe0\x01\n$CreateSupervisedFineTuningJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12J\n\x1asupervised_fine_tuning_job\x18\x02 \x01(\x0b\x32 .gateway.SupervisedFineTuningJobB\x04\xe2\x41\x01\x02\x12)\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12+\n\x1dsupervised_fine_tuning_job_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\"\x9c\x01\n#ListSupervisedFineTuningJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\x9a\x01\n$ListSupervisedFineTuningJobsResponse\x12\x45\n\x1bsupervised_fine_tuning_jobs\x18\x01 \x03(\x0b\x32 .gateway.SupervisedFineTuningJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\":\n$DeleteSupervisedFineTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.supervised_fine_tuning_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['name']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['completed_time']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['completed_time']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['dataset']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['dataset']._serialized_options = b'\342A\001\002'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['state']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['status']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['output_model']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['output_model']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['base_model']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['base_model']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['warm_start_from']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['warm_start_from']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['jinja_template']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['jinja_template']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['early_stop']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['early_stop']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['epochs']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['epochs']._serialized_options = b'\342A\001\001\272H\006\032\004\030d(\000'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['learning_rate']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['learning_rate']._serialized_options = b'\342A\001\001\272H\014\n\n\035\315\314\314=-\000\000\000\000'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['max_context_length']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['max_context_length']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['lora_rank']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['lora_rank']._serialized_options = b'\342A\001\001\272H\006\032\004\030 (\000'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['base_model_weight_precision']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['base_model_weight_precision']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['wandb_config']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['wandb_config']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['evaluation_dataset']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['evaluation_dataset']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['accelerator_type']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['accelerator_type']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['accelerator_count']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['accelerator_count']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['is_turbo']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['is_turbo']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['eval_auto_carveout']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['eval_auto_carveout']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['region']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['region']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['nodes']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['nodes']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['batch_size']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['batch_size']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_enabled']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_enabled']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_num_draft_tokens']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_num_draft_tokens']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_freeze_base_model']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_freeze_base_model']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB']._serialized_options = b'\352A\250\001\n(api.fireworks.ai/SupervisedFineTuningJob\022Iaccounts/{AccountId}/supervisedFineTuningJobs/{SupervisedFineTuningJobId}*\030supervisedFineTuningJobs2\027supervisedFineTuningJob\272H\346\002\032\266\001\n;supervised_fine_tuning_job.exactly_one_of_must_be_specified\022>exactly one of base_model or warm_start_from must be specified\0327(this.base_model != \'\') != (this.warm_start_from != \'\')\032\252\001\n<supervised_fine_tuning_job.batch_size_gte_max_context_length\022>batch_size must be greater than or equal to max_context_length\032*this.batch_size >= this.max_context_length\202\361\004\013\n\007Account\030\001'
  _globals['_GETSUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETSUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['supervised_fine_tuning_job']._loaded_options = None
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['supervised_fine_tuning_job']._serialized_options = b'\342A\001\002'
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['debug']._loaded_options = None
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['debug']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['supervised_fine_tuning_job_id']._loaded_options = None
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['supervised_fine_tuning_job_id']._serialized_options = b'\342A\001\001'
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_SUPERVISEDFINETUNINGJOB']._serialized_start=297
  _globals['_SUPERVISEDFINETUNINGJOB']._serialized_end=2186
  _globals['_SUPERVISEDFINETUNINGJOB_WEIGHTPRECISION']._serialized_start=1550
  _globals['_SUPERVISEDFINETUNINGJOB_WEIGHTPRECISION']._serialized_end=1634
  _globals['_GETSUPERVISEDFINETUNINGJOBREQUEST']._serialized_start=2188
  _globals['_GETSUPERVISEDFINETUNINGJOBREQUEST']._serialized_end=2243
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST']._serialized_start=2246
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST']._serialized_end=2470
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST']._serialized_start=2473
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST']._serialized_end=2629
  _globals['_LISTSUPERVISEDFINETUNINGJOBSRESPONSE']._serialized_start=2632
  _globals['_LISTSUPERVISEDFINETUNINGJOBSRESPONSE']._serialized_end=2786
  _globals['_DELETESUPERVISEDFINETUNINGJOBREQUEST']._serialized_start=2788
  _globals['_DELETESUPERVISEDFINETUNINGJOBREQUEST']._serialized_end=2846
# @@protoc_insertion_point(module_scope)
