# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/fine_tuning_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/fine_tuning_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgateway/fine_tuning_job.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x99\x18\n\rFineTuningJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x32\n\x05state\x18\x04 \x01(\x0e\x32\x1c.gateway.FineTuningJob.StateB\x05\xe2\x41\x02\x03\x05\x12\x15\n\x07\x64\x61taset\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x30\n\x08\x64\x61tasets\x18\x1d \x03(\x0b\x32\x1e.gateway.FineTuningJob.Dataset\x12&\n\x06status\x18\t \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\n \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1f\n\x11\x63ontainer_version\x18\x0b \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08model_id\x18\r \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\nlegacy_job\x18& \x01(\x0b\x32 .gateway.FineTuningJob.LegacyJobH\x00\x12@\n\x0ftext_completion\x18\x0f \x01(\x0b\x32%.gateway.FineTuningJob.TextCompletionH\x00\x12H\n\x13text_classification\x18\x10 \x01(\x0b\x32).gateway.FineTuningJob.TextClassificationH\x00\x12;\n\x0c\x63onversation\x18\x17 \x01(\x0b\x32#.gateway.FineTuningJob.ConversationH\x00\x12\x45\n\x10\x64raft_model_data\x18  \x01(\x0b\x32%.gateway.FineTuningJob.DraftModelDataB\x02\x18\x01H\x00\x12<\n\x0b\x64raft_model\x18\x18 \x01(\x0b\x32!.gateway.FineTuningJob.DraftModelB\x02\x18\x01H\x00\x12\x31\n\x05genie\x18\x1b \x01(\x0b\x32\x1c.gateway.FineTuningJob.GenieB\x02\x18\x01H\x00\x12\x18\n\nbase_model\x18\x11 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1e\n\x0fwarm_start_from\x18\" \x01(\tB\x05\xe2\x41\x02\x03\x05\x12.\n\nearly_stop\x18. \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12+\n\x06\x65pochs\x18\x12 \x01(\x01\x42\x1b\xe2\x41\x01\x01\xbaH\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00Y@)\x00\x00\x00\x00\x00\x00\x00\x00\x12\x32\n\rlearning_rate\x18\x13 \x01(\x01\x42\x1b\xe2\x41\x01\x01\xbaH\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00\x12\x35\n\x11lr_scheduler_type\x18, \x01(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x37\n\x0cwarmup_steps\x18- \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x38\n\nlora_alpha\x18* \x01(\x05\x42$\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\x80\x08(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12 \n\tlora_rank\x18\x19 \x01(\x05\x42\r\xe2\x41\x01\x01\xbaH\x06\x1a\x04\x18 (\x00\x12!\n\x13lora_target_modules\x18+ \x03(\tB\x04\xe2\x41\x01\x01\x12\"\n\nbatch_size\x18\x1a \x01(\x05\x42\x0e\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\x80\x08(\x00\x12%\n\x10micro_batch_size\x18\' \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12\x18\n\nmask_token\x18# \x01(\tB\x04\xe2\x41\x01\x01\x12\x17\n\tpad_token\x18$ \x01(\tB\x04\xe2\x41\x01\x01\x12\x38\n\rcutoff_length\x18% \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x18\n\twandb_url\x18\x0e \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0cwandb_entity\x18\x14 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1c\n\rwandb_api_key\x18\x15 \x01(\tB\x05\xe2\x41\x02\x01\x04\x12\x1b\n\rwandb_project\x18\x16 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\nevaluation\x18\x1e \x01(\x08\x42\x02\x18\x01\x12\x1e\n\x10\x65valuation_split\x18\x1f \x01(\x01\x42\x04\xe2\x41\x01\x01\x12 \n\x12\x65valuation_dataset\x18) \x01(\tB\x04\xe2\x41\x01\x01\x12\x1c\n\x0e\x64\x65pendent_jobs\x18! \x03(\tB\x04\xe2\x41\x01\x01\x1a!\n\x07\x44\x61taset\x12\x16\n\x07\x64\x61taset\x18\x01 \x01(\tB\x05\xe2\x41\x02\x05\x01\x1a\x0b\n\tLegacyJob\x1aM\n\x0eTextCompletion\x12\x1c\n\x0einput_template\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1d\n\x0foutput_template\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x1a=\n\x12TextClassification\x12\x12\n\x04text\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05label\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x1ao\n\x0e\x44raftModelData\x12\x1d\n\x0f\x64\x65ployment_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1c\n\x0ejinja_template\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12 \n\x12\x63leanup_deployment\x18\x1e \x01(\x08\x42\x04\xe2\x41\x01\x01\x1a\x0c\n\nDraftModel\x1a,\n\x0c\x43onversation\x12\x1c\n\x0ejinja_template\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01\x1a(\n\x05Genie\x12\x1b\n\rpipeline_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02:\x02\x18\x01\"o\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06:\x83\x07\xea\x41v\n\x1e\x61pi.fireworks.ai/FineTuningJob\x12\x35\x61\x63\x63ounts/{AccountId}/fineTuningJobs/{FineTuningJobId}*\x0e\x66ineTuningJobs2\rfineTuningJob\xbaH\xf7\x05\x1a\xb2\x01\n-fine_tuning_job.wandb_entity.requires_api_key\x12Hwandb_api_key must be specified if and only if wandb_entity is specified\x1a\x37(this.wandb_entity == \'\') == (this.wandb_api_key == \'\')\x1a\xb2\x01\n-fine_tuning_job.wandb_entity.requires_project\x12Hwandb_project must be specified if and only if wandb_entity is specified\x1a\x37(this.wandb_entity == \'\') == (this.wandb_project == \'\')\x1a\xab\x01\n0fine_tuning_job.exactly_one_of_must_be_specified\x12>exactly one of base_model or warm_start_from must be specified\x1a\x37(this.base_model != \'\') != (this.warm_start_from != \'\')\x1a\xdc\x01\n&fine_tuning_job.evaluation_split_range\x12Sevaluation_split must be between 0 and 0.5 when evaluation_dataset is not specified\x1a]this.evaluation_dataset != \'\' || (this.evaluation_split >= 0 && this.evaluation_split <= 0.5)\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\x42\x06\n\x04kind\"-\n\x17GetFineTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xd7\x01\n\x1a\x43reateFineTuningJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x35\n\x0f\x66ine_tuning_job\x18\x02 \x01(\x0b\x32\x16.gateway.FineTuningJobB\x04\xe2\x41\x01\x02\x12\x13\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12 \n\x12\x66ine_tuning_job_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x35\n\x0bupdate_time\x18/ \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\"\x92\x01\n\x19ListFineTuningJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"{\n\x1aListFineTuningJobsResponse\x12\x30\n\x10\x66ine_tuning_jobs\x18\x01 \x03(\x0b\x32\x16.gateway.FineTuningJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x8a\x01\n\x1aUpdateFineTuningJobRequest\x12\x35\n\x0f\x66ine_tuning_job\x18\x01 \x01(\x0b\x32\x16.gateway.FineTuningJobB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"0\n\x1a\x44\x65leteFineTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.fine_tuning_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_FINETUNINGJOB_DATASET'].fields_by_name['dataset']._loaded_options = None
  _globals['_FINETUNINGJOB_DATASET'].fields_by_name['dataset']._serialized_options = b'\342A\002\005\001'
  _globals['_FINETUNINGJOB_TEXTCOMPLETION'].fields_by_name['input_template']._loaded_options = None
  _globals['_FINETUNINGJOB_TEXTCOMPLETION'].fields_by_name['input_template']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_TEXTCOMPLETION'].fields_by_name['output_template']._loaded_options = None
  _globals['_FINETUNINGJOB_TEXTCOMPLETION'].fields_by_name['output_template']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION'].fields_by_name['text']._loaded_options = None
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION'].fields_by_name['text']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION'].fields_by_name['label']._loaded_options = None
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION'].fields_by_name['label']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['deployment_name']._loaded_options = None
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['deployment_name']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['jinja_template']._loaded_options = None
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['jinja_template']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['cleanup_deployment']._loaded_options = None
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['cleanup_deployment']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB_CONVERSATION'].fields_by_name['jinja_template']._loaded_options = None
  _globals['_FINETUNINGJOB_CONVERSATION'].fields_by_name['jinja_template']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB_GENIE'].fields_by_name['pipeline_name']._loaded_options = None
  _globals['_FINETUNINGJOB_GENIE'].fields_by_name['pipeline_name']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_GENIE']._loaded_options = None
  _globals['_FINETUNINGJOB_GENIE']._serialized_options = b'\030\001'
  _globals['_FINETUNINGJOB'].fields_by_name['name']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['state']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['dataset']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['dataset']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['status']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['container_version']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['container_version']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['model_id']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['model_id']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['draft_model_data']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['draft_model_data']._serialized_options = b'\030\001'
  _globals['_FINETUNINGJOB'].fields_by_name['draft_model']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['draft_model']._serialized_options = b'\030\001'
  _globals['_FINETUNINGJOB'].fields_by_name['genie']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['genie']._serialized_options = b'\030\001'
  _globals['_FINETUNINGJOB'].fields_by_name['base_model']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['base_model']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['warm_start_from']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['warm_start_from']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['early_stop']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['early_stop']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_FINETUNINGJOB'].fields_by_name['epochs']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['epochs']._serialized_options = b'\342A\001\001\272H\024\022\022\031\000\000\000\000\000\000Y@)\000\000\000\000\000\000\000\000'
  _globals['_FINETUNINGJOB'].fields_by_name['learning_rate']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['learning_rate']._serialized_options = b'\342A\001\001\272H\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000'
  _globals['_FINETUNINGJOB'].fields_by_name['lr_scheduler_type']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['lr_scheduler_type']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_FINETUNINGJOB'].fields_by_name['warmup_steps']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['warmup_steps']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_FINETUNINGJOB'].fields_by_name['lora_alpha']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['lora_alpha']._serialized_options = b'\342A\001\001\272H\007\032\005\030\200\010(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_FINETUNINGJOB'].fields_by_name['lora_rank']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['lora_rank']._serialized_options = b'\342A\001\001\272H\006\032\004\030 (\000'
  _globals['_FINETUNINGJOB'].fields_by_name['lora_target_modules']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['lora_target_modules']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['batch_size']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['batch_size']._serialized_options = b'\342A\001\001\272H\007\032\005\030\200\010(\000'
  _globals['_FINETUNINGJOB'].fields_by_name['micro_batch_size']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['micro_batch_size']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_FINETUNINGJOB'].fields_by_name['mask_token']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['mask_token']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['pad_token']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['pad_token']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['cutoff_length']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['cutoff_length']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_url']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_url']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_entity']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_entity']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_api_key']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_api_key']._serialized_options = b'\342A\002\001\004'
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_project']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_project']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation']._serialized_options = b'\030\001'
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation_split']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation_split']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation_dataset']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation_dataset']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['dependent_jobs']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['dependent_jobs']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB']._loaded_options = None
  _globals['_FINETUNINGJOB']._serialized_options = b'\352Av\n\036api.fireworks.ai/FineTuningJob\0225accounts/{AccountId}/fineTuningJobs/{FineTuningJobId}*\016fineTuningJobs2\rfineTuningJob\272H\367\005\032\262\001\n-fine_tuning_job.wandb_entity.requires_api_key\022Hwandb_api_key must be specified if and only if wandb_entity is specified\0327(this.wandb_entity == \'\') == (this.wandb_api_key == \'\')\032\262\001\n-fine_tuning_job.wandb_entity.requires_project\022Hwandb_project must be specified if and only if wandb_entity is specified\0327(this.wandb_entity == \'\') == (this.wandb_project == \'\')\032\253\001\n0fine_tuning_job.exactly_one_of_must_be_specified\022>exactly one of base_model or warm_start_from must be specified\0327(this.base_model != \'\') != (this.warm_start_from != \'\')\032\334\001\n&fine_tuning_job.evaluation_split_range\022Sevaluation_split must be between 0 and 0.5 when evaluation_dataset is not specified\032]this.evaluation_dataset != \'\' || (this.evaluation_split >= 0 && this.evaluation_split <= 0.5)\202\361\004\013\n\007Account\030\001'
  _globals['_GETFINETUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETFINETUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job']._loaded_options = None
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job']._serialized_options = b'\342A\001\002'
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['debug']._loaded_options = None
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['debug']._serialized_options = b'\342A\001\001'
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job_id']._loaded_options = None
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job_id']._serialized_options = b'\342A\001\001'
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['update_time']._loaded_options = None
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job']._loaded_options = None
  _globals['_UPDATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEFINETUNINGJOBREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEFINETUNINGJOBREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEFINETUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEFINETUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB']._serialized_start=273
  _globals['_FINETUNINGJOB']._serialized_end=3370
  _globals['_FINETUNINGJOB_DATASET']._serialized_start=1944
  _globals['_FINETUNINGJOB_DATASET']._serialized_end=1977
  _globals['_FINETUNINGJOB_LEGACYJOB']._serialized_start=1979
  _globals['_FINETUNINGJOB_LEGACYJOB']._serialized_end=1990
  _globals['_FINETUNINGJOB_TEXTCOMPLETION']._serialized_start=1992
  _globals['_FINETUNINGJOB_TEXTCOMPLETION']._serialized_end=2069
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION']._serialized_start=2071
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION']._serialized_end=2132
  _globals['_FINETUNINGJOB_DRAFTMODELDATA']._serialized_start=2134
  _globals['_FINETUNINGJOB_DRAFTMODELDATA']._serialized_end=2245
  _globals['_FINETUNINGJOB_DRAFTMODEL']._serialized_start=2247
  _globals['_FINETUNINGJOB_DRAFTMODEL']._serialized_end=2259
  _globals['_FINETUNINGJOB_CONVERSATION']._serialized_start=2261
  _globals['_FINETUNINGJOB_CONVERSATION']._serialized_end=2305
  _globals['_FINETUNINGJOB_GENIE']._serialized_start=2307
  _globals['_FINETUNINGJOB_GENIE']._serialized_end=2347
  _globals['_FINETUNINGJOB_STATE']._serialized_start=2349
  _globals['_FINETUNINGJOB_STATE']._serialized_end=2460
  _globals['_GETFINETUNINGJOBREQUEST']._serialized_start=3372
  _globals['_GETFINETUNINGJOBREQUEST']._serialized_end=3417
  _globals['_CREATEFINETUNINGJOBREQUEST']._serialized_start=3420
  _globals['_CREATEFINETUNINGJOBREQUEST']._serialized_end=3635
  _globals['_LISTFINETUNINGJOBSREQUEST']._serialized_start=3638
  _globals['_LISTFINETUNINGJOBSREQUEST']._serialized_end=3784
  _globals['_LISTFINETUNINGJOBSRESPONSE']._serialized_start=3786
  _globals['_LISTFINETUNINGJOBSRESPONSE']._serialized_end=3909
  _globals['_UPDATEFINETUNINGJOBREQUEST']._serialized_start=3912
  _globals['_UPDATEFINETUNINGJOBREQUEST']._serialized_end=4050
  _globals['_DELETEFINETUNINGJOBREQUEST']._serialized_start=4052
  _globals['_DELETEFINETUNINGJOBREQUEST']._serialized_end=4100
# @@protoc_insertion_point(module_scope)
