# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12gateway/user.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xce\x04\n\x04User\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\'\n\nfirst_name\x18\t \x01(\tB\x13\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12&\n\tlast_name\x18\n \x01(\tB\x13\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12(\n\x0bstated_role\x18\x0b \x01(\tB\x13\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12\x36\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x12\n\x04role\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x14\n\x05\x65mail\x18\x04 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12)\n\x05state\x18\x06 \x01(\x0e\x32\x13.gateway.User.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x07 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\"S\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04:Y\xea\x41I\n\x15\x61pi.fireworks.ai/User\x12#accounts/{AccountId}/users/{UserId}*\x05users2\x04user\x82\xf1\x04\t\n\x07\x41\x63\x63ount\"c\n\x11\x43reateUserRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12!\n\x04user\x18\x02 \x01(\x0b\x32\r.gateway.UserB\x04\xe2\x41\x01\x02\x12\x15\n\x07user_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"$\n\x0eGetUserRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x89\x01\n\x10ListUsersRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"^\n\x11ListUsersResponse\x12\x1c\n\x05users\x18\x01 \x03(\x0b\x32\r.gateway.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"m\n\x11UpdateUserRequest\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.gateway.UserB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"\'\n\x11\x44\x65leteUserRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_USER'].fields_by_name['name']._loaded_options = None
  _globals['_USER'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_USER'].fields_by_name['display_name']._loaded_options = None
  _globals['_USER'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_USER'].fields_by_name['first_name']._loaded_options = None
  _globals['_USER'].fields_by_name['first_name']._serialized_options = b'\342A\001\001\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_USER'].fields_by_name['last_name']._loaded_options = None
  _globals['_USER'].fields_by_name['last_name']._serialized_options = b'\342A\001\001\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_USER'].fields_by_name['stated_role']._loaded_options = None
  _globals['_USER'].fields_by_name['stated_role']._serialized_options = b'\342A\001\001\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_USER'].fields_by_name['create_time']._loaded_options = None
  _globals['_USER'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_USER'].fields_by_name['role']._loaded_options = None
  _globals['_USER'].fields_by_name['role']._serialized_options = b'\342A\001\002'
  _globals['_USER'].fields_by_name['email']._loaded_options = None
  _globals['_USER'].fields_by_name['email']._serialized_options = b'\342A\002\002\005'
  _globals['_USER'].fields_by_name['state']._loaded_options = None
  _globals['_USER'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_USER'].fields_by_name['status']._loaded_options = None
  _globals['_USER'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_USER'].fields_by_name['update_time']._loaded_options = None
  _globals['_USER'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_USER']._loaded_options = None
  _globals['_USER']._serialized_options = b'\352AI\n\025api.fireworks.ai/User\022#accounts/{AccountId}/users/{UserId}*\005users2\004user\202\361\004\t\n\007Account'
  _globals['_CREATEUSERREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEUSERREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['user']._serialized_options = b'\342A\001\002'
  _globals['_CREATEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\342A\001\001'
  _globals['_GETUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTUSERSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTUSERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTUSERSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_USER']._serialized_start=233
  _globals['_USER']._serialized_end=823
  _globals['_USER_STATE']._serialized_start=649
  _globals['_USER_STATE']._serialized_end=732
  _globals['_CREATEUSERREQUEST']._serialized_start=825
  _globals['_CREATEUSERREQUEST']._serialized_end=924
  _globals['_GETUSERREQUEST']._serialized_start=926
  _globals['_GETUSERREQUEST']._serialized_end=962
  _globals['_LISTUSERSREQUEST']._serialized_start=965
  _globals['_LISTUSERSREQUEST']._serialized_end=1102
  _globals['_LISTUSERSRESPONSE']._serialized_start=1104
  _globals['_LISTUSERSRESPONSE']._serialized_end=1198
  _globals['_UPDATEUSERREQUEST']._serialized_start=1200
  _globals['_UPDATEUSERREQUEST']._serialized_end=1309
  _globals['_DELETEUSERREQUEST']._serialized_start=1311
  _globals['_DELETEUSERREQUEST']._serialized_end=1350
# @@protoc_insertion_point(module_scope)
