# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/options.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/options.proto\x12\x07gateway\x1a google/protobuf/descriptor.proto\"Q\n\x0b\x41piResource\x12\x13\n\x0bparent_type\x18\x01 \x01(\t\x12\x11\n\tskip_gorm\x18\x02 \x01(\x08\x12\x1a\n\x12has_db_only_fields\x18\x03 \x01(\x08:O\n\x0c\x61pi_resource\x12\x1f.google.protobuf.MessageOptions\x18\x90N \x01(\x0b\x32\x14.gateway.ApiResource\x88\x01\x01:3\n\x08\x61pi_only\x12\x1d.google.protobuf.FieldOptions\x18\x93N \x01(\x08\x88\x01\x01:4\n\tgorm_json\x12\x1d.google.protobuf.FieldOptions\x18\x94N \x01(\x08\x88\x01\x01:7\n\x0cshow_if_zero\x12\x1d.google.protobuf.FieldOptions\x18\x95N \x01(\x08\x88\x01\x01:2\n\ngorm_index\x12\x1d.google.protobuf.FieldOptions\x18\x96N \x01(\x08:9\n\x11gorm_unique_index\x12\x1d.google.protobuf.FieldOptions\x18\x97N \x01(\x08:?\n\x17gorm_unique_named_index\x12\x1d.google.protobuf.FieldOptions\x18\x98N \x01(\tBCZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_APIRESOURCE']._serialized_start=68
  _globals['_APIRESOURCE']._serialized_end=149
# @@protoc_insertion_point(module_scope)
