# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/batch_job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/batch_job.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17gateway/batch_job.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x08\n\x08\x42\x61tchJob\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\t \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x36\n\nstart_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x34\n\x08\x65nd_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1a\n\ncreated_by\x18\r \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1c\n\x0cnode_pool_id\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x1e\n\x0e\x65nvironment_id\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1b\n\x0bsnapshot_id\x18\x13 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x19\n\tnum_ranks\x18\x0b \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x38\n\x08\x65nv_vars\x18\x06 \x03(\x0b\x32\x1e.gateway.BatchJob.EnvVarsEntryB\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04role\x18\x11 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x32\n\x0fpython_executor\x18\x07 \x01(\x0b\x32\x17.gateway.PythonExecutorH\x00\x12\x36\n\x11notebook_executor\x18\x08 \x01(\x0b\x32\x19.gateway.NotebookExecutorH\x00\x12\x30\n\x0eshell_executor\x18\x10 \x01(\x0b\x32\x16.gateway.ShellExecutorH\x00\x12\x19\n\timage_ref\x18\n \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12?\n\x0b\x61nnotations\x18\x12 \x03(\x0b\x32\".gateway.BatchJob.AnnotationsEntryB\x06\xe0\x41\x01\xe0\x41\x05\x12.\n\x05state\x18\x04 \x01(\x0e\x32\x17.gateway.BatchJob.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\x16\n\x06status\x18\x05 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x0e\n\x06shared\x18\x14 \x01(\x08\x1a.\n\x0c\x45nvVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x07\x12\n\n\x06QUEUED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0e\n\nCANCELLING\x10\x08\x12\r\n\tCANCELLED\x10\x06\x12\x0c\n\x08\x44\x45LETING\x10\tB\n\n\x08\x65xecutor\"W\n\x15\x43reateBatchJobRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12)\n\tbatch_job\x18\x02 \x01(\x0b\x32\x11.gateway.BatchJobB\x03\xe0\x41\x02\"\'\n\x12GetBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x88\x01\n\x14ListBatchJobsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"k\n\x15ListBatchJobsResponse\x12%\n\nbatch_jobs\x18\x01 \x03(\x0b\x32\x11.gateway.BatchJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"*\n\x15\x44\x65leteBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"F\n\x1b\x42\x61tchDeleteBatchJobsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05names\x18\x02 \x03(\tB\x03\xe0\x41\x02\"*\n\x15\x43\x61ncelBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\xd3\x01\n\x16GetBatchJobLogsRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\r\n\x05ranks\x18\x03 \x03(\x05\x12\x16\n\tpage_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x05 \x01(\tB\x03\xe0\x41\x01\x12\x33\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x07 \x01(\tB\x03\xe0\x41\x01\x12\x1c\n\x0fstart_from_head\x18\x08 \x01(\x08\x42\x03\xe0\x41\x01\"V\n\x17GetBatchJobLogsResponse\x12\"\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x11.gateway.LogEntry\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\xbb\x01\n\x0ePythonExecutor\x12<\n\x0btarget_type\x18\x01 \x01(\x0e\x32\".gateway.PythonExecutor.TargetTypeB\x03\xe0\x41\x02\x12\x13\n\x06target\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04\x61rgs\x18\x03 \x03(\tB\x03\xe0\x41\x01\"C\n\nTargetType\x12\x1b\n\x17TARGET_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MODULE\x10\x01\x12\x0c\n\x08\x46ILENAME\x10\x02\"%\n\rShellExecutor\x12\x14\n\x07\x63ommand\x18\x01 \x01(\tB\x03\xe0\x41\x02\"2\n\x10NotebookExecutor\x12\x1e\n\x11notebook_filename\x18\x01 \x01(\tB\x03\xe0\x41\x02\"W\n\x08LogEntry\x12,\n\x08log_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04rank\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\tB\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_BATCHJOB_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='gateway.BatchJob.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUEUED', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=3, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=4, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=5, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=6, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELLING', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=8, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=996,
  serialized_end=1150,
)
_sym_db.RegisterEnumDescriptor(_BATCHJOB_STATE)

_PYTHONEXECUTOR_TARGETTYPE = _descriptor.EnumDescriptor(
  name='TargetType',
  full_name='gateway.PythonExecutor.TargetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TARGET_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODULE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILENAME', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2125,
  serialized_end=2192,
)
_sym_db.RegisterEnumDescriptor(_PYTHONEXECUTOR_TARGETTYPE)


_BATCHJOB_ENVVARSENTRY = _descriptor.Descriptor(
  name='EnvVarsEntry',
  full_name='gateway.BatchJob.EnvVarsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.BatchJob.EnvVarsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.BatchJob.EnvVarsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=941,
)

_BATCHJOB_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='gateway.BatchJob.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.BatchJob.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.BatchJob.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=943,
  serialized_end=993,
)

_BATCHJOB = _descriptor.Descriptor(
  name='BatchJob',
  full_name='gateway.BatchJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.BatchJob.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.BatchJob.display_name', index=1,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.BatchJob.create_time', index=2,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='gateway.BatchJob.start_time', index=3,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='gateway.BatchJob.end_time', index=4,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='gateway.BatchJob.created_by', index=5,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_pool_id', full_name='gateway.BatchJob.node_pool_id', index=6,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment_id', full_name='gateway.BatchJob.environment_id', index=7,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_id', full_name='gateway.BatchJob.snapshot_id', index=8,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_ranks', full_name='gateway.BatchJob.num_ranks', index=9,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_vars', full_name='gateway.BatchJob.env_vars', index=10,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='gateway.BatchJob.role', index=11,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='python_executor', full_name='gateway.BatchJob.python_executor', index=12,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notebook_executor', full_name='gateway.BatchJob.notebook_executor', index=13,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shell_executor', full_name='gateway.BatchJob.shell_executor', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_ref', full_name='gateway.BatchJob.image_ref', index=15,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='gateway.BatchJob.annotations', index=16,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='gateway.BatchJob.state', index=17,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.BatchJob.status', index=18,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared', full_name='gateway.BatchJob.shared', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BATCHJOB_ENVVARSENTRY, _BATCHJOB_ANNOTATIONSENTRY, ],
  enum_types=[
    _BATCHJOB_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='executor', full_name='gateway.BatchJob.executor',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=103,
  serialized_end=1162,
)


_CREATEBATCHJOBREQUEST = _descriptor.Descriptor(
  name='CreateBatchJobRequest',
  full_name='gateway.CreateBatchJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateBatchJobRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_job', full_name='gateway.CreateBatchJobRequest.batch_job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1164,
  serialized_end=1251,
)


_GETBATCHJOBREQUEST = _descriptor.Descriptor(
  name='GetBatchJobRequest',
  full_name='gateway.GetBatchJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetBatchJobRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1253,
  serialized_end=1292,
)


_LISTBATCHJOBSREQUEST = _descriptor.Descriptor(
  name='ListBatchJobsRequest',
  full_name='gateway.ListBatchJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListBatchJobsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListBatchJobsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListBatchJobsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListBatchJobsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListBatchJobsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1295,
  serialized_end=1431,
)


_LISTBATCHJOBSRESPONSE = _descriptor.Descriptor(
  name='ListBatchJobsResponse',
  full_name='gateway.ListBatchJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_jobs', full_name='gateway.ListBatchJobsResponse.batch_jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListBatchJobsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListBatchJobsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1433,
  serialized_end=1540,
)


_DELETEBATCHJOBREQUEST = _descriptor.Descriptor(
  name='DeleteBatchJobRequest',
  full_name='gateway.DeleteBatchJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteBatchJobRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1542,
  serialized_end=1584,
)


_BATCHDELETEBATCHJOBSREQUEST = _descriptor.Descriptor(
  name='BatchDeleteBatchJobsRequest',
  full_name='gateway.BatchDeleteBatchJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.BatchDeleteBatchJobsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='gateway.BatchDeleteBatchJobsRequest.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1586,
  serialized_end=1656,
)


_CANCELBATCHJOBREQUEST = _descriptor.Descriptor(
  name='CancelBatchJobRequest',
  full_name='gateway.CancelBatchJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.CancelBatchJobRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1658,
  serialized_end=1700,
)


_GETBATCHJOBLOGSREQUEST = _descriptor.Descriptor(
  name='GetBatchJobLogsRequest',
  full_name='gateway.GetBatchJobLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetBatchJobLogsRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ranks', full_name='gateway.GetBatchJobLogsRequest.ranks', index=1,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.GetBatchJobLogsRequest.page_size', index=2,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.GetBatchJobLogsRequest.page_token', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='gateway.GetBatchJobLogsRequest.start_time', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.GetBatchJobLogsRequest.filter', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_from_head', full_name='gateway.GetBatchJobLogsRequest.start_from_head', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1703,
  serialized_end=1914,
)


_GETBATCHJOBLOGSRESPONSE = _descriptor.Descriptor(
  name='GetBatchJobLogsResponse',
  full_name='gateway.GetBatchJobLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='gateway.GetBatchJobLogsResponse.entries', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.GetBatchJobLogsResponse.next_page_token', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1916,
  serialized_end=2002,
)


_PYTHONEXECUTOR = _descriptor.Descriptor(
  name='PythonExecutor',
  full_name='gateway.PythonExecutor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_type', full_name='gateway.PythonExecutor.target_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='gateway.PythonExecutor.target', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='gateway.PythonExecutor.args', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PYTHONEXECUTOR_TARGETTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2005,
  serialized_end=2192,
)


_SHELLEXECUTOR = _descriptor.Descriptor(
  name='ShellExecutor',
  full_name='gateway.ShellExecutor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='gateway.ShellExecutor.command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2194,
  serialized_end=2231,
)


_NOTEBOOKEXECUTOR = _descriptor.Descriptor(
  name='NotebookExecutor',
  full_name='gateway.NotebookExecutor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='notebook_filename', full_name='gateway.NotebookExecutor.notebook_filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2233,
  serialized_end=2283,
)


_LOGENTRY = _descriptor.Descriptor(
  name='LogEntry',
  full_name='gateway.LogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_time', full_name='gateway.LogEntry.log_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rank', full_name='gateway.LogEntry.rank', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='gateway.LogEntry.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2285,
  serialized_end=2372,
)

_BATCHJOB_ENVVARSENTRY.containing_type = _BATCHJOB
_BATCHJOB_ANNOTATIONSENTRY.containing_type = _BATCHJOB
_BATCHJOB.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BATCHJOB.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BATCHJOB.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BATCHJOB.fields_by_name['env_vars'].message_type = _BATCHJOB_ENVVARSENTRY
_BATCHJOB.fields_by_name['python_executor'].message_type = _PYTHONEXECUTOR
_BATCHJOB.fields_by_name['notebook_executor'].message_type = _NOTEBOOKEXECUTOR
_BATCHJOB.fields_by_name['shell_executor'].message_type = _SHELLEXECUTOR
_BATCHJOB.fields_by_name['annotations'].message_type = _BATCHJOB_ANNOTATIONSENTRY
_BATCHJOB.fields_by_name['state'].enum_type = _BATCHJOB_STATE
_BATCHJOB_STATE.containing_type = _BATCHJOB
_BATCHJOB.oneofs_by_name['executor'].fields.append(
  _BATCHJOB.fields_by_name['python_executor'])
_BATCHJOB.fields_by_name['python_executor'].containing_oneof = _BATCHJOB.oneofs_by_name['executor']
_BATCHJOB.oneofs_by_name['executor'].fields.append(
  _BATCHJOB.fields_by_name['notebook_executor'])
_BATCHJOB.fields_by_name['notebook_executor'].containing_oneof = _BATCHJOB.oneofs_by_name['executor']
_BATCHJOB.oneofs_by_name['executor'].fields.append(
  _BATCHJOB.fields_by_name['shell_executor'])
_BATCHJOB.fields_by_name['shell_executor'].containing_oneof = _BATCHJOB.oneofs_by_name['executor']
_CREATEBATCHJOBREQUEST.fields_by_name['batch_job'].message_type = _BATCHJOB
_LISTBATCHJOBSRESPONSE.fields_by_name['batch_jobs'].message_type = _BATCHJOB
_GETBATCHJOBLOGSREQUEST.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETBATCHJOBLOGSRESPONSE.fields_by_name['entries'].message_type = _LOGENTRY
_PYTHONEXECUTOR.fields_by_name['target_type'].enum_type = _PYTHONEXECUTOR_TARGETTYPE
_PYTHONEXECUTOR_TARGETTYPE.containing_type = _PYTHONEXECUTOR
_LOGENTRY.fields_by_name['log_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['BatchJob'] = _BATCHJOB
DESCRIPTOR.message_types_by_name['CreateBatchJobRequest'] = _CREATEBATCHJOBREQUEST
DESCRIPTOR.message_types_by_name['GetBatchJobRequest'] = _GETBATCHJOBREQUEST
DESCRIPTOR.message_types_by_name['ListBatchJobsRequest'] = _LISTBATCHJOBSREQUEST
DESCRIPTOR.message_types_by_name['ListBatchJobsResponse'] = _LISTBATCHJOBSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteBatchJobRequest'] = _DELETEBATCHJOBREQUEST
DESCRIPTOR.message_types_by_name['BatchDeleteBatchJobsRequest'] = _BATCHDELETEBATCHJOBSREQUEST
DESCRIPTOR.message_types_by_name['CancelBatchJobRequest'] = _CANCELBATCHJOBREQUEST
DESCRIPTOR.message_types_by_name['GetBatchJobLogsRequest'] = _GETBATCHJOBLOGSREQUEST
DESCRIPTOR.message_types_by_name['GetBatchJobLogsResponse'] = _GETBATCHJOBLOGSRESPONSE
DESCRIPTOR.message_types_by_name['PythonExecutor'] = _PYTHONEXECUTOR
DESCRIPTOR.message_types_by_name['ShellExecutor'] = _SHELLEXECUTOR
DESCRIPTOR.message_types_by_name['NotebookExecutor'] = _NOTEBOOKEXECUTOR
DESCRIPTOR.message_types_by_name['LogEntry'] = _LOGENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BatchJob = _reflection.GeneratedProtocolMessageType('BatchJob', (_message.Message,), {

  'EnvVarsEntry' : _reflection.GeneratedProtocolMessageType('EnvVarsEntry', (_message.Message,), {
    'DESCRIPTOR' : _BATCHJOB_ENVVARSENTRY,
    '__module__' : 'gateway.batch_job_pb2'
    # @@protoc_insertion_point(class_scope:gateway.BatchJob.EnvVarsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _BATCHJOB_ANNOTATIONSENTRY,
    '__module__' : 'gateway.batch_job_pb2'
    # @@protoc_insertion_point(class_scope:gateway.BatchJob.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _BATCHJOB,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.BatchJob)
  })
_sym_db.RegisterMessage(BatchJob)
_sym_db.RegisterMessage(BatchJob.EnvVarsEntry)
_sym_db.RegisterMessage(BatchJob.AnnotationsEntry)

CreateBatchJobRequest = _reflection.GeneratedProtocolMessageType('CreateBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBATCHJOBREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateBatchJobRequest)
  })
_sym_db.RegisterMessage(CreateBatchJobRequest)

GetBatchJobRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetBatchJobRequest)
  })
_sym_db.RegisterMessage(GetBatchJobRequest)

ListBatchJobsRequest = _reflection.GeneratedProtocolMessageType('ListBatchJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHJOBSREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListBatchJobsRequest)
  })
_sym_db.RegisterMessage(ListBatchJobsRequest)

ListBatchJobsResponse = _reflection.GeneratedProtocolMessageType('ListBatchJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHJOBSRESPONSE,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListBatchJobsResponse)
  })
_sym_db.RegisterMessage(ListBatchJobsResponse)

DeleteBatchJobRequest = _reflection.GeneratedProtocolMessageType('DeleteBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBATCHJOBREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteBatchJobRequest)
  })
_sym_db.RegisterMessage(DeleteBatchJobRequest)

BatchDeleteBatchJobsRequest = _reflection.GeneratedProtocolMessageType('BatchDeleteBatchJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHDELETEBATCHJOBSREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.BatchDeleteBatchJobsRequest)
  })
_sym_db.RegisterMessage(BatchDeleteBatchJobsRequest)

CancelBatchJobRequest = _reflection.GeneratedProtocolMessageType('CancelBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELBATCHJOBREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CancelBatchJobRequest)
  })
_sym_db.RegisterMessage(CancelBatchJobRequest)

GetBatchJobLogsRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBLOGSREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetBatchJobLogsRequest)
  })
_sym_db.RegisterMessage(GetBatchJobLogsRequest)

GetBatchJobLogsResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBLOGSRESPONSE,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetBatchJobLogsResponse)
  })
_sym_db.RegisterMessage(GetBatchJobLogsResponse)

PythonExecutor = _reflection.GeneratedProtocolMessageType('PythonExecutor', (_message.Message,), {
  'DESCRIPTOR' : _PYTHONEXECUTOR,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.PythonExecutor)
  })
_sym_db.RegisterMessage(PythonExecutor)

ShellExecutor = _reflection.GeneratedProtocolMessageType('ShellExecutor', (_message.Message,), {
  'DESCRIPTOR' : _SHELLEXECUTOR,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ShellExecutor)
  })
_sym_db.RegisterMessage(ShellExecutor)

NotebookExecutor = _reflection.GeneratedProtocolMessageType('NotebookExecutor', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKEXECUTOR,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.NotebookExecutor)
  })
_sym_db.RegisterMessage(NotebookExecutor)

LogEntry = _reflection.GeneratedProtocolMessageType('LogEntry', (_message.Message,), {
  'DESCRIPTOR' : _LOGENTRY,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.LogEntry)
  })
_sym_db.RegisterMessage(LogEntry)


DESCRIPTOR._options = None
_BATCHJOB_ENVVARSENTRY._options = None
_BATCHJOB_ANNOTATIONSENTRY._options = None
_BATCHJOB.fields_by_name['name']._options = None
_BATCHJOB.fields_by_name['display_name']._options = None
_BATCHJOB.fields_by_name['create_time']._options = None
_BATCHJOB.fields_by_name['start_time']._options = None
_BATCHJOB.fields_by_name['end_time']._options = None
_BATCHJOB.fields_by_name['created_by']._options = None
_BATCHJOB.fields_by_name['node_pool_id']._options = None
_BATCHJOB.fields_by_name['environment_id']._options = None
_BATCHJOB.fields_by_name['snapshot_id']._options = None
_BATCHJOB.fields_by_name['num_ranks']._options = None
_BATCHJOB.fields_by_name['env_vars']._options = None
_BATCHJOB.fields_by_name['role']._options = None
_BATCHJOB.fields_by_name['image_ref']._options = None
_BATCHJOB.fields_by_name['annotations']._options = None
_BATCHJOB.fields_by_name['state']._options = None
_BATCHJOB.fields_by_name['status']._options = None
_CREATEBATCHJOBREQUEST.fields_by_name['parent']._options = None
_CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._options = None
_GETBATCHJOBREQUEST.fields_by_name['name']._options = None
_LISTBATCHJOBSREQUEST.fields_by_name['parent']._options = None
_LISTBATCHJOBSREQUEST.fields_by_name['page_size']._options = None
_LISTBATCHJOBSREQUEST.fields_by_name['page_token']._options = None
_LISTBATCHJOBSREQUEST.fields_by_name['filter']._options = None
_LISTBATCHJOBSREQUEST.fields_by_name['order_by']._options = None
_DELETEBATCHJOBREQUEST.fields_by_name['name']._options = None
_BATCHDELETEBATCHJOBSREQUEST.fields_by_name['parent']._options = None
_BATCHDELETEBATCHJOBSREQUEST.fields_by_name['names']._options = None
_CANCELBATCHJOBREQUEST.fields_by_name['name']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['name']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['page_size']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['page_token']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['start_time']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['filter']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['start_from_head']._options = None
_PYTHONEXECUTOR.fields_by_name['target_type']._options = None
_PYTHONEXECUTOR.fields_by_name['target']._options = None
_PYTHONEXECUTOR.fields_by_name['args']._options = None
_SHELLEXECUTOR.fields_by_name['command']._options = None
_NOTEBOOKEXECUTOR.fields_by_name['notebook_filename']._options = None
# @@protoc_insertion_point(module_scope)
