# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/audit_log.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/audit_log.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/audit_log.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdb\x01\n\rAuditLogEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x11\n\tprincipal\x18\x03 \x01(\t\x12(\n\x07payload\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1f\n\x06status\x18\x05 \x01(\x0b\x32\x0f.gateway.Status\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x07 \x01(\t\x12\x10\n\x08resource\x18\x08 \x01(\t\"\x86\x02\n\x14ListAuditLogsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x34\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\x32\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\r\n\x05\x65mail\x18\x08 \x01(\t\x12\x17\n\tpage_size\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01\"p\n\x15ListAuditLogsResponse\x12*\n\naudit_logs\x18\x01 \x03(\x0b\x32\x16.gateway.AuditLogEntry\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.audit_log_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['start_time']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['start_time']._serialized_options = b'\342A\001\001'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['end_time']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['end_time']._serialized_options = b'\342A\001\001'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_AUDITLOGENTRY']._serialized_start=155
  _globals['_AUDITLOGENTRY']._serialized_end=374
  _globals['_LISTAUDITLOGSREQUEST']._serialized_start=377
  _globals['_LISTAUDITLOGSREQUEST']._serialized_end=639
  _globals['_LISTAUDITLOGSRESPONSE']._serialized_start=641
  _globals['_LISTAUDITLOGSRESPONSE']._serialized_end=753
# @@protoc_insertion_point(module_scope)
