# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/dataset.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/dataset.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/dataset.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xab\x08\n\x07\x44\x61taset\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12,\n\x05state\x18\x04 \x01(\x0e\x32\x16.gateway.Dataset.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x1b\n\rexample_count\x18\x07 \x01(\x03\x42\x04\xe2\x41\x01\x01\x12P\n\raccess_policy\x18\t \x01(\x0e\x32\x1d.gateway.Dataset.AccessPolicyB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12.\n\ruser_uploaded\x18\x0b \x01(\x0b\x32\x15.gateway.UserUploadedH\x00\x12\x36\n\x11\x65valuation_result\x18\x0f \x01(\x0b\x32\x19.gateway.EvaluationResultH\x00\x12L\n\x10\x66ireworks_traced\x18\x0c \x01(\x0b\x32\x18.gateway.FireworksTracedB\x16\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLYH\x00\x12O\n\x12\x64raft_model_states\x18\r \x01(\x0b\x32\x19.gateway.DraftModelStatesB\x16\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLYH\x00\x12+\n\x0btransformed\x18\x12 \x01(\x0b\x32\x14.gateway.TransformedH\x00\x12\x1a\n\x0c\x65xternal_url\x18\x10 \x01(\tB\x04\xe2\x41\x01\x01\x12.\n\x06\x66ormat\x18\n \x01(\x0e\x32\x17.gateway.Dataset.FormatB\x05\xe2\x41\x02\x01\x05\x12\x19\n\ncreated_by\x18\x0e \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\"8\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\r\n\tUPLOADING\x10\x01\x12\t\n\x05READY\x10\x02\"\'\n\x0c\x41\x63\x63\x65ssPolicy\x12\x0b\n\x07PRIVATE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\"B\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x08\n\x04\x43HAT\x10\x01\x12\x0e\n\nCOMPLETION\x10\x02\x12\x06\n\x02RL\x10\x03:j\xea\x41X\n\x18\x61pi.fireworks.ai/Dataset\x12)accounts/{AccountId}/datasets/{DatasetId}*\x08\x64\x61tasets2\x07\x64\x61taset\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\x42\r\n\x0b\x64\x61ta_source\"\x8c\x01\n\x15PreviewDatasetRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"j\n\x16PreviewDatasetResponse\x12\"\n\x08\x65xamples\x18\x01 \x03(\x0b\x32\x10.gateway.Example\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x13\n\x0btotal_count\x18\x03 \x01(\x05\"\x1a\n\x07\x45xample\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"\x0e\n\x0cUserUploaded\"|\n\x0bTransformed\x12\x1f\n\x11source_dataset_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x14\n\x06\x66ilter\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0foriginal_format\x18\x03 \x01(\x0e\x32\x17.gateway.Dataset.FormatB\x04\xe2\x41\x01\x01\"\xae\x01\n\x0f\x46ireworksTraced\x12\x14\n\x05model\x18\x01 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x19\n\nbase_model\x18\x02 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x35\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x02\x05\x12\x33\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x02\x05\"-\n\x10\x44raftModelStates\x12\x19\n\nbase_model\x18\x01 \x01(\tB\x05\xe2\x41\x02\x02\x05\"3\n\x10\x45valuationResult\x12\x1f\n\x11\x65valuation_job_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\'\n\x11GetDatasetRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xa6\x01\n\x14\x43reateDatasetRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\'\n\x07\x64\x61taset\x18\x02 \x01(\x0b\x32\x10.gateway.DatasetB\x04\xe2\x41\x01\x02\x12\x18\n\ndataset_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1f\n\x11source_dataset_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"v\n\x14UpdateDatasetRequest\x12\'\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x10.gateway.DatasetB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"\xb4\x01\n\x14UploadDatasetRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12Q\n\x10\x66ilename_to_size\x18\x02 \x03(\x0b\x32\x31.gateway.UploadDatasetRequest.FilenameToSizeEntryB\x04\xe2\x41\x01\x02\x1a\x35\n\x13\x46ilenameToSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xaf\x01\n\x15UploadDatasetResponse\x12Y\n\x17\x66ilename_to_signed_urls\x18\x01 \x03(\x0b\x32\x38.gateway.UploadDatasetResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xca\x01\n\x1fGetDatasetUploadEndpointRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\\\n\x10\x66ilename_to_size\x18\x02 \x03(\x0b\x32<.gateway.GetDatasetUploadEndpointRequest.FilenameToSizeEntryB\x04\xe2\x41\x01\x02\x1a\x35\n\x13\x46ilenameToSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xc5\x01\n GetDatasetUploadEndpointResponse\x12\x64\n\x17\x66ilename_to_signed_urls\x18\x01 \x03(\x0b\x32\x43.gateway.GetDatasetUploadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x1cValidateDatasetUploadRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"7\n!GetDatasetDownloadEndpointRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xc9\x01\n\"GetDatasetDownloadEndpointResponse\x12\x66\n\x17\x66ilename_to_signed_urls\x18\x01 \x03(\x0b\x32\x45.gateway.GetDatasetDownloadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x13ListDatasetsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"g\n\x14ListDatasetsResponse\x12\"\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32\x10.gateway.Dataset\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"*\n\x14\x44\x65leteDatasetRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.dataset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_DATASET'].fields_by_name['name']._loaded_options = None
  _globals['_DATASET'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASET'].fields_by_name['display_name']._loaded_options = None
  _globals['_DATASET'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_DATASET'].fields_by_name['create_time']._loaded_options = None
  _globals['_DATASET'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASET'].fields_by_name['state']._loaded_options = None
  _globals['_DATASET'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASET'].fields_by_name['status']._loaded_options = None
  _globals['_DATASET'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASET'].fields_by_name['example_count']._loaded_options = None
  _globals['_DATASET'].fields_by_name['example_count']._serialized_options = b'\342A\001\001'
  _globals['_DATASET'].fields_by_name['access_policy']._loaded_options = None
  _globals['_DATASET'].fields_by_name['access_policy']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DATASET'].fields_by_name['fireworks_traced']._loaded_options = None
  _globals['_DATASET'].fields_by_name['fireworks_traced']._serialized_options = b'\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DATASET'].fields_by_name['draft_model_states']._loaded_options = None
  _globals['_DATASET'].fields_by_name['draft_model_states']._serialized_options = b'\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DATASET'].fields_by_name['external_url']._loaded_options = None
  _globals['_DATASET'].fields_by_name['external_url']._serialized_options = b'\342A\001\001'
  _globals['_DATASET'].fields_by_name['format']._loaded_options = None
  _globals['_DATASET'].fields_by_name['format']._serialized_options = b'\342A\002\001\005'
  _globals['_DATASET'].fields_by_name['created_by']._loaded_options = None
  _globals['_DATASET'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASET'].fields_by_name['update_time']._loaded_options = None
  _globals['_DATASET'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_DATASET']._loaded_options = None
  _globals['_DATASET']._serialized_options = b'\352AX\n\030api.fireworks.ai/Dataset\022)accounts/{AccountId}/datasets/{DatasetId}*\010datasets2\007dataset\202\361\004\013\n\007Account\030\001'
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_TRANSFORMED'].fields_by_name['source_dataset_id']._loaded_options = None
  _globals['_TRANSFORMED'].fields_by_name['source_dataset_id']._serialized_options = b'\342A\001\002'
  _globals['_TRANSFORMED'].fields_by_name['filter']._loaded_options = None
  _globals['_TRANSFORMED'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_TRANSFORMED'].fields_by_name['original_format']._loaded_options = None
  _globals['_TRANSFORMED'].fields_by_name['original_format']._serialized_options = b'\342A\001\001'
  _globals['_FIREWORKSTRACED'].fields_by_name['model']._loaded_options = None
  _globals['_FIREWORKSTRACED'].fields_by_name['model']._serialized_options = b'\342A\002\002\005'
  _globals['_FIREWORKSTRACED'].fields_by_name['base_model']._loaded_options = None
  _globals['_FIREWORKSTRACED'].fields_by_name['base_model']._serialized_options = b'\342A\002\002\005'
  _globals['_FIREWORKSTRACED'].fields_by_name['start_time']._loaded_options = None
  _globals['_FIREWORKSTRACED'].fields_by_name['start_time']._serialized_options = b'\342A\002\002\005'
  _globals['_FIREWORKSTRACED'].fields_by_name['end_time']._loaded_options = None
  _globals['_FIREWORKSTRACED'].fields_by_name['end_time']._serialized_options = b'\342A\002\002\005'
  _globals['_DRAFTMODELSTATES'].fields_by_name['base_model']._loaded_options = None
  _globals['_DRAFTMODELSTATES'].fields_by_name['base_model']._serialized_options = b'\342A\002\002\005'
  _globals['_EVALUATIONRESULT'].fields_by_name['evaluation_job_id']._loaded_options = None
  _globals['_EVALUATIONRESULT'].fields_by_name['evaluation_job_id']._serialized_options = b'\342A\001\002'
  _globals['_GETDATASETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDATASETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['dataset']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['dataset']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['source_dataset_id']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['source_dataset_id']._serialized_options = b'\342A\001\001'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['dataset']._loaded_options = None
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['dataset']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPLOADDATASETREQUEST_FILENAMETOSIZEENTRY']._loaded_options = None
  _globals['_UPLOADDATASETREQUEST_FILENAMETOSIZEENTRY']._serialized_options = b'8\001'
  _globals['_UPLOADDATASETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPLOADDATASETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_UPLOADDATASETREQUEST'].fields_by_name['filename_to_size']._loaded_options = None
  _globals['_UPLOADDATASETREQUEST'].fields_by_name['filename_to_size']._serialized_options = b'\342A\001\002'
  _globals['_UPLOADDATASETRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_UPLOADDATASETRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_GETDATASETUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._loaded_options = None
  _globals['_GETDATASETUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_options = b'8\001'
  _globals['_GETDATASETUPLOADENDPOINTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDATASETUPLOADENDPOINTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETDATASETUPLOADENDPOINTREQUEST'].fields_by_name['filename_to_size']._loaded_options = None
  _globals['_GETDATASETUPLOADENDPOINTREQUEST'].fields_by_name['filename_to_size']._serialized_options = b'\342A\001\002'
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_VALIDATEDATASETUPLOADREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_VALIDATEDATASETUPLOADREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETDATASETDOWNLOADENDPOINTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDATASETDOWNLOADENDPOINTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETEDATASETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEDATASETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DATASET']._serialized_start=236
  _globals['_DATASET']._serialized_end=1303
  _globals['_DATASET_STATE']._serialized_start=1015
  _globals['_DATASET_STATE']._serialized_end=1071
  _globals['_DATASET_ACCESSPOLICY']._serialized_start=1073
  _globals['_DATASET_ACCESSPOLICY']._serialized_end=1112
  _globals['_DATASET_FORMAT']._serialized_start=1114
  _globals['_DATASET_FORMAT']._serialized_end=1180
  _globals['_PREVIEWDATASETREQUEST']._serialized_start=1306
  _globals['_PREVIEWDATASETREQUEST']._serialized_end=1446
  _globals['_PREVIEWDATASETRESPONSE']._serialized_start=1448
  _globals['_PREVIEWDATASETRESPONSE']._serialized_end=1554
  _globals['_EXAMPLE']._serialized_start=1556
  _globals['_EXAMPLE']._serialized_end=1582
  _globals['_USERUPLOADED']._serialized_start=1584
  _globals['_USERUPLOADED']._serialized_end=1598
  _globals['_TRANSFORMED']._serialized_start=1600
  _globals['_TRANSFORMED']._serialized_end=1724
  _globals['_FIREWORKSTRACED']._serialized_start=1727
  _globals['_FIREWORKSTRACED']._serialized_end=1901
  _globals['_DRAFTMODELSTATES']._serialized_start=1903
  _globals['_DRAFTMODELSTATES']._serialized_end=1948
  _globals['_EVALUATIONRESULT']._serialized_start=1950
  _globals['_EVALUATIONRESULT']._serialized_end=2001
  _globals['_GETDATASETREQUEST']._serialized_start=2003
  _globals['_GETDATASETREQUEST']._serialized_end=2042
  _globals['_CREATEDATASETREQUEST']._serialized_start=2045
  _globals['_CREATEDATASETREQUEST']._serialized_end=2211
  _globals['_UPDATEDATASETREQUEST']._serialized_start=2213
  _globals['_UPDATEDATASETREQUEST']._serialized_end=2331
  _globals['_UPLOADDATASETREQUEST']._serialized_start=2334
  _globals['_UPLOADDATASETREQUEST']._serialized_end=2514
  _globals['_UPLOADDATASETREQUEST_FILENAMETOSIZEENTRY']._serialized_start=2461
  _globals['_UPLOADDATASETREQUEST_FILENAMETOSIZEENTRY']._serialized_end=2514
  _globals['_UPLOADDATASETRESPONSE']._serialized_start=2517
  _globals['_UPLOADDATASETRESPONSE']._serialized_end=2692
  _globals['_UPLOADDATASETRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=2633
  _globals['_UPLOADDATASETRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=2692
  _globals['_GETDATASETUPLOADENDPOINTREQUEST']._serialized_start=2695
  _globals['_GETDATASETUPLOADENDPOINTREQUEST']._serialized_end=2897
  _globals['_GETDATASETUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_start=2461
  _globals['_GETDATASETUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_end=2514
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE']._serialized_start=2900
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE']._serialized_end=3097
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=2633
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=2692
  _globals['_VALIDATEDATASETUPLOADREQUEST']._serialized_start=3099
  _globals['_VALIDATEDATASETUPLOADREQUEST']._serialized_end=3149
  _globals['_GETDATASETDOWNLOADENDPOINTREQUEST']._serialized_start=3151
  _globals['_GETDATASETDOWNLOADENDPOINTREQUEST']._serialized_end=3206
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE']._serialized_start=3209
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE']._serialized_end=3410
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=2633
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=2692
  _globals['_LISTDATASETSREQUEST']._serialized_start=3413
  _globals['_LISTDATASETSREQUEST']._serialized_end=3553
  _globals['_LISTDATASETSRESPONSE']._serialized_start=3555
  _globals['_LISTDATASETSRESPONSE']._serialized_end=3658
  _globals['_DELETEDATASETREQUEST']._serialized_start=3660
  _globals['_DELETEDATASETREQUEST']._serialized_end=3702
# @@protoc_insertion_point(module_scope)
