# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/aws_iam_role_binding.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/aws_iam_role_binding.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"gateway/aws_iam_role_binding.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x93\x01\n\x11\x41wsIamRoleBinding\x12\x1a\n\naccount_id\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x37\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x16\n\tprincipal\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04role\x18\x04 \x01(\tB\x03\xe0\x41\x02\"t\n\x1e\x43reateAwsIamRoleBindingRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12=\n\x14\x61ws_iam_role_binding\x18\x02 \x01(\x0b\x32\x1a.gateway.AwsIamRoleBindingB\x03\xe0\x41\x02\"\x91\x01\n\x1dListAwsIamRoleBindingsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"\x88\x01\n\x1eListAwsIamRoleBindingsResponse\x12\x39\n\x15\x61ws_iam_role_bindings\x18\x01 \x03(\x0b\x32\x1a.gateway.AwsIamRoleBinding\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"_\n\x1e\x44\x65leteAwsIamRoleBindingRequest\x12=\n\x14\x61ws_iam_role_binding\x18\x02 \x01(\x0b\x32\x1a.gateway.AwsIamRoleBindingB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_AWSIAMROLEBINDING = _descriptor.Descriptor(
  name='AwsIamRoleBinding',
  full_name='gateway.AwsIamRoleBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='gateway.AwsIamRoleBinding.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.AwsIamRoleBinding.create_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='principal', full_name='gateway.AwsIamRoleBinding.principal', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='gateway.AwsIamRoleBinding.role', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=261,
)


_CREATEAWSIAMROLEBINDINGREQUEST = _descriptor.Descriptor(
  name='CreateAwsIamRoleBindingRequest',
  full_name='gateway.CreateAwsIamRoleBindingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateAwsIamRoleBindingRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws_iam_role_binding', full_name='gateway.CreateAwsIamRoleBindingRequest.aws_iam_role_binding', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=379,
)


_LISTAWSIAMROLEBINDINGSREQUEST = _descriptor.Descriptor(
  name='ListAwsIamRoleBindingsRequest',
  full_name='gateway.ListAwsIamRoleBindingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListAwsIamRoleBindingsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListAwsIamRoleBindingsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListAwsIamRoleBindingsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListAwsIamRoleBindingsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListAwsIamRoleBindingsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=527,
)


_LISTAWSIAMROLEBINDINGSRESPONSE = _descriptor.Descriptor(
  name='ListAwsIamRoleBindingsResponse',
  full_name='gateway.ListAwsIamRoleBindingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws_iam_role_bindings', full_name='gateway.ListAwsIamRoleBindingsResponse.aws_iam_role_bindings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListAwsIamRoleBindingsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListAwsIamRoleBindingsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=666,
)


_DELETEAWSIAMROLEBINDINGREQUEST = _descriptor.Descriptor(
  name='DeleteAwsIamRoleBindingRequest',
  full_name='gateway.DeleteAwsIamRoleBindingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws_iam_role_binding', full_name='gateway.DeleteAwsIamRoleBindingRequest.aws_iam_role_binding', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=668,
  serialized_end=763,
)

_AWSIAMROLEBINDING.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding'].message_type = _AWSIAMROLEBINDING
_LISTAWSIAMROLEBINDINGSRESPONSE.fields_by_name['aws_iam_role_bindings'].message_type = _AWSIAMROLEBINDING
_DELETEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding'].message_type = _AWSIAMROLEBINDING
DESCRIPTOR.message_types_by_name['AwsIamRoleBinding'] = _AWSIAMROLEBINDING
DESCRIPTOR.message_types_by_name['CreateAwsIamRoleBindingRequest'] = _CREATEAWSIAMROLEBINDINGREQUEST
DESCRIPTOR.message_types_by_name['ListAwsIamRoleBindingsRequest'] = _LISTAWSIAMROLEBINDINGSREQUEST
DESCRIPTOR.message_types_by_name['ListAwsIamRoleBindingsResponse'] = _LISTAWSIAMROLEBINDINGSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAwsIamRoleBindingRequest'] = _DELETEAWSIAMROLEBINDINGREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AwsIamRoleBinding = _reflection.GeneratedProtocolMessageType('AwsIamRoleBinding', (_message.Message,), {
  'DESCRIPTOR' : _AWSIAMROLEBINDING,
  '__module__' : 'gateway.aws_iam_role_binding_pb2'
  # @@protoc_insertion_point(class_scope:gateway.AwsIamRoleBinding)
  })
_sym_db.RegisterMessage(AwsIamRoleBinding)

CreateAwsIamRoleBindingRequest = _reflection.GeneratedProtocolMessageType('CreateAwsIamRoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAWSIAMROLEBINDINGREQUEST,
  '__module__' : 'gateway.aws_iam_role_binding_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateAwsIamRoleBindingRequest)
  })
_sym_db.RegisterMessage(CreateAwsIamRoleBindingRequest)

ListAwsIamRoleBindingsRequest = _reflection.GeneratedProtocolMessageType('ListAwsIamRoleBindingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAWSIAMROLEBINDINGSREQUEST,
  '__module__' : 'gateway.aws_iam_role_binding_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListAwsIamRoleBindingsRequest)
  })
_sym_db.RegisterMessage(ListAwsIamRoleBindingsRequest)

ListAwsIamRoleBindingsResponse = _reflection.GeneratedProtocolMessageType('ListAwsIamRoleBindingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAWSIAMROLEBINDINGSRESPONSE,
  '__module__' : 'gateway.aws_iam_role_binding_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListAwsIamRoleBindingsResponse)
  })
_sym_db.RegisterMessage(ListAwsIamRoleBindingsResponse)

DeleteAwsIamRoleBindingRequest = _reflection.GeneratedProtocolMessageType('DeleteAwsIamRoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAWSIAMROLEBINDINGREQUEST,
  '__module__' : 'gateway.aws_iam_role_binding_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteAwsIamRoleBindingRequest)
  })
_sym_db.RegisterMessage(DeleteAwsIamRoleBindingRequest)


DESCRIPTOR._options = None
_AWSIAMROLEBINDING.fields_by_name['account_id']._options = None
_AWSIAMROLEBINDING.fields_by_name['create_time']._options = None
_AWSIAMROLEBINDING.fields_by_name['principal']._options = None
_AWSIAMROLEBINDING.fields_by_name['role']._options = None
_CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['parent']._options = None
_CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._options = None
_LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['parent']._options = None
_LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_size']._options = None
_LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_token']._options = None
_LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['filter']._options = None
_LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['order_by']._options = None
_DELETEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._options = None
# @@protoc_insertion_point(module_scope)
