# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/prompt_tuning_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/prompt_tuning_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgateway/prompt_tuning_job.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa5\x05\n\x0fPromptTuningJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x04 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\'\n\x05state\x18\x05 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x19\n\nmodel_name\x18\x07 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x19\n\ndataset_id\x18\x08 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x1b\n\x0cinput_prompt\x18\t \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x1b\n\routput_prompt\x18\n \x01(\tB\x04\xe2\x41\x01\x03\x12H\n\x11prompt_to_metrics\x18\x0b \x03(\x0b\x32-.gateway.PromptTuningJob.PromptToMetricsEntry\x12\x35\n\x0bupdate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a\x36\n\x14PromptToMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01:\x93\x01\xea\x41\x80\x01\n api.fireworks.ai/PromptTuningJob\x12\x39\x61\x63\x63ounts/{AccountId}/promptTuningJobs/{PromptTuningJobId}*\x10PromptTuningJobs2\x0fPromptTuningJob\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"/\n\x19GetPromptTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"o\n\x1c\x43reatePromptTuningJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x39\n\x11prompt_tuning_job\x18\x02 \x01(\x0b\x32\x18.gateway.PromptTuningJobB\x04\xe2\x41\x01\x02\"\x94\x01\n\x1bListPromptTuningJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\x81\x01\n\x1cListPromptTuningJobsResponse\x12\x34\n\x12prompt_tuning_jobs\x18\x01 \x03(\x0b\x32\x18.gateway.PromptTuningJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"2\n\x1c\x44\x65letePromptTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.prompt_tuning_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_PROMPTTUNINGJOB_PROMPTTOMETRICSENTRY']._loaded_options = None
  _globals['_PROMPTTUNINGJOB_PROMPTTOMETRICSENTRY']._serialized_options = b'8\001'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['name']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['state']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['status']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['model_name']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['model_name']._serialized_options = b'\342A\002\002\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['dataset_id']._serialized_options = b'\342A\002\002\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['input_prompt']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['input_prompt']._serialized_options = b'\342A\002\002\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['output_prompt']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['output_prompt']._serialized_options = b'\342A\001\003'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_PROMPTTUNINGJOB']._loaded_options = None
  _globals['_PROMPTTUNINGJOB']._serialized_options = b'\352A\200\001\n api.fireworks.ai/PromptTuningJob\0229accounts/{AccountId}/promptTuningJobs/{PromptTuningJobId}*\020PromptTuningJobs2\017PromptTuningJob\202\361\004\013\n\007Account\030\001'
  _globals['_GETPROMPTTUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETPROMPTTUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEPROMPTTUNINGJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEPROMPTTUNINGJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEPROMPTTUNINGJOBREQUEST'].fields_by_name['prompt_tuning_job']._loaded_options = None
  _globals['_CREATEPROMPTTUNINGJOBREQUEST'].fields_by_name['prompt_tuning_job']._serialized_options = b'\342A\001\002'
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETEPROMPTTUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEPROMPTTUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PROMPTTUNINGJOB']._serialized_start=183
  _globals['_PROMPTTUNINGJOB']._serialized_end=860
  _globals['_PROMPTTUNINGJOB_PROMPTTOMETRICSENTRY']._serialized_start=656
  _globals['_PROMPTTUNINGJOB_PROMPTTOMETRICSENTRY']._serialized_end=710
  _globals['_GETPROMPTTUNINGJOBREQUEST']._serialized_start=862
  _globals['_GETPROMPTTUNINGJOBREQUEST']._serialized_end=909
  _globals['_CREATEPROMPTTUNINGJOBREQUEST']._serialized_start=911
  _globals['_CREATEPROMPTTUNINGJOBREQUEST']._serialized_end=1022
  _globals['_LISTPROMPTTUNINGJOBSREQUEST']._serialized_start=1025
  _globals['_LISTPROMPTTUNINGJOBSREQUEST']._serialized_end=1173
  _globals['_LISTPROMPTTUNINGJOBSRESPONSE']._serialized_start=1176
  _globals['_LISTPROMPTTUNINGJOBSRESPONSE']._serialized_end=1305
  _globals['_DELETEPROMPTTUNINGJOBREQUEST']._serialized_start=1307
  _globals['_DELETEPROMPTTUNINGJOBREQUEST']._serialized_end=1357
# @@protoc_insertion_point(module_scope)
