# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/abuse_rule.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/abuse_rule.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gateway/abuse_rule.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x05\n\tAbuseRule\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x37\n\x06target\x18\x02 \x01(\tB\'\xe2\x41\x02\x02\x05\xc2\xf1\x04\x1eidx_abuse_rule_target_and_type\x12N\n\x04type\x18\x03 \x01(\x0e\x32\x17.gateway.AbuseRule.TypeB\'\xe2\x41\x02\x02\x05\xc2\xf1\x04\x1eidx_abuse_rule_target_and_type\x12\x39\n\x0b\x64\x65signation\x18\x04 \x01(\x0e\x32\x1e.gateway.AbuseRule.DesignationB\x04\xe2\x41\x01\x02\x12\x36\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x0e\n\x06reason\x18\x07 \x01(\t\x12.\n\x05state\x18\x08 \x01(\x0e\x32\x18.gateway.AbuseRule.StateB\x05\xe2\x41\x02\x03\x05\"=\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x44OMAIN\x10\x01\x12\x06\n\x02IP\x10\x02\x12\x0b\n\x07\x41\x43\x43OUNT\x10\x03\"S\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"T\n\x0b\x44\x65signation\x12\x1b\n\x17\x44\x45SIGNATION_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x41LLOWED\x10\x01\x12\x0b\n\x07\x42LOCKED\x10\x02\x12\x0e\n\nSUSPICIOUS\x10\x03:Y\xea\x41P\n\x1a\x61pi.fireworks.ai/AbuseRule\x12\x19\x61\x62use_rules/{AbuseRuleId}*\x0b\x61\x62use_rules2\nabuse_rule\x82\xf1\x04\x02\x18\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.abuse_rule_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_ABUSERULE'].fields_by_name['name']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_ABUSERULE'].fields_by_name['target']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['target']._serialized_options = b'\342A\002\002\005\302\361\004\036idx_abuse_rule_target_and_type'
  _globals['_ABUSERULE'].fields_by_name['type']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['type']._serialized_options = b'\342A\002\002\005\302\361\004\036idx_abuse_rule_target_and_type'
  _globals['_ABUSERULE'].fields_by_name['designation']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['designation']._serialized_options = b'\342A\001\002'
  _globals['_ABUSERULE'].fields_by_name['create_time']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_ABUSERULE'].fields_by_name['update_time']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_ABUSERULE'].fields_by_name['state']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_ABUSERULE']._loaded_options = None
  _globals['_ABUSERULE']._serialized_options = b'\352AP\n\032api.fireworks.ai/AbuseRule\022\031abuse_rules/{AbuseRuleId}*\013abuse_rules2\nabuse_rule\202\361\004\002\030\001'
  _globals['_ABUSERULE']._serialized_start=154
  _globals['_ABUSERULE']._serialized_end=882
  _globals['_ABUSERULE_TYPE']._serialized_start=559
  _globals['_ABUSERULE_TYPE']._serialized_end=620
  _globals['_ABUSERULE_STATE']._serialized_start=622
  _globals['_ABUSERULE_STATE']._serialized_end=705
  _globals['_ABUSERULE_DESIGNATION']._serialized_start=707
  _globals['_ABUSERULE_DESIGNATION']._serialized_end=791
# @@protoc_insertion_point(module_scope)
