# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/billing.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/billing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..google.type import money_pb2 as google_dot_type_dot_money__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/billing.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/type/money.proto\"\'\n\x11GetBalanceRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\",\n\x07\x42\x61lance\x12!\n\x05money\x18\x01 \x01(\x0b\x32\x12.google.type.Money\"1\n\x19ListPaymentMethodsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xf7\x01\n\x15StripeCheckoutSession\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x63heckout_url\x18\x02 \x01(\t\x12\x31\n\x04mode\x18\x03 \x01(\x0e\x32#.gateway.StripeCheckoutSession.Mode\x12\"\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x12.google.type.Money\x12/\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"4\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PAYMENT\x10\x01\x12\t\n\x05SETUP\x10\x02\"\x9e\x04\n\x1aListPaymentMethodsResponse\x12!\n\x19\x64\x65\x66\x61ult_payment_method_id\x18\x01 \x01(\t\x12W\n\x16stripe_payment_methods\x18\x02 \x03(\x0b\x32\x37.gateway.ListPaymentMethodsResponse.StripePaymentMethod\x12R\n\x19pending_checkout_sessions\x18\x03 \x03(\x0b\x32\x1e.gateway.StripeCheckoutSessionB\x0f\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x1aI\n\x04\x43\x61rd\x12\r\n\x05\x62rand\x18\x01 \x01(\t\x12\r\n\x05last4\x18\x02 \x01(\t\x12\x11\n\texp_month\x18\x03 \x01(\x05\x12\x10\n\x08\x65xp_year\x18\x04 \x01(\x05\x1a\x31\n\rUsBankAccount\x12\x11\n\tbank_name\x18\x01 \x01(\t\x12\r\n\x05last4\x18\x02 \x01(\t\x1a\xb1\x01\n\x13StripePaymentMethod\x12\n\n\x02id\x18\x01 \x01(\t\x12\x38\n\x04\x63\x61rd\x18\x02 \x01(\x0b\x32(.gateway.ListPaymentMethodsResponse.CardH\x00\x12L\n\x0fus_bank_account\x18\x03 \x01(\x0b\x32\x31.gateway.ListPaymentMethodsResponse.UsBankAccountH\x00\x42\x06\n\x04type\"\xa6\x01\n\x10ListCostsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x34\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02\x12\x32\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02\x12\x12\n\ncumulative\x18\x04 \x01(\x08\"\x8d\x02\n\x11ListCostsResponse\x12@\n\x0f\x63ost_data_items\x18\x01 \x03(\x0b\x32\'.gateway.ListCostsResponse.CostDataItem\x1a\xb5\x01\n\x0c\x43ostDataItem\x12$\n\x08subtotal\x18\x01 \x01(\x0b\x32\x12.google.type.Money\x12!\n\x05total\x18\x02 \x01(\x0b\x32\x12.google.type.Money\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9d\x01\n\x13ListInvoicesRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x0f\n\x07pending\x18\x02 \x01(\x08\x12\x17\n\tpage_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01\"\xb0\x02\n\x07Invoice\x12\n\n\x02id\x18\x01 \x01(\t\x12&\n\namount_due\x18\x02 \x01(\x0b\x32\x12.google.type.Money\x12\x13\n\x0binvoice_url\x18\x03 \x01(\t\x12%\n\x05state\x18\x04 \x01(\x0e\x32\x16.gateway.Invoice.State\x12/\n\x0btarget_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tpaid_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"U\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\n\n\x06ISSUED\x10\x02\x12\x08\n\x04PAID\x10\x03\x12\x08\n\x04VOID\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\"g\n\x14ListInvoicesResponse\x12\"\n\x08invoices\x18\x01 \x03(\x0b\x32\x10.gateway.Invoice\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"H\n\x07SKUInfo\x12\x0b\n\x03sku\x18\x01 \x01(\t\x12\"\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x12.google.type.Money\x12\x0c\n\x04unit\x18\x03 \x01(\t\"\x9b\x01\n\x1b\x45xportBillingMetricsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x34\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\x32\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\"3\n\x1c\x45xportBillingMetricsResponse\x12\x13\n\x0bsigned_urls\x18\x01 \x03(\t\"4\n\x1eGetTotalHistoricalSpendRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"D\n\x1fGetTotalHistoricalSpendResponse\x12!\n\x05spend\x18\x01 \x01(\x0b\x32\x12.google.type.Money\"U\n\"ListHuggingFaceBillingCostsRecords\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0brequest_ids\x18\x02 \x03(\tB\x04\xe2\x41\x01\x02\"E\n\x18\x42illingRequestCostRecord\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x15\n\rcost_nano_usd\x18\x02 \x01(\x01\"Z\n#ListHuggingFaceBillingCostsResponse\x12\x33\n\x08requests\x18\x01 \x03(\x0b\x32!.gateway.BillingRequestCostRecordBCZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.billing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_GETBALANCEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETBALANCEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTPAYMENTMETHODSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTPAYMENTMETHODSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTPAYMENTMETHODSRESPONSE'].fields_by_name['pending_checkout_sessions']._loaded_options = None
  _globals['_LISTPAYMENTMETHODSRESPONSE'].fields_by_name['pending_checkout_sessions']._serialized_options = b'\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_LISTCOSTSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTCOSTSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTCOSTSREQUEST'].fields_by_name['start_time']._loaded_options = None
  _globals['_LISTCOSTSREQUEST'].fields_by_name['start_time']._serialized_options = b'\342A\001\002'
  _globals['_LISTCOSTSREQUEST'].fields_by_name['end_time']._loaded_options = None
  _globals['_LISTCOSTSREQUEST'].fields_by_name['end_time']._serialized_options = b'\342A\001\002'
  _globals['_LISTINVOICESREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTINVOICESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTINVOICESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTINVOICESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTINVOICESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTINVOICESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTINVOICESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTINVOICESREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTINVOICESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTINVOICESREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['start_time']._loaded_options = None
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['start_time']._serialized_options = b'\342A\001\001'
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['end_time']._loaded_options = None
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['end_time']._serialized_options = b'\342A\001\001'
  _globals['_GETTOTALHISTORICALSPENDREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETTOTALHISTORICALSPENDREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS'].fields_by_name['request_ids']._loaded_options = None
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS'].fields_by_name['request_ids']._serialized_options = b'\342A\001\002'
  _globals['_GETBALANCEREQUEST']._serialized_start=154
  _globals['_GETBALANCEREQUEST']._serialized_end=193
  _globals['_BALANCE']._serialized_start=195
  _globals['_BALANCE']._serialized_end=239
  _globals['_LISTPAYMENTMETHODSREQUEST']._serialized_start=241
  _globals['_LISTPAYMENTMETHODSREQUEST']._serialized_end=290
  _globals['_STRIPECHECKOUTSESSION']._serialized_start=293
  _globals['_STRIPECHECKOUTSESSION']._serialized_end=540
  _globals['_STRIPECHECKOUTSESSION_MODE']._serialized_start=488
  _globals['_STRIPECHECKOUTSESSION_MODE']._serialized_end=540
  _globals['_LISTPAYMENTMETHODSRESPONSE']._serialized_start=543
  _globals['_LISTPAYMENTMETHODSRESPONSE']._serialized_end=1085
  _globals['_LISTPAYMENTMETHODSRESPONSE_CARD']._serialized_start=781
  _globals['_LISTPAYMENTMETHODSRESPONSE_CARD']._serialized_end=854
  _globals['_LISTPAYMENTMETHODSRESPONSE_USBANKACCOUNT']._serialized_start=856
  _globals['_LISTPAYMENTMETHODSRESPONSE_USBANKACCOUNT']._serialized_end=905
  _globals['_LISTPAYMENTMETHODSRESPONSE_STRIPEPAYMENTMETHOD']._serialized_start=908
  _globals['_LISTPAYMENTMETHODSRESPONSE_STRIPEPAYMENTMETHOD']._serialized_end=1085
  _globals['_LISTCOSTSREQUEST']._serialized_start=1088
  _globals['_LISTCOSTSREQUEST']._serialized_end=1254
  _globals['_LISTCOSTSRESPONSE']._serialized_start=1257
  _globals['_LISTCOSTSRESPONSE']._serialized_end=1526
  _globals['_LISTCOSTSRESPONSE_COSTDATAITEM']._serialized_start=1345
  _globals['_LISTCOSTSRESPONSE_COSTDATAITEM']._serialized_end=1526
  _globals['_LISTINVOICESREQUEST']._serialized_start=1529
  _globals['_LISTINVOICESREQUEST']._serialized_end=1686
  _globals['_INVOICE']._serialized_start=1689
  _globals['_INVOICE']._serialized_end=1993
  _globals['_INVOICE_STATE']._serialized_start=1908
  _globals['_INVOICE_STATE']._serialized_end=1993
  _globals['_LISTINVOICESRESPONSE']._serialized_start=1995
  _globals['_LISTINVOICESRESPONSE']._serialized_end=2098
  _globals['_SKUINFO']._serialized_start=2100
  _globals['_SKUINFO']._serialized_end=2172
  _globals['_EXPORTBILLINGMETRICSREQUEST']._serialized_start=2175
  _globals['_EXPORTBILLINGMETRICSREQUEST']._serialized_end=2330
  _globals['_EXPORTBILLINGMETRICSRESPONSE']._serialized_start=2332
  _globals['_EXPORTBILLINGMETRICSRESPONSE']._serialized_end=2383
  _globals['_GETTOTALHISTORICALSPENDREQUEST']._serialized_start=2385
  _globals['_GETTOTALHISTORICALSPENDREQUEST']._serialized_end=2437
  _globals['_GETTOTALHISTORICALSPENDRESPONSE']._serialized_start=2439
  _globals['_GETTOTALHISTORICALSPENDRESPONSE']._serialized_end=2507
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS']._serialized_start=2509
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS']._serialized_end=2594
  _globals['_BILLINGREQUESTCOSTRECORD']._serialized_start=2596
  _globals['_BILLINGREQUESTCOSTRECORD']._serialized_end=2665
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRESPONSE']._serialized_start=2667
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRESPONSE']._serialized_end=2757
# @@protoc_insertion_point(module_scope)
