# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/node_pool.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/node_pool.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/node_pool.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8e\x0b\n\x08NodePool\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12!\n\x0c\x64isplay_name\x18\x06 \x01(\tB\x0b\xe2\x41\x01\x01\xbaH\x04r\x02\x18?\x12\x36\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12&\n\x0emin_node_count\x18\n \x01(\x05\x42\x0e\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\xe8\x07(\x00\x12&\n\x0emax_node_count\x18\x0b \x01(\x05\x42\x0e\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\xe8\x07(\x00\x12-\n\x18overprovision_node_count\x18\x0c \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12-\n\reks_node_pool\x18\x07 \x01(\x0b\x32\x14.gateway.EksNodePoolH\x00\x12/\n\x0e\x66\x61ke_node_pool\x18\x03 \x01(\x0b\x32\x15.gateway.FakeNodePoolH\x00\x12=\n\x0b\x61nnotations\x18\x0e \x03(\x0b\x32\".gateway.NodePool.AnnotationsEntryB\x04\xe2\x41\x01\x01\x12-\n\x05state\x18\x05 \x01(\x0e\x32\x17.gateway.NodePool.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12:\n\x0fnode_pool_stats\x18\r \x01(\x0b\x32\x16.gateway.NodePoolStatsB\t\xe2\x41\x02\x03\x05\xa0\xf1\x04\x01\x12\x35\n\x0bupdate_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04:\x90\x05\xea\x41r\n\x19\x61pi.fireworks.ai/NodePool\x12@accounts/{AccountId}/clusters/{ClusterId}/nodePools/{NodePoolId}*\tnodePools2\x08nodePool\xbaH\x8a\x04\x1a\xa6\x01\n\x1anode_pool.node_count_check\x12>max_node_count must be greater than or equal to min_node_count\x1aHthis.max_node_count == 0 || (this.max_node_count >= this.min_node_count)\x1a\xc2\x01\n*node_pool.overprovision_node_count_range_1\x12Hoverprovision_node_count cannot exceed (max_node_count - min_node_count)\x1aJthis.overprovision_node_count <= this.max_node_count - this.min_node_count\x1a\x99\x01\n*node_pool.overprovision_node_count_range_2\x12\x35overprovision_node_count cannot exceed min_node_count\x1a\x34this.overprovision_node_count <= this.min_node_count\x82\xf1\x04\t\n\x07\x43lusterB\x10\n\x0enode_pool_type\"\xea\x01\n\x0b\x45ksNodePool\x12\x18\n\tnode_role\x18\x01 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x1c\n\rinstance_type\x18\x02 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x13\n\x04spot\x18\x04 \x01(\x08\x42\x05\xe2\x41\x02\x01\x05\x12\x1e\n\x0fnode_group_name\x18\x05 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x19\n\nsubnet_ids\x18\x06 \x03(\tB\x05\xe2\x41\x02\x01\x05\x12\x13\n\x04zone\x18\x07 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x1e\n\x0fplacement_group\x18\x08 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x1e\n\x0flaunch_template\x18\t \x01(\tB\x05\xe2\x41\x02\x01\x05\"P\n\x0c\x46\x61keNodePool\x12\x14\n\x0cmachine_type\x18\x01 \x01(\t\x12\x11\n\tnum_nodes\x18\x02 \x01(\x05\x12\x17\n\x0fservice_account\x18\x03 \x01(\t\"\xe5\x02\n\rNodePoolStats\x12\x12\n\nnode_count\x18\x01 \x01(\x05\x12\x16\n\x0eranks_per_node\x18\x02 \x01(\x05\x12\x19\n\x11\x65nvironment_count\x18\x03 \x01(\x05\x12\x19\n\x11\x65nvironment_ranks\x18\x04 \x01(\x05\x12\x42\n\x0f\x62\x61tch_job_count\x18\x05 \x03(\x0b\x32).gateway.NodePoolStats.BatchJobCountEntry\x12\x42\n\x0f\x62\x61tch_job_ranks\x18\x06 \x03(\x0b\x32).gateway.NodePoolStats.BatchJobRanksEntry\x1a\x34\n\x12\x42\x61tchJobCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x34\n\x12\x42\x61tchJobRanksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"u\n\x15\x43reateNodePoolRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12*\n\tnode_pool\x18\x02 \x01(\x0b\x32\x11.gateway.NodePoolB\x04\xe2\x41\x01\x02\x12\x1a\n\x0cnode_pool_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"(\n\x12GetNodePoolRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x8d\x01\n\x14ListNodePoolsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"k\n\x15ListNodePoolsResponse\x12%\n\nnode_pools\x18\x01 \x03(\x0b\x32\x11.gateway.NodePool\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"z\n\x15UpdateNodePoolRequest\x12*\n\tnode_pool\x18\x01 \x01(\x0b\x32\x11.gateway.NodePoolB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"+\n\x15\x44\x65leteNodePoolRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"H\n\x1b\x42\x61tchDeleteNodePoolsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05names\x18\x02 \x03(\tB\x04\xe2\x41\x01\x02\"-\n\x17GetNodePoolStatsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.node_pool_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_NODEPOOL_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_NODEPOOL_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_NODEPOOL'].fields_by_name['name']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOL'].fields_by_name['display_name']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['display_name']._serialized_options = b'\342A\001\001\272H\004r\002\030?'
  _globals['_NODEPOOL'].fields_by_name['create_time']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOL'].fields_by_name['min_node_count']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['min_node_count']._serialized_options = b'\342A\001\001\272H\007\032\005\030\350\007(\000'
  _globals['_NODEPOOL'].fields_by_name['max_node_count']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['max_node_count']._serialized_options = b'\342A\001\001\272H\007\032\005\030\350\007(\000'
  _globals['_NODEPOOL'].fields_by_name['overprovision_node_count']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['overprovision_node_count']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_NODEPOOL'].fields_by_name['annotations']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['annotations']._serialized_options = b'\342A\001\001'
  _globals['_NODEPOOL'].fields_by_name['state']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOL'].fields_by_name['status']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOL'].fields_by_name['node_pool_stats']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['node_pool_stats']._serialized_options = b'\342A\002\003\005\240\361\004\001'
  _globals['_NODEPOOL'].fields_by_name['update_time']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_NODEPOOL']._loaded_options = None
  _globals['_NODEPOOL']._serialized_options = b'\352Ar\n\031api.fireworks.ai/NodePool\022@accounts/{AccountId}/clusters/{ClusterId}/nodePools/{NodePoolId}*\tnodePools2\010nodePool\272H\212\004\032\246\001\n\032node_pool.node_count_check\022>max_node_count must be greater than or equal to min_node_count\032Hthis.max_node_count == 0 || (this.max_node_count >= this.min_node_count)\032\302\001\n*node_pool.overprovision_node_count_range_1\022Hoverprovision_node_count cannot exceed (max_node_count - min_node_count)\032Jthis.overprovision_node_count <= this.max_node_count - this.min_node_count\032\231\001\n*node_pool.overprovision_node_count_range_2\0225overprovision_node_count cannot exceed min_node_count\0324this.overprovision_node_count <= this.min_node_count\202\361\004\t\n\007Cluster'
  _globals['_EKSNODEPOOL'].fields_by_name['node_role']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['node_role']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['instance_type']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['instance_type']._serialized_options = b'\342A\002\002\005'
  _globals['_EKSNODEPOOL'].fields_by_name['spot']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['spot']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['node_group_name']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['node_group_name']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['subnet_ids']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['subnet_ids']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['zone']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['zone']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['placement_group']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['placement_group']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['launch_template']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['launch_template']._serialized_options = b'\342A\002\001\005'
  _globals['_NODEPOOLSTATS_BATCHJOBCOUNTENTRY']._loaded_options = None
  _globals['_NODEPOOLSTATS_BATCHJOBCOUNTENTRY']._serialized_options = b'8\001'
  _globals['_NODEPOOLSTATS_BATCHJOBRANKSENTRY']._loaded_options = None
  _globals['_NODEPOOLSTATS_BATCHJOBRANKSENTRY']._serialized_options = b'8\001'
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['node_pool']._loaded_options = None
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['node_pool']._serialized_options = b'\342A\001\002'
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['node_pool_id']._loaded_options = None
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['node_pool_id']._serialized_options = b'\342A\001\002'
  _globals['_GETNODEPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETNODEPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENODEPOOLREQUEST'].fields_by_name['node_pool']._loaded_options = None
  _globals['_UPDATENODEPOOLREQUEST'].fields_by_name['node_pool']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENODEPOOLREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATENODEPOOLREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETENODEPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETENODEPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETENODEPOOLSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_BATCHDELETENODEPOOLSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETENODEPOOLSREQUEST'].fields_by_name['names']._loaded_options = None
  _globals['_BATCHDELETENODEPOOLSREQUEST'].fields_by_name['names']._serialized_options = b'\342A\001\002'
  _globals['_GETNODEPOOLSTATSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETNODEPOOLSTATSREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_NODEPOOL']._serialized_start=238
  _globals['_NODEPOOL']._serialized_end=1660
  _globals['_NODEPOOL_ANNOTATIONSENTRY']._serialized_start=850
  _globals['_NODEPOOL_ANNOTATIONSENTRY']._serialized_end=900
  _globals['_NODEPOOL_STATE']._serialized_start=902
  _globals['_NODEPOOL_STATE']._serialized_end=983
  _globals['_EKSNODEPOOL']._serialized_start=1663
  _globals['_EKSNODEPOOL']._serialized_end=1897
  _globals['_FAKENODEPOOL']._serialized_start=1899
  _globals['_FAKENODEPOOL']._serialized_end=1979
  _globals['_NODEPOOLSTATS']._serialized_start=1982
  _globals['_NODEPOOLSTATS']._serialized_end=2339
  _globals['_NODEPOOLSTATS_BATCHJOBCOUNTENTRY']._serialized_start=2233
  _globals['_NODEPOOLSTATS_BATCHJOBCOUNTENTRY']._serialized_end=2285
  _globals['_NODEPOOLSTATS_BATCHJOBRANKSENTRY']._serialized_start=2287
  _globals['_NODEPOOLSTATS_BATCHJOBRANKSENTRY']._serialized_end=2339
  _globals['_CREATENODEPOOLREQUEST']._serialized_start=2341
  _globals['_CREATENODEPOOLREQUEST']._serialized_end=2458
  _globals['_GETNODEPOOLREQUEST']._serialized_start=2460
  _globals['_GETNODEPOOLREQUEST']._serialized_end=2500
  _globals['_LISTNODEPOOLSREQUEST']._serialized_start=2503
  _globals['_LISTNODEPOOLSREQUEST']._serialized_end=2644
  _globals['_LISTNODEPOOLSRESPONSE']._serialized_start=2646
  _globals['_LISTNODEPOOLSRESPONSE']._serialized_end=2753
  _globals['_UPDATENODEPOOLREQUEST']._serialized_start=2755
  _globals['_UPDATENODEPOOLREQUEST']._serialized_end=2877
  _globals['_DELETENODEPOOLREQUEST']._serialized_start=2879
  _globals['_DELETENODEPOOLREQUEST']._serialized_end=2922
  _globals['_BATCHDELETENODEPOOLSREQUEST']._serialized_start=2924
  _globals['_BATCHDELETENODEPOOLSREQUEST']._serialized_end=2996
  _globals['_GETNODEPOOLSTATSREQUEST']._serialized_start=2998
  _globals['_GETNODEPOOLSTATSREQUEST']._serialized_end=3043
# @@protoc_insertion_point(module_scope)
