# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/environment.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/environment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gateway/environment.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe9\x06\n\x0b\x45nvironment\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x06 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x30\n\x05state\x18\n \x01(\x0e\x32\x1a.gateway.Environment.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x0b \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x39\n\nconnection\x18\x02 \x01(\x0b\x32\x1e.gateway.EnvironmentConnectionB\x05\xe2\x41\x02\x03\x05\x12\x1d\n\x0e\x62\x61se_image_ref\x18\x07 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x18\n\timage_ref\x18\x04 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12!\n\x12snapshot_image_ref\x18\x08 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x0e\n\x06shared\x18\x0c \x01(\x08\x12@\n\x0b\x61nnotations\x18\t \x03(\x0b\x32%.gateway.Environment.AnnotationsEntryB\x04\xe2\x41\x01\x01\x12\x35\n\x0bupdate_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x10\n\x0c\x44ISCONNECTED\x10\x02\x12\x0e\n\nCONNECTING\x10\x03\x12\r\n\tCONNECTED\x10\x04\x12\x11\n\rDISCONNECTING\x10\x05\x12\x10\n\x0cRECONNECTING\x10\x07\x12\x0c\n\x08\x44\x45LETING\x10\x06:\x94\x01\xea\x41\x81\x01\n\x1c\x61pi.fireworks.ai/Environment\x12\x46\x61\x63\x63ounts/{AccountId}/clusters/{ClusterId}/environments/{EnvironmentId}*\x0c\x65nvironments2\x0b\x65nvironment\x82\xf1\x04\x0b\n\x07\x43luster\x18\x01\"\x98\x01\n\x15\x45nvironmentConnection\x12\x1a\n\x0cnode_pool_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tnum_ranks\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x12\n\x04role\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01\x12\x13\n\x04zone\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12!\n\x11use_local_storage\x18\x07 \x01(\x08\x42\x06\x18\x01\xe2\x41\x01\x01\"\x7f\n\x18\x43reateEnvironmentRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12/\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x14.gateway.EnvironmentB\x04\xe2\x41\x01\x02\x12\x1c\n\x0e\x65nvironment_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"+\n\x15GetEnvironmentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x90\x01\n\x17ListEnvironmentsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"s\n\x18ListEnvironmentsResponse\x12*\n\x0c\x65nvironments\x18\x01 \x03(\x0b\x32\x14.gateway.Environment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x82\x01\n\x18UpdateEnvironmentRequest\x12/\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x14.gateway.EnvironmentB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\".\n\x18\x44\x65leteEnvironmentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"K\n\x1e\x42\x61tchDeleteEnvironmentsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05names\x18\x02 \x03(\tB\x04\xe2\x41\x01\x02\"\x87\x01\n\x19\x43onnectEnvironmentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x38\n\nconnection\x18\x02 \x01(\x0b\x32\x1e.gateway.EnvironmentConnectionB\x04\xe2\x41\x01\x02\x12\x1c\n\x0evscode_version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"f\n\x1c\x44isconnectEnvironmentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05\x66orce\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x1d\n\x0freset_snapshots\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.environment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_ENVIRONMENT_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_ENVIRONMENT_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_ENVIRONMENT'].fields_by_name['name']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['display_name']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_ENVIRONMENT'].fields_by_name['create_time']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['created_by']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['state']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['status']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['connection']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['connection']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['base_image_ref']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['base_image_ref']._serialized_options = b'\342A\002\001\005'
  _globals['_ENVIRONMENT'].fields_by_name['image_ref']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['image_ref']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['snapshot_image_ref']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['snapshot_image_ref']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['annotations']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['annotations']._serialized_options = b'\342A\001\001'
  _globals['_ENVIRONMENT'].fields_by_name['update_time']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_ENVIRONMENT']._loaded_options = None
  _globals['_ENVIRONMENT']._serialized_options = b'\352A\201\001\n\034api.fireworks.ai/Environment\022Faccounts/{AccountId}/clusters/{ClusterId}/environments/{EnvironmentId}*\014environments2\013environment\202\361\004\013\n\007Cluster\030\001'
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['node_pool_id']._loaded_options = None
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['node_pool_id']._serialized_options = b'\342A\001\002'
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['num_ranks']._loaded_options = None
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['num_ranks']._serialized_options = b'\342A\001\001'
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['role']._loaded_options = None
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['role']._serialized_options = b'\342A\001\001'
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['zone']._loaded_options = None
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['zone']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['use_local_storage']._loaded_options = None
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['use_local_storage']._serialized_options = b'\030\001\342A\001\001'
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['environment']._serialized_options = b'\342A\001\002'
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['environment_id']._loaded_options = None
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['environment_id']._serialized_options = b'\342A\001\002'
  _globals['_GETENVIRONMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETENVIRONMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['environment']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEENVIRONMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEENVIRONMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETEENVIRONMENTSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_BATCHDELETEENVIRONMENTSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETEENVIRONMENTSREQUEST'].fields_by_name['names']._loaded_options = None
  _globals['_BATCHDELETEENVIRONMENTSREQUEST'].fields_by_name['names']._serialized_options = b'\342A\001\002'
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['connection']._loaded_options = None
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['connection']._serialized_options = b'\342A\001\002'
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['vscode_version']._loaded_options = None
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['vscode_version']._serialized_options = b'\342A\001\001'
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['force']._loaded_options = None
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['force']._serialized_options = b'\342A\001\001'
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['reset_snapshots']._loaded_options = None
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['reset_snapshots']._serialized_options = b'\342A\001\001'
  _globals['_ENVIRONMENT']._serialized_start=211
  _globals['_ENVIRONMENT']._serialized_end=1084
  _globals['_ENVIRONMENT_ANNOTATIONSENTRY']._serialized_start=736
  _globals['_ENVIRONMENT_ANNOTATIONSENTRY']._serialized_end=786
  _globals['_ENVIRONMENT_STATE']._serialized_start=789
  _globals['_ENVIRONMENT_STATE']._serialized_end=933
  _globals['_ENVIRONMENTCONNECTION']._serialized_start=1087
  _globals['_ENVIRONMENTCONNECTION']._serialized_end=1239
  _globals['_CREATEENVIRONMENTREQUEST']._serialized_start=1241
  _globals['_CREATEENVIRONMENTREQUEST']._serialized_end=1368
  _globals['_GETENVIRONMENTREQUEST']._serialized_start=1370
  _globals['_GETENVIRONMENTREQUEST']._serialized_end=1413
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_start=1416
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_end=1560
  _globals['_LISTENVIRONMENTSRESPONSE']._serialized_start=1562
  _globals['_LISTENVIRONMENTSRESPONSE']._serialized_end=1677
  _globals['_UPDATEENVIRONMENTREQUEST']._serialized_start=1680
  _globals['_UPDATEENVIRONMENTREQUEST']._serialized_end=1810
  _globals['_DELETEENVIRONMENTREQUEST']._serialized_start=1812
  _globals['_DELETEENVIRONMENTREQUEST']._serialized_end=1858
  _globals['_BATCHDELETEENVIRONMENTSREQUEST']._serialized_start=1860
  _globals['_BATCHDELETEENVIRONMENTSREQUEST']._serialized_end=1935
  _globals['_CONNECTENVIRONMENTREQUEST']._serialized_start=1938
  _globals['_CONNECTENVIRONMENTREQUEST']._serialized_end=2073
  _globals['_DISCONNECTENVIRONMENTREQUEST']._serialized_start=2075
  _globals['_DISCONNECTENVIRONMENTREQUEST']._serialized_end=2177
# @@protoc_insertion_point(module_scope)
