# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/account.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from . import user_pb2 as gateway_dot_user__pb2
from . import wandb_pb2 as gateway_dot_wandb__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/account.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x12gateway/user.proto\x1a\x13gateway/wandb.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbe\t\n\x07\x41\x63\x63ount\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x05\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12)\n\x0cintended_use\x18\x13 \x01(\tB\x13\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12\x38\n\x13prometheus_endpoint\x18\x04 \x01(\tB\x1b\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x44\n\x1f\x61thena_cost_usage_report_bucket\x18\x05 \x01(\tB\x1b\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x38\n\x0c\x61\x63\x63ount_type\x18\x06 \x01(\x0e\x32\x1c.gateway.Account.AccountTypeB\x04\xe2\x41\x01\x01\x12\x13\n\x05\x65mail\x18\t \x01(\tB\x04\xe2\x41\x01\x02\x12,\n\x05state\x18\x07 \x01(\x0e\x32\x16.gateway.Account.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12?\n\rsuspend_state\x18\x0c \x01(\x0e\x32\x1d.gateway.Account.SuspendStateB\t\xe2\x41\x02\x03\x05\x98\xf1\x04\x01\x12\x30\n\x12stripe_customer_id\x18\r \x01(\tB\x14\xe2\x41\x02\x03\x05\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12\x34\n\x0foidc_issuer_url\x18\x0e \x01(\tB\x1b\xe2\x41\x02\x04\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x33\n\x0eoidc_client_id\x18\x0f \x01(\tB\x1b\xe2\x41\x02\x04\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x33\n\x0e\x63ognito_domain\x18\x10 \x01(\tB\x1b\xe2\x41\x02\x04\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x46\n\x0cwandb_config\x18\x11 \x01(\x0b\x32\x14.gateway.WandbConfigB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x0bupdate_time\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\"X\n\x0b\x41\x63\x63ountType\x12\x1c\n\x18\x41\x43\x43OUNT_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDEVELOPER\x10\x01\x12\x0e\n\nENTERPRISE\x10\x02\x12\x0c\n\x08\x42USINESS\x10\x04\"S\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"k\n\x0cSuspendState\x12\x0f\n\x0bUNSUSPENDED\x10\x00\x12\x13\n\x0f\x46\x41ILED_PAYMENTS\x10\x01\x12\x13\n\x0f\x43REDIT_DEPLETED\x10\x02\x12 \n\x1cMONTHLY_SPEND_LIMIT_EXCEEDED\x10\x03:L\xea\x41\x43\n\x18\x61pi.fireworks.ai/Account\x12\x14\x61\x63\x63ounts/{AccountId}*\x08\x61\x63\x63ounts2\x07\x61\x63\x63ount\x82\xf1\x04\x02\x18\x01\"\x90\x01\n\x14\x43reateAccountRequest\x12\'\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x10.gateway.AccountB\x04\xe2\x41\x01\x02\x12\x18\n\naccount_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x12\n\x04wait\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12!\n\x04user\x18\x04 \x01(\x0b\x32\r.gateway.UserB\x04\xe2\x41\x01\x01\"\'\n\x11GetAccountRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xa4\x01\n\x13ListAccountsRequest\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12,\n\x08show_all\x18\x06 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\"g\n\x14ListAccountsResponse\x12\"\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x10.gateway.Account\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"v\n\x14UpdateAccountRequest\x12\'\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x10.gateway.AccountB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"U\n\x14\x44\x65leteAccountRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12)\n\x05\x66orce\x18\x02 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLYBCZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_ACCOUNT'].fields_by_name['name']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_ACCOUNT'].fields_by_name['display_name']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['display_name']._serialized_options = b'\342A\001\005'
  _globals['_ACCOUNT'].fields_by_name['create_time']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_ACCOUNT'].fields_by_name['intended_use']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['intended_use']._serialized_options = b'\342A\001\001\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_ACCOUNT'].fields_by_name['prometheus_endpoint']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['prometheus_endpoint']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['athena_cost_usage_report_bucket']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['athena_cost_usage_report_bucket']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['account_type']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['account_type']._serialized_options = b'\342A\001\001'
  _globals['_ACCOUNT'].fields_by_name['email']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['email']._serialized_options = b'\342A\001\002'
  _globals['_ACCOUNT'].fields_by_name['state']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_ACCOUNT'].fields_by_name['status']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_ACCOUNT'].fields_by_name['suspend_state']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['suspend_state']._serialized_options = b'\342A\002\003\005\230\361\004\001'
  _globals['_ACCOUNT'].fields_by_name['stripe_customer_id']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['stripe_customer_id']._serialized_options = b'\342A\002\003\005\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_ACCOUNT'].fields_by_name['oidc_issuer_url']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['oidc_issuer_url']._serialized_options = b'\342A\002\004\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['oidc_client_id']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['oidc_client_id']._serialized_options = b'\342A\002\004\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['cognito_domain']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['cognito_domain']._serialized_options = b'\342A\002\004\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['wandb_config']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['wandb_config']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT'].fields_by_name['update_time']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_ACCOUNT']._loaded_options = None
  _globals['_ACCOUNT']._serialized_options = b'\352AC\n\030api.fireworks.ai/Account\022\024accounts/{AccountId}*\010accounts2\007account\202\361\004\002\030\001'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['account']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['account']._serialized_options = b'\342A\001\002'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['account_id']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['account_id']._serialized_options = b'\342A\001\001'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['wait']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['wait']._serialized_options = b'\342A\001\001'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['user']._serialized_options = b'\342A\001\001'
  _globals['_GETACCOUNTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETACCOUNTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['show_all']._loaded_options = None
  _globals['_LISTACCOUNTSREQUEST'].fields_by_name['show_all']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_UPDATEACCOUNTREQUEST'].fields_by_name['account']._loaded_options = None
  _globals['_UPDATEACCOUNTREQUEST'].fields_by_name['account']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEACCOUNTREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEACCOUNTREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEACCOUNTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEACCOUNTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DELETEACCOUNTREQUEST'].fields_by_name['force']._loaded_options = None
  _globals['_DELETEACCOUNTREQUEST'].fields_by_name['force']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_ACCOUNT']._serialized_start=277
  _globals['_ACCOUNT']._serialized_end=1491
  _globals['_ACCOUNT_ACCOUNTTYPE']._serialized_start=1131
  _globals['_ACCOUNT_ACCOUNTTYPE']._serialized_end=1219
  _globals['_ACCOUNT_STATE']._serialized_start=1221
  _globals['_ACCOUNT_STATE']._serialized_end=1304
  _globals['_ACCOUNT_SUSPENDSTATE']._serialized_start=1306
  _globals['_ACCOUNT_SUSPENDSTATE']._serialized_end=1413
  _globals['_CREATEACCOUNTREQUEST']._serialized_start=1494
  _globals['_CREATEACCOUNTREQUEST']._serialized_end=1638
  _globals['_GETACCOUNTREQUEST']._serialized_start=1640
  _globals['_GETACCOUNTREQUEST']._serialized_end=1679
  _globals['_LISTACCOUNTSREQUEST']._serialized_start=1682
  _globals['_LISTACCOUNTSREQUEST']._serialized_end=1846
  _globals['_LISTACCOUNTSRESPONSE']._serialized_start=1848
  _globals['_LISTACCOUNTSRESPONSE']._serialized_end=1951
  _globals['_UPDATEACCOUNTREQUEST']._serialized_start=1953
  _globals['_UPDATEACCOUNTREQUEST']._serialized_end=2071
  _globals['_DELETEACCOUNTREQUEST']._serialized_start=2073
  _globals['_DELETEACCOUNTREQUEST']._serialized_end=2158
# @@protoc_insertion_point(module_scope)
