# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/deployment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/deployment.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18gateway/deployment.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc7\x05\n\nDeployment\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x64\x65scription\x18\x08 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x30\n\x05state\x18\x05 \x01(\x0e\x32\x19.gateway.Deployment.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12 \n\x10predict_http_uri\x18\t \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12!\n\x11min_replica_count\x18\r \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12!\n\x11max_replica_count\x18\x0e \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fmax_addon_count\x18\x10 \x01(\x05\x42\x06\xe0\x41\x03\xe0\x41\x05\x12\x1b\n\x0b\x61\x64\x64on_count\x18\x11 \x01(\x05\x42\x06\xe0\x41\x03\xe0\x41\x05\x12\x1a\n\nbase_model\x18\x12 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12+\n\x1b\x64isaggregated_prefill_count\x18\x13 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1e\n\x0emax_batch_size\x18\x14 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x30\n\x0e\x61ws_deployment\x18\x15 \x01(\x0b\x32\x16.gateway.AwsDeploymentH\x00\x12\x30\n\x0egcp_deployment\x18\x16 \x01(\x0b\x32\x16.gateway.GcpDeploymentH\x00\"_\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\x42\x06\n\x04type\"\x0f\n\rAwsDeployment\"\x0f\n\rGcpDeployment\"s\n\x17\x43reateDeploymentRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12,\n\ndeployment\x18\x02 \x01(\x0b\x32\x13.gateway.DeploymentB\x03\xe0\x41\x02\x12\x15\n\x08model_id\x18\x04 \x01(\tB\x03\xe0\x41\x01\")\n\x14GetDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x8a\x01\n\x16ListDeploymentsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"p\n\x17ListDeploymentsResponse\x12(\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32\x13.gateway.Deployment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"G\n\x17UpdateDeploymentRequest\x12,\n\ndeployment\x18\x01 \x01(\x0b\x32\x13.gateway.DeploymentB\x03\xe0\x41\x02\",\n\x17\x44\x65leteDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"+\n\x16StartDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[gateway_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_DEPLOYMENT_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='gateway.Deployment.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=734,
  serialized_end=829,
)
_sym_db.RegisterEnumDescriptor(_DEPLOYMENT_STATE)


_DEPLOYMENT = _descriptor.Descriptor(
  name='Deployment',
  full_name='gateway.Deployment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.Deployment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.Deployment.display_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='gateway.Deployment.description', index=2,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.Deployment.create_time', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='gateway.Deployment.state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.Deployment.status', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predict_http_uri', full_name='gateway.Deployment.predict_http_uri', index=6,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_replica_count', full_name='gateway.Deployment.min_replica_count', index=7,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_replica_count', full_name='gateway.Deployment.max_replica_count', index=8,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_addon_count', full_name='gateway.Deployment.max_addon_count', index=9,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addon_count', full_name='gateway.Deployment.addon_count', index=10,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_model', full_name='gateway.Deployment.base_model', index=11,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disaggregated_prefill_count', full_name='gateway.Deployment.disaggregated_prefill_count', index=12,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_batch_size', full_name='gateway.Deployment.max_batch_size', index=13,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws_deployment', full_name='gateway.Deployment.aws_deployment', index=14,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gcp_deployment', full_name='gateway.Deployment.gcp_deployment', index=15,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEPLOYMENT_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='gateway.Deployment.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=126,
  serialized_end=837,
)


_AWSDEPLOYMENT = _descriptor.Descriptor(
  name='AwsDeployment',
  full_name='gateway.AwsDeployment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=839,
  serialized_end=854,
)


_GCPDEPLOYMENT = _descriptor.Descriptor(
  name='GcpDeployment',
  full_name='gateway.GcpDeployment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=856,
  serialized_end=871,
)


_CREATEDEPLOYMENTREQUEST = _descriptor.Descriptor(
  name='CreateDeploymentRequest',
  full_name='gateway.CreateDeploymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateDeploymentRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deployment', full_name='gateway.CreateDeploymentRequest.deployment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='gateway.CreateDeploymentRequest.model_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=988,
)


_GETDEPLOYMENTREQUEST = _descriptor.Descriptor(
  name='GetDeploymentRequest',
  full_name='gateway.GetDeploymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetDeploymentRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=990,
  serialized_end=1031,
)


_LISTDEPLOYMENTSREQUEST = _descriptor.Descriptor(
  name='ListDeploymentsRequest',
  full_name='gateway.ListDeploymentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListDeploymentsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListDeploymentsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListDeploymentsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListDeploymentsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListDeploymentsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1172,
)


_LISTDEPLOYMENTSRESPONSE = _descriptor.Descriptor(
  name='ListDeploymentsResponse',
  full_name='gateway.ListDeploymentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployments', full_name='gateway.ListDeploymentsResponse.deployments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListDeploymentsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListDeploymentsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1174,
  serialized_end=1286,
)


_UPDATEDEPLOYMENTREQUEST = _descriptor.Descriptor(
  name='UpdateDeploymentRequest',
  full_name='gateway.UpdateDeploymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployment', full_name='gateway.UpdateDeploymentRequest.deployment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1288,
  serialized_end=1359,
)


_DELETEDEPLOYMENTREQUEST = _descriptor.Descriptor(
  name='DeleteDeploymentRequest',
  full_name='gateway.DeleteDeploymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteDeploymentRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1361,
  serialized_end=1405,
)


_STARTDEPLOYMENTREQUEST = _descriptor.Descriptor(
  name='StartDeploymentRequest',
  full_name='gateway.StartDeploymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.StartDeploymentRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1407,
  serialized_end=1450,
)

_DEPLOYMENT.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DEPLOYMENT.fields_by_name['state'].enum_type = _DEPLOYMENT_STATE
_DEPLOYMENT.fields_by_name['status'].message_type = gateway_dot_status__pb2._STATUS
_DEPLOYMENT.fields_by_name['aws_deployment'].message_type = _AWSDEPLOYMENT
_DEPLOYMENT.fields_by_name['gcp_deployment'].message_type = _GCPDEPLOYMENT
_DEPLOYMENT_STATE.containing_type = _DEPLOYMENT
_DEPLOYMENT.oneofs_by_name['type'].fields.append(
  _DEPLOYMENT.fields_by_name['aws_deployment'])
_DEPLOYMENT.fields_by_name['aws_deployment'].containing_oneof = _DEPLOYMENT.oneofs_by_name['type']
_DEPLOYMENT.oneofs_by_name['type'].fields.append(
  _DEPLOYMENT.fields_by_name['gcp_deployment'])
_DEPLOYMENT.fields_by_name['gcp_deployment'].containing_oneof = _DEPLOYMENT.oneofs_by_name['type']
_CREATEDEPLOYMENTREQUEST.fields_by_name['deployment'].message_type = _DEPLOYMENT
_LISTDEPLOYMENTSRESPONSE.fields_by_name['deployments'].message_type = _DEPLOYMENT
_UPDATEDEPLOYMENTREQUEST.fields_by_name['deployment'].message_type = _DEPLOYMENT
DESCRIPTOR.message_types_by_name['Deployment'] = _DEPLOYMENT
DESCRIPTOR.message_types_by_name['AwsDeployment'] = _AWSDEPLOYMENT
DESCRIPTOR.message_types_by_name['GcpDeployment'] = _GCPDEPLOYMENT
DESCRIPTOR.message_types_by_name['CreateDeploymentRequest'] = _CREATEDEPLOYMENTREQUEST
DESCRIPTOR.message_types_by_name['GetDeploymentRequest'] = _GETDEPLOYMENTREQUEST
DESCRIPTOR.message_types_by_name['ListDeploymentsRequest'] = _LISTDEPLOYMENTSREQUEST
DESCRIPTOR.message_types_by_name['ListDeploymentsResponse'] = _LISTDEPLOYMENTSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDeploymentRequest'] = _UPDATEDEPLOYMENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteDeploymentRequest'] = _DELETEDEPLOYMENTREQUEST
DESCRIPTOR.message_types_by_name['StartDeploymentRequest'] = _STARTDEPLOYMENTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Deployment = _reflection.GeneratedProtocolMessageType('Deployment', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENT,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.Deployment)
  })
_sym_db.RegisterMessage(Deployment)

AwsDeployment = _reflection.GeneratedProtocolMessageType('AwsDeployment', (_message.Message,), {
  'DESCRIPTOR' : _AWSDEPLOYMENT,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.AwsDeployment)
  })
_sym_db.RegisterMessage(AwsDeployment)

GcpDeployment = _reflection.GeneratedProtocolMessageType('GcpDeployment', (_message.Message,), {
  'DESCRIPTOR' : _GCPDEPLOYMENT,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GcpDeployment)
  })
_sym_db.RegisterMessage(GcpDeployment)

CreateDeploymentRequest = _reflection.GeneratedProtocolMessageType('CreateDeploymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDEPLOYMENTREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateDeploymentRequest)
  })
_sym_db.RegisterMessage(CreateDeploymentRequest)

GetDeploymentRequest = _reflection.GeneratedProtocolMessageType('GetDeploymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDEPLOYMENTREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetDeploymentRequest)
  })
_sym_db.RegisterMessage(GetDeploymentRequest)

ListDeploymentsRequest = _reflection.GeneratedProtocolMessageType('ListDeploymentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEPLOYMENTSREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListDeploymentsRequest)
  })
_sym_db.RegisterMessage(ListDeploymentsRequest)

ListDeploymentsResponse = _reflection.GeneratedProtocolMessageType('ListDeploymentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEPLOYMENTSRESPONSE,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListDeploymentsResponse)
  })
_sym_db.RegisterMessage(ListDeploymentsResponse)

UpdateDeploymentRequest = _reflection.GeneratedProtocolMessageType('UpdateDeploymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDEPLOYMENTREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UpdateDeploymentRequest)
  })
_sym_db.RegisterMessage(UpdateDeploymentRequest)

DeleteDeploymentRequest = _reflection.GeneratedProtocolMessageType('DeleteDeploymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDEPLOYMENTREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteDeploymentRequest)
  })
_sym_db.RegisterMessage(DeleteDeploymentRequest)

StartDeploymentRequest = _reflection.GeneratedProtocolMessageType('StartDeploymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTDEPLOYMENTREQUEST,
  '__module__' : 'gateway.deployment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.StartDeploymentRequest)
  })
_sym_db.RegisterMessage(StartDeploymentRequest)


DESCRIPTOR._options = None
_DEPLOYMENT.fields_by_name['name']._options = None
_DEPLOYMENT.fields_by_name['display_name']._options = None
_DEPLOYMENT.fields_by_name['description']._options = None
_DEPLOYMENT.fields_by_name['create_time']._options = None
_DEPLOYMENT.fields_by_name['state']._options = None
_DEPLOYMENT.fields_by_name['status']._options = None
_DEPLOYMENT.fields_by_name['predict_http_uri']._options = None
_DEPLOYMENT.fields_by_name['min_replica_count']._options = None
_DEPLOYMENT.fields_by_name['max_replica_count']._options = None
_DEPLOYMENT.fields_by_name['max_addon_count']._options = None
_DEPLOYMENT.fields_by_name['addon_count']._options = None
_DEPLOYMENT.fields_by_name['base_model']._options = None
_DEPLOYMENT.fields_by_name['disaggregated_prefill_count']._options = None
_DEPLOYMENT.fields_by_name['max_batch_size']._options = None
_CREATEDEPLOYMENTREQUEST.fields_by_name['parent']._options = None
_CREATEDEPLOYMENTREQUEST.fields_by_name['deployment']._options = None
_CREATEDEPLOYMENTREQUEST.fields_by_name['model_id']._options = None
_GETDEPLOYMENTREQUEST.fields_by_name['name']._options = None
_LISTDEPLOYMENTSREQUEST.fields_by_name['parent']._options = None
_LISTDEPLOYMENTSREQUEST.fields_by_name['page_size']._options = None
_LISTDEPLOYMENTSREQUEST.fields_by_name['page_token']._options = None
_LISTDEPLOYMENTSREQUEST.fields_by_name['filter']._options = None
_LISTDEPLOYMENTSREQUEST.fields_by_name['order_by']._options = None
_UPDATEDEPLOYMENTREQUEST.fields_by_name['deployment']._options = None
_DELETEDEPLOYMENTREQUEST.fields_by_name['name']._options = None
_STARTDEPLOYMENTREQUEST.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)
