# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/peft_merge_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/peft_merge_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgateway/peft_merge_job.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x03\n\x0cPeftMergeJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x04 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\'\n\x05state\x18\x05 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x19\n\npeft_model\x18\x07 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x1b\n\x0cmerged_model\x18\t \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x35\n\x0bupdate_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03:\x83\x01\xea\x41q\n\x1d\x61pi.fireworks.ai/PeftMergeJob\x12\x33\x61\x63\x63ounts/{AccountId}/PeftMergeJobs/{PeftMergeJobId}*\rPeftMergeJobs2\x0cPeftMergeJob\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\",\n\x16GetPeftMergeJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"f\n\x19\x43reatePeftMergeJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x33\n\x0epeft_merge_job\x18\x02 \x01(\x0b\x32\x15.gateway.PeftMergeJobB\x04\xe2\x41\x01\x02\"\x91\x01\n\x18ListPeftMergeJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"x\n\x19ListPeftMergeJobsResponse\x12.\n\x0fpeft_merge_jobs\x18\x01 \x03(\x0b\x32\x15.gateway.PeftMergeJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"/\n\x19\x44\x65letePeftMergeJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.peft_merge_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_PEFTMERGEJOB'].fields_by_name['name']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_PEFTMERGEJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['state']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['status']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['peft_model']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['peft_model']._serialized_options = b'\342A\002\002\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['merged_model']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['merged_model']._serialized_options = b'\342A\002\002\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_PEFTMERGEJOB']._loaded_options = None
  _globals['_PEFTMERGEJOB']._serialized_options = b'\352Aq\n\035api.fireworks.ai/PeftMergeJob\0223accounts/{AccountId}/PeftMergeJobs/{PeftMergeJobId}*\rPeftMergeJobs2\014PeftMergeJob\202\361\004\013\n\007Account\030\001'
  _globals['_GETPEFTMERGEJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETPEFTMERGEJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEPEFTMERGEJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEPEFTMERGEJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEPEFTMERGEJOBREQUEST'].fields_by_name['peft_merge_job']._loaded_options = None
  _globals['_CREATEPEFTMERGEJOBREQUEST'].fields_by_name['peft_merge_job']._serialized_options = b'\342A\001\002'
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETEPEFTMERGEJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEPEFTMERGEJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PEFTMERGEJOB']._serialized_start=180
  _globals['_PEFTMERGEJOB']._serialized_end=652
  _globals['_GETPEFTMERGEJOBREQUEST']._serialized_start=654
  _globals['_GETPEFTMERGEJOBREQUEST']._serialized_end=698
  _globals['_CREATEPEFTMERGEJOBREQUEST']._serialized_start=700
  _globals['_CREATEPEFTMERGEJOBREQUEST']._serialized_end=802
  _globals['_LISTPEFTMERGEJOBSREQUEST']._serialized_start=805
  _globals['_LISTPEFTMERGEJOBSREQUEST']._serialized_end=950
  _globals['_LISTPEFTMERGEJOBSRESPONSE']._serialized_start=952
  _globals['_LISTPEFTMERGEJOBSRESPONSE']._serialized_end=1072
  _globals['_DELETEPEFTMERGEJOBREQUEST']._serialized_start=1074
  _globals['_DELETEPEFTMERGEJOBREQUEST']._serialized_end=1121
# @@protoc_insertion_point(module_scope)
