# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/model.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/model.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import billing_pb2 as gateway_dot_billing__pb2
from . import deployed_model_pb2 as gateway_dot_deployed__model__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..google.type import date_pb2 as google_dot_type_dot_date__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13gateway/model.proto\x12\x07gateway\x1a\x15gateway/billing.proto\x1a\x1cgateway/deployed_model.proto\x1a\x18gateway/deployment.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x16google/type/date.proto\"\xaf\x0f\n\x05Model\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x19\n\x0b\x64\x65scription\x18\x14 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18  \x01(\tB\x05\xe2\x41\x02\x03\x05\x12*\n\x05state\x18\x06 \x01(\x0e\x32\x14.gateway.Model.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x07 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12(\n\x04kind\x18\x04 \x01(\x0e\x32\x13.gateway.Model.KindB\x05\xe2\x41\x02\x01\x05\x12\x18\n\ngithub_url\x18\x15 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1e\n\x10hugging_face_url\x18\x16 \x01(\tB\x04\xe2\x41\x01\x01\x12<\n\x12\x62\x61se_model_details\x18\x17 \x01(\x0b\x32\x19.gateway.BaseModelDetailsB\x05\xe2\x41\x02\x01\x05\x12\x31\n\x0cpeft_details\x18\x10 \x01(\x0b\x32\x14.gateway.PEFTDetailsB\x05\xe2\x41\x02\x01\x05\x12\x31\n\x0cteft_details\x18\x11 \x01(\x0b\x32\x14.gateway.TEFTDetailsB\x05\xe2\x41\x02\x01\x05\x12\x14\n\x06public\x18\x13 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12?\n\x13\x63onversation_config\x18\x18 \x01(\x0b\x32\x1b.gateway.ConversationConfigB\x05\xe2\x41\x02\x01\x05\x12\x1c\n\x0e\x63ontext_length\x18\x19 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\"\n\x14supports_image_input\x18\x1a \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x1c\n\x0esupports_tools\x18\x1b \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x1e\n\rimported_from\x18\x1c \x01(\tB\x07\x18\x01\xe2\x41\x02\x03\x05\x12*\n\x11tokens_per_second\x18\x1d \x01(\x05\x42\x0f\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12*\n\x11\x66\x65\x61tured_priority\x18\x1f \x01(\x05\x42\x0f\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12\x1e\n\x0f\x66ine_tuning_job\x18! \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x38\n\tsku_infos\x18\" \x03(\x0b\x32\x10.gateway.SKUInfoB\x13\x98\xf1\x04\x01\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12!\n\x13\x64\x65\x66\x61ult_draft_model\x18# \x01(\tB\x04\xe2\x41\x01\x01\x12\'\n\x19\x64\x65\x66\x61ult_draft_token_count\x18$ \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x38\n\nprecisions\x18& \x03(\x0e\x32\x1d.gateway.Deployment.PrecisionB\x05\xe2\x41\x02\x01\x03\x12@\n\x13\x64\x65ployed_model_refs\x18% \x03(\x0b\x32\x19.gateway.DeployedModelRefB\x08\xe2\x41\x01\x03\x98\xf1\x04\x01\x12\x16\n\x07\x63luster\x18\' \x01(\tB\x05\xe2\x41\x02\x01\x03\x12\x31\n\x10\x64\x65precation_date\x18( \x01(\x0b\x32\x11.google.type.DateB\x04\xe2\x41\x01\x01\x12\x18\n\ncalibrated\x18) \x01(\x08\x42\x04\xe2\x41\x01\x03\x12\x15\n\x07tunable\x18* \x01(\x08\x42\x04\xe2\x41\x01\x03\x12\x1b\n\rsupports_lora\x18+ \x01(\x08\x42\x04\xe2\x41\x01\x01\x12(\n\x1ause_hf_apply_chat_template\x18, \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x39\n\x15\x65xtra_deployment_args\x18- \x03(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x0bupdate_time\x18. \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12P\n\x17\x64\x65\x66\x61ult_sampling_params\x18/ \x03(\x0b\x32).gateway.Model.DefaultSamplingParamsEntryB\x04\xe2\x41\x01\x03\x12+\n\x07gcs_uri\x18\x30 \x01(\tB\x1a\xe2\x41\x01\x03\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x18\n\nrl_tunable\x18\x31 \x01(\x08\x42\x04\xe2\x41\x01\x03\x1a<\n\x1a\x44\x65\x66\x61ultSamplingParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"8\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\r\n\tUPLOADING\x10\x01\x12\t\n\x05READY\x10\x06\"\xb1\x01\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x11\n\rHF_BASE_MODEL\x10\x01\x12\x11\n\rHF_PEFT_ADDON\x10\x02\x12\x11\n\rHF_TEFT_ADDON\x10\x03\x12\x16\n\x12\x46LUMINA_BASE_MODEL\x10\x04\x12\x11\n\rFLUMINA_ADDON\x10\x05\x12\x0f\n\x0b\x44RAFT_ADDON\x10\x06\x12\x0e\n\nFIRE_AGENT\x10\x07\x12\x0e\n\nLIVE_MERGE\x10\x08:`\xea\x41N\n\x16\x61pi.fireworks.ai/Model\x12%accounts/{AccountId}/models/{ModelId}*\x06models2\x05model\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"\xf5\x02\n\x10\x42\x61seModelDetails\x12\x19\n\nworld_size\x18\x01 \x01(\x05\x42\x05\xe2\x41\x02\x01\x05\x12L\n\x11\x63heckpoint_format\x18\x02 \x01(\x0e\x32*.gateway.BaseModelDetails.CheckpointFormatB\x05\xe2\x41\x02\x01\x05\x12/\n\x11huggingface_files\x18\x03 \x03(\tB\x14\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12\x17\n\x0fparameter_count\x18\x04 \x01(\x03\x12\x0b\n\x03moe\x18\x05 \x01(\x08\x12\x13\n\x07tunable\x18\x06 \x01(\x08\x42\x02\x18\x01\x12\x12\n\nmodel_type\x18\x07 \x01(\t\x12$\n\x16supports_fireattention\x18\x08 \x01(\x08\x42\x04\xe2\x41\x01\x01\"R\n\x10\x43heckpointFormat\x12!\n\x1d\x43HECKPOINT_FORMAT_UNSPECIFIED\x10\x00\x12\n\n\x06NATIVE\x10\x01\x12\x0f\n\x0bHUGGINGFACE\x10\x02\"\x9e\x01\n\x0bPEFTDetails\x12\x19\n\nbase_model\x18\x01 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x10\n\x01r\x18\x02 \x01(\x05\x42\x05\xe2\x41\x02\x02\x05\x12\x1d\n\x0etarget_modules\x18\x03 \x03(\tB\x05\xe2\x41\x02\x02\x05\x12\x1d\n\x0f\x62\x61se_model_type\x18\x04 \x01(\tB\x04\xe2\x41\x01\x03\x12$\n\x16merge_addon_model_name\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\r\n\x0bTEFTDetails\"W\n\x12\x43onversationConfig\x12\x13\n\x05style\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x14\n\x06system\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08template\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"~\n\x12\x43reateModelRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12#\n\x05model\x18\x02 \x01(\x0b\x32\x0e.gateway.ModelB\x04\xe2\x41\x01\x01\x12\x16\n\x08model_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\x12\x15\n\x07\x63luster\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"%\n\x0fGetModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"a\n\x13PrepareModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x36\n\tprecision\x18\x02 \x01(\x0e\x32\x1d.gateway.Deployment.PrecisionB\x04\xe2\x41\x01\x01\"\xed\x01\n\x1dGetModelUploadEndpointRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12Z\n\x10\x66ilename_to_size\x18\x02 \x03(\x0b\x32:.gateway.GetModelUploadEndpointRequest.FilenameToSizeEntryB\x04\xe2\x41\x01\x02\x12%\n\x17\x65nable_resumable_upload\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\x1a\x35\n\x13\x46ilenameToSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xe8\x02\n\x1eGetModelUploadEndpointResponse\x12\x62\n\x17\x66ilename_to_signed_urls\x18\x05 \x03(\x0b\x32\x41.gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry\x12\x66\n\x19\x66ilename_to_unsigned_uris\x18\x06 \x03(\x0b\x32\x43.gateway.GetModelUploadEndpointResponse.FilenameToUnsignedUrisEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a=\n\x1b\x46ilenameToUnsignedUrisEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x1fGetModelDownloadEndpointRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xc5\x01\n GetModelDownloadEndpointResponse\x12\x64\n\x17\x66ilename_to_signed_urls\x18\x05 \x03(\x0b\x32\x43.gateway.GetModelDownloadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n\x1aValidateModelUploadRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\'\n\x19skip_hf_config_validation\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01\"\xc0\x01\n\x11ListModelsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x34\n\x1binclude_deployed_model_refs\x18\x06 \x01(\x08\x42\x0f\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\"a\n\x12ListModelsResponse\x12\x1e\n\x06models\x18\x01 \x03(\x0b\x32\x0e.gateway.Model\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"!\n\x1fListServerlessLoraModelsRequest\"2\n ListServerlessLoraModelsResponse\x12\x0e\n\x06models\x18\x01 \x03(\t\"\\\n\x1aValidateModelConfigRequest\x12\x19\n\x0b\x63onfig_json\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12#\n\x15tokenizer_config_json\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\"p\n\x12UpdateModelRequest\x12#\n\x05model\x18\x01 \x01(\x0b\x32\x0e.gateway.ModelB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"(\n\x12\x44\x65leteModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x94\x01\n\x10\x41wsS3ModelSource\x12\x17\n\ts3_bucket\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x15\n\x07s3_path\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08role_arn\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1b\n\raccess_key_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1b\n\raccess_secret\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"`\n\x12ImportModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x36\n\raws_s3_source\x18\x02 \x01(\x0b\x32\x19.gateway.AwsS3ModelSourceB\x04\xe2\x41\x01\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.model_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_MODEL_DEFAULTSAMPLINGPARAMSENTRY']._loaded_options = None
  _globals['_MODEL_DEFAULTSAMPLINGPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_MODEL'].fields_by_name['name']._loaded_options = None
  _globals['_MODEL'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['display_name']._loaded_options = None
  _globals['_MODEL'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['description']._loaded_options = None
  _globals['_MODEL'].fields_by_name['description']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['create_time']._loaded_options = None
  _globals['_MODEL'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['created_by']._loaded_options = None
  _globals['_MODEL'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['state']._loaded_options = None
  _globals['_MODEL'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['status']._loaded_options = None
  _globals['_MODEL'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['kind']._loaded_options = None
  _globals['_MODEL'].fields_by_name['kind']._serialized_options = b'\342A\002\001\005'
  _globals['_MODEL'].fields_by_name['github_url']._loaded_options = None
  _globals['_MODEL'].fields_by_name['github_url']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['hugging_face_url']._loaded_options = None
  _globals['_MODEL'].fields_by_name['hugging_face_url']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['base_model_details']._loaded_options = None
  _globals['_MODEL'].fields_by_name['base_model_details']._serialized_options = b'\342A\002\001\005'
  _globals['_MODEL'].fields_by_name['peft_details']._loaded_options = None
  _globals['_MODEL'].fields_by_name['peft_details']._serialized_options = b'\342A\002\001\005'
  _globals['_MODEL'].fields_by_name['teft_details']._loaded_options = None
  _globals['_MODEL'].fields_by_name['teft_details']._serialized_options = b'\342A\002\001\005'
  _globals['_MODEL'].fields_by_name['public']._loaded_options = None
  _globals['_MODEL'].fields_by_name['public']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['conversation_config']._loaded_options = None
  _globals['_MODEL'].fields_by_name['conversation_config']._serialized_options = b'\342A\002\001\005'
  _globals['_MODEL'].fields_by_name['context_length']._loaded_options = None
  _globals['_MODEL'].fields_by_name['context_length']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['supports_image_input']._loaded_options = None
  _globals['_MODEL'].fields_by_name['supports_image_input']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['supports_tools']._loaded_options = None
  _globals['_MODEL'].fields_by_name['supports_tools']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['imported_from']._loaded_options = None
  _globals['_MODEL'].fields_by_name['imported_from']._serialized_options = b'\030\001\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['tokens_per_second']._loaded_options = None
  _globals['_MODEL'].fields_by_name['tokens_per_second']._serialized_options = b'\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_MODEL'].fields_by_name['featured_priority']._loaded_options = None
  _globals['_MODEL'].fields_by_name['featured_priority']._serialized_options = b'\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_MODEL'].fields_by_name['fine_tuning_job']._loaded_options = None
  _globals['_MODEL'].fields_by_name['fine_tuning_job']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['sku_infos']._loaded_options = None
  _globals['_MODEL'].fields_by_name['sku_infos']._serialized_options = b'\230\361\004\001\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_MODEL'].fields_by_name['default_draft_model']._loaded_options = None
  _globals['_MODEL'].fields_by_name['default_draft_model']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['default_draft_token_count']._loaded_options = None
  _globals['_MODEL'].fields_by_name['default_draft_token_count']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['precisions']._loaded_options = None
  _globals['_MODEL'].fields_by_name['precisions']._serialized_options = b'\342A\002\001\003'
  _globals['_MODEL'].fields_by_name['deployed_model_refs']._loaded_options = None
  _globals['_MODEL'].fields_by_name['deployed_model_refs']._serialized_options = b'\342A\001\003\230\361\004\001'
  _globals['_MODEL'].fields_by_name['cluster']._loaded_options = None
  _globals['_MODEL'].fields_by_name['cluster']._serialized_options = b'\342A\002\001\003'
  _globals['_MODEL'].fields_by_name['deprecation_date']._loaded_options = None
  _globals['_MODEL'].fields_by_name['deprecation_date']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['calibrated']._loaded_options = None
  _globals['_MODEL'].fields_by_name['calibrated']._serialized_options = b'\342A\001\003'
  _globals['_MODEL'].fields_by_name['tunable']._loaded_options = None
  _globals['_MODEL'].fields_by_name['tunable']._serialized_options = b'\342A\001\003'
  _globals['_MODEL'].fields_by_name['supports_lora']._loaded_options = None
  _globals['_MODEL'].fields_by_name['supports_lora']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['use_hf_apply_chat_template']._loaded_options = None
  _globals['_MODEL'].fields_by_name['use_hf_apply_chat_template']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['extra_deployment_args']._loaded_options = None
  _globals['_MODEL'].fields_by_name['extra_deployment_args']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_MODEL'].fields_by_name['update_time']._loaded_options = None
  _globals['_MODEL'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_MODEL'].fields_by_name['default_sampling_params']._loaded_options = None
  _globals['_MODEL'].fields_by_name['default_sampling_params']._serialized_options = b'\342A\001\003'
  _globals['_MODEL'].fields_by_name['gcs_uri']._loaded_options = None
  _globals['_MODEL'].fields_by_name['gcs_uri']._serialized_options = b'\342A\001\003\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_MODEL'].fields_by_name['rl_tunable']._loaded_options = None
  _globals['_MODEL'].fields_by_name['rl_tunable']._serialized_options = b'\342A\001\003'
  _globals['_MODEL']._loaded_options = None
  _globals['_MODEL']._serialized_options = b'\352AN\n\026api.fireworks.ai/Model\022%accounts/{AccountId}/models/{ModelId}*\006models2\005model\202\361\004\013\n\007Account\030\001'
  _globals['_BASEMODELDETAILS'].fields_by_name['world_size']._loaded_options = None
  _globals['_BASEMODELDETAILS'].fields_by_name['world_size']._serialized_options = b'\342A\002\001\005'
  _globals['_BASEMODELDETAILS'].fields_by_name['checkpoint_format']._loaded_options = None
  _globals['_BASEMODELDETAILS'].fields_by_name['checkpoint_format']._serialized_options = b'\342A\002\001\005'
  _globals['_BASEMODELDETAILS'].fields_by_name['huggingface_files']._loaded_options = None
  _globals['_BASEMODELDETAILS'].fields_by_name['huggingface_files']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_BASEMODELDETAILS'].fields_by_name['tunable']._loaded_options = None
  _globals['_BASEMODELDETAILS'].fields_by_name['tunable']._serialized_options = b'\030\001'
  _globals['_BASEMODELDETAILS'].fields_by_name['supports_fireattention']._loaded_options = None
  _globals['_BASEMODELDETAILS'].fields_by_name['supports_fireattention']._serialized_options = b'\342A\001\001'
  _globals['_PEFTDETAILS'].fields_by_name['base_model']._loaded_options = None
  _globals['_PEFTDETAILS'].fields_by_name['base_model']._serialized_options = b'\342A\002\002\005'
  _globals['_PEFTDETAILS'].fields_by_name['r']._loaded_options = None
  _globals['_PEFTDETAILS'].fields_by_name['r']._serialized_options = b'\342A\002\002\005'
  _globals['_PEFTDETAILS'].fields_by_name['target_modules']._loaded_options = None
  _globals['_PEFTDETAILS'].fields_by_name['target_modules']._serialized_options = b'\342A\002\002\005'
  _globals['_PEFTDETAILS'].fields_by_name['base_model_type']._loaded_options = None
  _globals['_PEFTDETAILS'].fields_by_name['base_model_type']._serialized_options = b'\342A\001\003'
  _globals['_PEFTDETAILS'].fields_by_name['merge_addon_model_name']._loaded_options = None
  _globals['_PEFTDETAILS'].fields_by_name['merge_addon_model_name']._serialized_options = b'\342A\001\001'
  _globals['_CONVERSATIONCONFIG'].fields_by_name['style']._loaded_options = None
  _globals['_CONVERSATIONCONFIG'].fields_by_name['style']._serialized_options = b'\342A\001\002'
  _globals['_CONVERSATIONCONFIG'].fields_by_name['system']._loaded_options = None
  _globals['_CONVERSATIONCONFIG'].fields_by_name['system']._serialized_options = b'\342A\001\001'
  _globals['_CONVERSATIONCONFIG'].fields_by_name['template']._loaded_options = None
  _globals['_CONVERSATIONCONFIG'].fields_by_name['template']._serialized_options = b'\342A\001\001'
  _globals['_CREATEMODELREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEMODELREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEMODELREQUEST'].fields_by_name['model']._loaded_options = None
  _globals['_CREATEMODELREQUEST'].fields_by_name['model']._serialized_options = b'\342A\001\001'
  _globals['_CREATEMODELREQUEST'].fields_by_name['model_id']._loaded_options = None
  _globals['_CREATEMODELREQUEST'].fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _globals['_CREATEMODELREQUEST'].fields_by_name['cluster']._loaded_options = None
  _globals['_CREATEMODELREQUEST'].fields_by_name['cluster']._serialized_options = b'\342A\001\001'
  _globals['_GETMODELREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETMODELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PREPAREMODELREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_PREPAREMODELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PREPAREMODELREQUEST'].fields_by_name['precision']._loaded_options = None
  _globals['_PREPAREMODELREQUEST'].fields_by_name['precision']._serialized_options = b'\342A\001\001'
  _globals['_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_options = b'8\001'
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['filename_to_size']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['filename_to_size']._serialized_options = b'\342A\001\002'
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['enable_resumable_upload']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['enable_resumable_upload']._serialized_options = b'\342A\001\001'
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOUNSIGNEDURISENTRY']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOUNSIGNEDURISENTRY']._serialized_options = b'8\001'
  _globals['_GETMODELDOWNLOADENDPOINTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETMODELDOWNLOADENDPOINTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_VALIDATEMODELUPLOADREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_VALIDATEMODELUPLOADREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_VALIDATEMODELUPLOADREQUEST'].fields_by_name['skip_hf_config_validation']._loaded_options = None
  _globals['_VALIDATEMODELUPLOADREQUEST'].fields_by_name['skip_hf_config_validation']._serialized_options = b'\342A\001\001'
  _globals['_LISTMODELSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTMODELSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTMODELSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTMODELSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTMODELSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_LISTMODELSREQUEST'].fields_by_name['include_deployed_model_refs']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['include_deployed_model_refs']._serialized_options = b'\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_VALIDATEMODELCONFIGREQUEST'].fields_by_name['config_json']._loaded_options = None
  _globals['_VALIDATEMODELCONFIGREQUEST'].fields_by_name['config_json']._serialized_options = b'\342A\001\002'
  _globals['_VALIDATEMODELCONFIGREQUEST'].fields_by_name['tokenizer_config_json']._loaded_options = None
  _globals['_VALIDATEMODELCONFIGREQUEST'].fields_by_name['tokenizer_config_json']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEMODELREQUEST'].fields_by_name['model']._loaded_options = None
  _globals['_UPDATEMODELREQUEST'].fields_by_name['model']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEMODELREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEMODELREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEMODELREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEMODELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_AWSS3MODELSOURCE'].fields_by_name['s3_bucket']._loaded_options = None
  _globals['_AWSS3MODELSOURCE'].fields_by_name['s3_bucket']._serialized_options = b'\342A\001\002'
  _globals['_AWSS3MODELSOURCE'].fields_by_name['s3_path']._loaded_options = None
  _globals['_AWSS3MODELSOURCE'].fields_by_name['s3_path']._serialized_options = b'\342A\001\001'
  _globals['_AWSS3MODELSOURCE'].fields_by_name['role_arn']._loaded_options = None
  _globals['_AWSS3MODELSOURCE'].fields_by_name['role_arn']._serialized_options = b'\342A\001\001'
  _globals['_AWSS3MODELSOURCE'].fields_by_name['access_key_id']._loaded_options = None
  _globals['_AWSS3MODELSOURCE'].fields_by_name['access_key_id']._serialized_options = b'\342A\001\001'
  _globals['_AWSS3MODELSOURCE'].fields_by_name['access_secret']._loaded_options = None
  _globals['_AWSS3MODELSOURCE'].fields_by_name['access_secret']._serialized_options = b'\342A\001\001'
  _globals['_IMPORTMODELREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_IMPORTMODELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_IMPORTMODELREQUEST'].fields_by_name['aws_s3_source']._loaded_options = None
  _globals['_IMPORTMODELREQUEST'].fields_by_name['aws_s3_source']._serialized_options = b'\342A\001\001'
  _globals['_MODEL']._serialized_start=337
  _globals['_MODEL']._serialized_end=2304
  _globals['_MODEL_DEFAULTSAMPLINGPARAMSENTRY']._serialized_start=1908
  _globals['_MODEL_DEFAULTSAMPLINGPARAMSENTRY']._serialized_end=1968
  _globals['_MODEL_STATE']._serialized_start=1970
  _globals['_MODEL_STATE']._serialized_end=2026
  _globals['_MODEL_KIND']._serialized_start=2029
  _globals['_MODEL_KIND']._serialized_end=2206
  _globals['_BASEMODELDETAILS']._serialized_start=2307
  _globals['_BASEMODELDETAILS']._serialized_end=2680
  _globals['_BASEMODELDETAILS_CHECKPOINTFORMAT']._serialized_start=2598
  _globals['_BASEMODELDETAILS_CHECKPOINTFORMAT']._serialized_end=2680
  _globals['_PEFTDETAILS']._serialized_start=2683
  _globals['_PEFTDETAILS']._serialized_end=2841
  _globals['_TEFTDETAILS']._serialized_start=2843
  _globals['_TEFTDETAILS']._serialized_end=2856
  _globals['_CONVERSATIONCONFIG']._serialized_start=2858
  _globals['_CONVERSATIONCONFIG']._serialized_end=2945
  _globals['_CREATEMODELREQUEST']._serialized_start=2947
  _globals['_CREATEMODELREQUEST']._serialized_end=3073
  _globals['_GETMODELREQUEST']._serialized_start=3075
  _globals['_GETMODELREQUEST']._serialized_end=3112
  _globals['_PREPAREMODELREQUEST']._serialized_start=3114
  _globals['_PREPAREMODELREQUEST']._serialized_end=3211
  _globals['_GETMODELUPLOADENDPOINTREQUEST']._serialized_start=3214
  _globals['_GETMODELUPLOADENDPOINTREQUEST']._serialized_end=3451
  _globals['_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_start=3398
  _globals['_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_end=3451
  _globals['_GETMODELUPLOADENDPOINTRESPONSE']._serialized_start=3454
  _globals['_GETMODELUPLOADENDPOINTRESPONSE']._serialized_end=3814
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=3692
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=3751
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOUNSIGNEDURISENTRY']._serialized_start=3753
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOUNSIGNEDURISENTRY']._serialized_end=3814
  _globals['_GETMODELDOWNLOADENDPOINTREQUEST']._serialized_start=3816
  _globals['_GETMODELDOWNLOADENDPOINTREQUEST']._serialized_end=3869
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE']._serialized_start=3872
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE']._serialized_end=4069
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=3692
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=3751
  _globals['_VALIDATEMODELUPLOADREQUEST']._serialized_start=4071
  _globals['_VALIDATEMODELUPLOADREQUEST']._serialized_end=4160
  _globals['_LISTMODELSREQUEST']._serialized_start=4163
  _globals['_LISTMODELSREQUEST']._serialized_end=4355
  _globals['_LISTMODELSRESPONSE']._serialized_start=4357
  _globals['_LISTMODELSRESPONSE']._serialized_end=4454
  _globals['_LISTSERVERLESSLORAMODELSREQUEST']._serialized_start=4456
  _globals['_LISTSERVERLESSLORAMODELSREQUEST']._serialized_end=4489
  _globals['_LISTSERVERLESSLORAMODELSRESPONSE']._serialized_start=4491
  _globals['_LISTSERVERLESSLORAMODELSRESPONSE']._serialized_end=4541
  _globals['_VALIDATEMODELCONFIGREQUEST']._serialized_start=4543
  _globals['_VALIDATEMODELCONFIGREQUEST']._serialized_end=4635
  _globals['_UPDATEMODELREQUEST']._serialized_start=4637
  _globals['_UPDATEMODELREQUEST']._serialized_end=4749
  _globals['_DELETEMODELREQUEST']._serialized_start=4751
  _globals['_DELETEMODELREQUEST']._serialized_end=4791
  _globals['_AWSS3MODELSOURCE']._serialized_start=4794
  _globals['_AWSS3MODELSOURCE']._serialized_end=4942
  _globals['_IMPORTMODELREQUEST']._serialized_start=4944
  _globals['_IMPORTMODELREQUEST']._serialized_end=5040
# @@protoc_insertion_point(module_scope)
