# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/batch_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/batch_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/batch_job.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\t\n\x08\x42\x61tchJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\t \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\nstart_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x33\n\x08\x65nd_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\r \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1b\n\x0cnode_pool_id\x18\x02 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x1d\n\x0e\x65nvironment_id\x18\x03 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x1a\n\x0bsnapshot_id\x18\x13 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x18\n\tnum_ranks\x18\x0b \x01(\x05\x42\x05\xe2\x41\x02\x01\x05\x12\x37\n\x08\x65nv_vars\x18\x06 \x03(\x0b\x32\x1e.gateway.BatchJob.EnvVarsEntryB\x05\xe2\x41\x02\x01\x05\x12\x13\n\x04role\x18\x11 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x32\n\x0fpython_executor\x18\x07 \x01(\x0b\x32\x17.gateway.PythonExecutorH\x00\x12\x36\n\x11notebook_executor\x18\x08 \x01(\x0b\x32\x19.gateway.NotebookExecutorH\x00\x12\x30\n\x0eshell_executor\x18\x10 \x01(\x0b\x32\x16.gateway.ShellExecutorH\x00\x12\x18\n\timage_ref\x18\n \x01(\tB\x05\xe2\x41\x02\x01\x05\x12>\n\x0b\x61nnotations\x18\x12 \x03(\x0b\x32\".gateway.BatchJob.AnnotationsEntryB\x05\xe2\x41\x02\x01\x05\x12-\n\x05state\x18\x04 \x01(\x0e\x32\x17.gateway.BatchJob.StateB\x05\xe2\x41\x02\x03\x05\x12\x15\n\x06status\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x0e\n\x06shared\x18\x14 \x01(\x08\x12\x35\n\x0bupdate_time\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a.\n\x0c\x45nvVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x07\x12\n\n\x06QUEUED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0e\n\nCANCELLING\x10\x08\x12\r\n\tCANCELLED\x10\x06\x12\x0c\n\x08\x44\x45LETING\x10\t:\x84\x01\xea\x41r\n\x19\x61pi.fireworks.ai/BatchJob\x12@accounts/{AccountId}/clusters/{ClusterId}/batchJobs/{BatchJobId}*\tbatchJobs2\x08\x62\x61tchJob\x82\xf1\x04\x0b\n\x07\x43luster\x10\x01\x42\x0f\n\rexecutor_type\"Y\n\x15\x43reateBatchJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12*\n\tbatch_job\x18\x02 \x01(\x0b\x32\x11.gateway.BatchJobB\x04\xe2\x41\x01\x02\"(\n\x12GetBatchJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x8d\x01\n\x14ListBatchJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"k\n\x15ListBatchJobsResponse\x12%\n\nbatch_jobs\x18\x01 \x03(\x0b\x32\x11.gateway.BatchJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"z\n\x15UpdateBatchJobRequest\x12*\n\tbatch_job\x18\x01 \x01(\x0b\x32\x11.gateway.BatchJobB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"+\n\x15\x44\x65leteBatchJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"H\n\x1b\x42\x61tchDeleteBatchJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05names\x18\x02 \x03(\tB\x04\xe2\x41\x01\x02\"+\n\x15\x43\x61ncelBatchJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xd9\x01\n\x16GetBatchJobLogsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\r\n\x05ranks\x18\x03 \x03(\x05\x12\x17\n\tpage_size\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x34\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1d\n\x0fstart_from_head\x18\x08 \x01(\x08\x42\x04\xe2\x41\x01\x01\"V\n\x17GetBatchJobLogsResponse\x12\"\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x11.gateway.LogEntry\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\xbe\x01\n\x0ePythonExecutor\x12=\n\x0btarget_type\x18\x01 \x01(\x0e\x32\".gateway.PythonExecutor.TargetTypeB\x04\xe2\x41\x01\x02\x12\x14\n\x06target\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x12\n\x04\x61rgs\x18\x03 \x03(\tB\x04\xe2\x41\x01\x01\"C\n\nTargetType\x12\x1b\n\x17TARGET_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MODULE\x10\x01\x12\x0c\n\x08\x46ILENAME\x10\x02\"&\n\rShellExecutor\x12\x15\n\x07\x63ommand\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"3\n\x10NotebookExecutor\x12\x1f\n\x11notebook_filename\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"W\n\x08LogEntry\x12,\n\x08log_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04rank\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\tBCZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.batch_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_BATCHJOB_ENVVARSENTRY']._loaded_options = None
  _globals['_BATCHJOB_ENVVARSENTRY']._serialized_options = b'8\001'
  _globals['_BATCHJOB_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_BATCHJOB_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_BATCHJOB'].fields_by_name['name']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_BATCHJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['start_time']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['start_time']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['end_time']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['end_time']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['node_pool_id']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['node_pool_id']._serialized_options = b'\342A\002\002\005'
  _globals['_BATCHJOB'].fields_by_name['environment_id']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['environment_id']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['snapshot_id']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['snapshot_id']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['num_ranks']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['num_ranks']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['env_vars']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['env_vars']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['role']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['role']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['image_ref']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['image_ref']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['annotations']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['annotations']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['state']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['status']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_BATCHJOB']._loaded_options = None
  _globals['_BATCHJOB']._serialized_options = b'\352Ar\n\031api.fireworks.ai/BatchJob\022@accounts/{AccountId}/clusters/{ClusterId}/batchJobs/{BatchJobId}*\tbatchJobs2\010batchJob\202\361\004\013\n\007Cluster\020\001'
  _globals['_CREATEBATCHJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEBATCHJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEBATCHJOBREQUEST'].fields_by_name['batch_job']._loaded_options = None
  _globals['_CREATEBATCHJOBREQUEST'].fields_by_name['batch_job']._serialized_options = b'\342A\001\002'
  _globals['_GETBATCHJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETBATCHJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEBATCHJOBREQUEST'].fields_by_name['batch_job']._loaded_options = None
  _globals['_UPDATEBATCHJOBREQUEST'].fields_by_name['batch_job']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEBATCHJOBREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEBATCHJOBREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEBATCHJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEBATCHJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETEBATCHJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_BATCHDELETEBATCHJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETEBATCHJOBSREQUEST'].fields_by_name['names']._loaded_options = None
  _globals['_BATCHDELETEBATCHJOBSREQUEST'].fields_by_name['names']._serialized_options = b'\342A\001\002'
  _globals['_CANCELBATCHJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CANCELBATCHJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['start_time']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['start_time']._serialized_options = b'\342A\001\001'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['start_from_head']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['start_from_head']._serialized_options = b'\342A\001\001'
  _globals['_PYTHONEXECUTOR'].fields_by_name['target_type']._loaded_options = None
  _globals['_PYTHONEXECUTOR'].fields_by_name['target_type']._serialized_options = b'\342A\001\002'
  _globals['_PYTHONEXECUTOR'].fields_by_name['target']._loaded_options = None
  _globals['_PYTHONEXECUTOR'].fields_by_name['target']._serialized_options = b'\342A\001\002'
  _globals['_PYTHONEXECUTOR'].fields_by_name['args']._loaded_options = None
  _globals['_PYTHONEXECUTOR'].fields_by_name['args']._serialized_options = b'\342A\001\001'
  _globals['_SHELLEXECUTOR'].fields_by_name['command']._loaded_options = None
  _globals['_SHELLEXECUTOR'].fields_by_name['command']._serialized_options = b'\342A\001\002'
  _globals['_NOTEBOOKEXECUTOR'].fields_by_name['notebook_filename']._loaded_options = None
  _globals['_NOTEBOOKEXECUTOR'].fields_by_name['notebook_filename']._serialized_options = b'\342A\001\002'
  _globals['_BATCHJOB']._serialized_start=187
  _globals['_BATCHJOB']._serialized_end=1427
  _globals['_BATCHJOB_ENVVARSENTRY']._serialized_start=1020
  _globals['_BATCHJOB_ENVVARSENTRY']._serialized_end=1066
  _globals['_BATCHJOB_ANNOTATIONSENTRY']._serialized_start=1068
  _globals['_BATCHJOB_ANNOTATIONSENTRY']._serialized_end=1118
  _globals['_BATCHJOB_STATE']._serialized_start=1121
  _globals['_BATCHJOB_STATE']._serialized_end=1275
  _globals['_CREATEBATCHJOBREQUEST']._serialized_start=1429
  _globals['_CREATEBATCHJOBREQUEST']._serialized_end=1518
  _globals['_GETBATCHJOBREQUEST']._serialized_start=1520
  _globals['_GETBATCHJOBREQUEST']._serialized_end=1560
  _globals['_LISTBATCHJOBSREQUEST']._serialized_start=1563
  _globals['_LISTBATCHJOBSREQUEST']._serialized_end=1704
  _globals['_LISTBATCHJOBSRESPONSE']._serialized_start=1706
  _globals['_LISTBATCHJOBSRESPONSE']._serialized_end=1813
  _globals['_UPDATEBATCHJOBREQUEST']._serialized_start=1815
  _globals['_UPDATEBATCHJOBREQUEST']._serialized_end=1937
  _globals['_DELETEBATCHJOBREQUEST']._serialized_start=1939
  _globals['_DELETEBATCHJOBREQUEST']._serialized_end=1982
  _globals['_BATCHDELETEBATCHJOBSREQUEST']._serialized_start=1984
  _globals['_BATCHDELETEBATCHJOBSREQUEST']._serialized_end=2056
  _globals['_CANCELBATCHJOBREQUEST']._serialized_start=2058
  _globals['_CANCELBATCHJOBREQUEST']._serialized_end=2101
  _globals['_GETBATCHJOBLOGSREQUEST']._serialized_start=2104
  _globals['_GETBATCHJOBLOGSREQUEST']._serialized_end=2321
  _globals['_GETBATCHJOBLOGSRESPONSE']._serialized_start=2323
  _globals['_GETBATCHJOBLOGSRESPONSE']._serialized_end=2409
  _globals['_PYTHONEXECUTOR']._serialized_start=2412
  _globals['_PYTHONEXECUTOR']._serialized_end=2602
  _globals['_PYTHONEXECUTOR_TARGETTYPE']._serialized_start=2535
  _globals['_PYTHONEXECUTOR_TARGETTYPE']._serialized_end=2602
  _globals['_SHELLEXECUTOR']._serialized_start=2604
  _globals['_SHELLEXECUTOR']._serialized_end=2642
  _globals['_NOTEBOOKEXECUTOR']._serialized_start=2644
  _globals['_NOTEBOOKEXECUTOR']._serialized_end=2695
  _globals['_LOGENTRY']._serialized_start=2697
  _globals['_LOGENTRY']._serialized_end=2784
# @@protoc_insertion_point(module_scope)
