# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/api_key.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/api_key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/api_key.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x01\n\x06\x41piKey\x12\x16\n\x06key_id\x18\x01 \x01(\tB\x06\xe2\x41\x03\x01\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x13\n\x03key\x18\x03 \x01(\tB\x06\xe2\x41\x03\x01\x03\x05\x12\x36\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x15\n\x06secure\x18\x06 \x01(\x08\x42\x05\xe2\x41\x02\x03\x05\x12\x13\n\x05\x65mail\x18\x07 \x01(\tB\x04\xe2\x41\x01\x03\"S\n\x13\x43reateApiKeyRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12&\n\x07\x61pi_key\x18\x02 \x01(\x0b\x32\x0f.gateway.ApiKeyB\x04\xe2\x41\x01\x02\"\x8b\x01\n\x12ListApiKeysRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"e\n\x13ListApiKeysResponse\x12!\n\x08\x61pi_keys\x18\x01 \x03(\x0b\x32\x0f.gateway.ApiKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"A\n\x13\x44\x65leteApiKeyRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x14\n\x06key_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\"0\n\x18GetInternalApiKeyRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"R\n\x1aUpdateApiKeyAccountRequest\x12\x19\n\x0bold_account\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0bnew_account\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.api_key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_APIKEY'].fields_by_name['key_id']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['key_id']._serialized_options = b'\342A\003\001\003\005'
  _globals['_APIKEY'].fields_by_name['display_name']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_APIKEY'].fields_by_name['key']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['key']._serialized_options = b'\342A\003\001\003\005'
  _globals['_APIKEY'].fields_by_name['create_time']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_APIKEY'].fields_by_name['secure']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['secure']._serialized_options = b'\342A\002\003\005'
  _globals['_APIKEY'].fields_by_name['email']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['email']._serialized_options = b'\342A\001\003'
  _globals['_CREATEAPIKEYREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEAPIKEYREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEAPIKEYREQUEST'].fields_by_name['api_key']._loaded_options = None
  _globals['_CREATEAPIKEYREQUEST'].fields_by_name['api_key']._serialized_options = b'\342A\001\002'
  _globals['_LISTAPIKEYSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTAPIKEYSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTAPIKEYSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAPIKEYSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTAPIKEYSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAPIKEYSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTAPIKEYSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTAPIKEYSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTAPIKEYSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTAPIKEYSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETEAPIKEYREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_DELETEAPIKEYREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_DELETEAPIKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_DELETEAPIKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\342A\001\002'
  _globals['_GETINTERNALAPIKEYREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_GETINTERNALAPIKEYREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEAPIKEYACCOUNTREQUEST'].fields_by_name['old_account']._loaded_options = None
  _globals['_UPDATEAPIKEYACCOUNTREQUEST'].fields_by_name['old_account']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEAPIKEYACCOUNTREQUEST'].fields_by_name['new_account']._loaded_options = None
  _globals['_UPDATEAPIKEYACCOUNTREQUEST'].fields_by_name['new_account']._serialized_options = b'\342A\001\002'
  _globals['_APIKEY']._serialized_start=101
  _globals['_APIKEY']._serialized_end=282
  _globals['_CREATEAPIKEYREQUEST']._serialized_start=284
  _globals['_CREATEAPIKEYREQUEST']._serialized_end=367
  _globals['_LISTAPIKEYSREQUEST']._serialized_start=370
  _globals['_LISTAPIKEYSREQUEST']._serialized_end=509
  _globals['_LISTAPIKEYSRESPONSE']._serialized_start=511
  _globals['_LISTAPIKEYSRESPONSE']._serialized_end=612
  _globals['_DELETEAPIKEYREQUEST']._serialized_start=614
  _globals['_DELETEAPIKEYREQUEST']._serialized_end=679
  _globals['_GETINTERNALAPIKEYREQUEST']._serialized_start=681
  _globals['_GETINTERNALAPIKEYREQUEST']._serialized_end=729
  _globals['_UPDATEAPIKEYACCOUNTREQUEST']._serialized_start=731
  _globals['_UPDATEAPIKEYACCOUNTREQUEST']._serialized_end=813
# @@protoc_insertion_point(module_scope)
