# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/test_resource.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/test_resource.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..google.type import date_pb2 as google_dot_type_dot_date__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgateway/test_resource.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x16google/type/date.proto\"\x8c\x05\n\x0cTestResource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02\x66\x32\x18\x02 \x01(\x01\x12\n\n\x02\x66\x33\x18\x03 \x01(\x02\x12\n\n\x02\x66\x34\x18\x04 \x01(\x05\x12\n\n\x02\x66\x35\x18\x05 \x01(\x03\x12\n\n\x02\x66\x36\x18\x06 \x01(\r\x12\n\n\x02\x66\x37\x18\x07 \x01(\x04\x12\n\n\x02\x66\x38\x18\x08 \x01(\x11\x12\n\n\x02\x66\x39\x18\t \x01(\x12\x12\x0b\n\x03\x66\x31\x30\x18\n \x01(\x07\x12\x0b\n\x03\x66\x31\x31\x18\x0b \x01(\x06\x12\x0b\n\x03\x66\x31\x32\x18\x0c \x01(\x0f\x12\x0b\n\x03\x66\x31\x33\x18\r \x01(\x10\x12\x0b\n\x03\x66\x31\x34\x18\x0e \x01(\x08\x12\x0b\n\x03\x66\x31\x35\x18\x0f \x01(\t\x12\'\n\x03\x66\x31\x36\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x03\x66\x31\x38\x18\x12 \x01(\x0e\x32\x1f.gateway.TestResource.InnerEnum\x12\x1f\n\x03\x66\x31\x39\x18\x13 \x01(\x0e\x32\x12.gateway.OuterEnum\x12/\n\x03\x66\x32\x30\x18\x14 \x01(\x0b\x32\".gateway.TestResource.InnerMessage\x12\"\n\x03\x66\x32\x31\x18\x15 \x01(\x0b\x32\x15.gateway.OuterMessage\x12\x1e\n\x03\x66\x32\x32\x18\x16 \x01(\x0b\x32\x11.google.type.Date\x1a\x1b\n\x0cInnerMessage\x12\x0b\n\x03\x66oo\x18\x01 \x01(\t\"0\n\tInnerEnum\x12\x1a\n\x16INNER_ENUM_UNSPECIFIED\x10\x00\x12\x07\n\x03ONE\x10\x01:\x83\x01\xea\x41q\n\x1d\x61pi.fireworks.ai/TestResource\x12\x33\x61\x63\x63ounts/{AccountId}/testResources/{TestResourceId}*\rtestResources2\x0ctestResource\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"\x1b\n\x0cOuterMessage\x12\x0b\n\x03\x62\x61r\x18\x01 \x01(\t*0\n\tOuterEnum\x12\x1a\n\x16OUTER_ENUM_UNSPECIFIED\x10\x00\x12\x07\n\x03ONE\x10\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.test_resource_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_TESTRESOURCE']._loaded_options = None
  _globals['_TESTRESOURCE']._serialized_options = b'\352Aq\n\035api.fireworks.ai/TestResource\0223accounts/{AccountId}/testResources/{TestResourceId}*\rtestResources2\014testResource\202\361\004\013\n\007Account\030\001'
  _globals['_OUTERENUM']._serialized_start=831
  _globals['_OUTERENUM']._serialized_end=879
  _globals['_TESTRESOURCE']._serialized_start=148
  _globals['_TESTRESOURCE']._serialized_end=800
  _globals['_TESTRESOURCE_INNERMESSAGE']._serialized_start=589
  _globals['_TESTRESOURCE_INNERMESSAGE']._serialized_end=616
  _globals['_TESTRESOURCE_INNERENUM']._serialized_start=618
  _globals['_TESTRESOURCE_INNERENUM']._serialized_end=666
  _globals['_OUTERMESSAGE']._serialized_start=802
  _globals['_OUTERMESSAGE']._serialized_end=829
# @@protoc_insertion_point(module_scope)
