# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/secret.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/secret.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gateway/secret.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\"I\n\x06Secret\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x16\n\x08key_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05value\x18\x03 \x01(\tB\x04\xe2\x41\x01\x04\"R\n\x13\x43reateSecretRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12%\n\x06secret\x18\x02 \x01(\x0b\x32\x0f.gateway.SecretB\x04\xe2\x41\x01\x02\"&\n\x10GetSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x8b\x01\n\x12ListSecretsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"d\n\x13ListSecretsResponse\x12 \n\x07secrets\x18\x01 \x03(\x0b\x32\x0f.gateway.Secret\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"<\n\x13UpdateSecretRequest\x12%\n\x06secret\x18\x01 \x01(\x0b\x32\x0f.gateway.SecretB\x04\xe2\x41\x01\x02\")\n\x13\x44\x65leteSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_SECRET'].fields_by_name['name']._loaded_options = None
  _globals['_SECRET'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_SECRET'].fields_by_name['key_name']._loaded_options = None
  _globals['_SECRET'].fields_by_name['key_name']._serialized_options = b'\342A\001\002'
  _globals['_SECRET'].fields_by_name['value']._loaded_options = None
  _globals['_SECRET'].fields_by_name['value']._serialized_options = b'\342A\001\004'
  _globals['_CREATESECRETREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATESECRETREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATESECRETREQUEST'].fields_by_name['secret']._loaded_options = None
  _globals['_CREATESECRETREQUEST'].fields_by_name['secret']._serialized_options = b'\342A\001\002'
  _globals['_GETSECRETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETSECRETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATESECRETREQUEST'].fields_by_name['secret']._loaded_options = None
  _globals['_UPDATESECRETREQUEST'].fields_by_name['secret']._serialized_options = b'\342A\001\002'
  _globals['_DELETESECRETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETESECRETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_SECRET']._serialized_start=66
  _globals['_SECRET']._serialized_end=139
  _globals['_CREATESECRETREQUEST']._serialized_start=141
  _globals['_CREATESECRETREQUEST']._serialized_end=223
  _globals['_GETSECRETREQUEST']._serialized_start=225
  _globals['_GETSECRETREQUEST']._serialized_end=263
  _globals['_LISTSECRETSREQUEST']._serialized_start=266
  _globals['_LISTSECRETSREQUEST']._serialized_end=405
  _globals['_LISTSECRETSRESPONSE']._serialized_start=407
  _globals['_LISTSECRETSRESPONSE']._serialized_end=507
  _globals['_UPDATESECRETREQUEST']._serialized_start=509
  _globals['_UPDATESECRETREQUEST']._serialized_end=569
  _globals['_DELETESECRETREQUEST']._serialized_start=571
  _globals['_DELETESECRETREQUEST']._serialized_end=612
# @@protoc_insertion_point(module_scope)
