# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/eagle_training_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/eagle_training_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from . import training_pb2 as gateway_dot_training__pb2
from . import wandb_pb2 as gateway_dot_wandb__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n gateway/eagle_training_job.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x18gateway/deployment.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x16gateway/training.proto\x1a\x13gateway/wandb.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb8\x07\n\x10\x45\x61gleTrainingJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0b\x65xpire_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x19\n\ncreated_by\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\'\n\x05state\x18\x06 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x07 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x1f\n\x11input_draft_model\x18\x08 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1e\n\x10training_dataset\x18\t \x01(\tB\x04\xe2\x41\x01\x02\x12\x18\n\nbase_model\x18\n \x01(\tB\x04\xe2\x41\x01\x02\x12 \n\x12output_draft_model\x18\x0b \x01(\tB\x04\xe2\x41\x01\x02\x12)\n\x0c\x65pochs_count\x18\x0c \x01(\x02\x42\x13\xe2\x41\x01\x01\xbaH\x0c\n\n\x1d\x00\x00\xc8\x42-\x00\x00\x00\x00\x12*\n\rlearning_rate\x18\r \x01(\x02\x42\x13\xe2\x41\x01\x01\xbaH\x0c\n\n\x1d\xcd\xcc\xcc=-\x00\x00\x00\x00\x12\x30\n\x0cwandb_config\x18\x0e \x01(\x0b\x32\x14.gateway.WandbConfigB\x04\xe2\x41\x01\x01\x12\x39\n\x11\x65\x61rly_stop_config\x18\x0f \x01(\x0b\x32\x18.gateway.EarlyStopConfigB\x04\xe2\x41\x01\x01\x12N\n\x10\x61\x63\x63\x65lerator_type\x18\x14 \x01(\x0e\x32\x18.gateway.AcceleratorTypeB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x11\x61\x63\x63\x65lerator_count\x18\x15 \x01(\x05\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x0bupdate_time\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03:\x98\x01\xea\x41\x85\x01\n!api.fireworks.ai/EagleTrainingJob\x12;accounts/{AccountId}/eagleTrainingJobs/{EagleTrainingJobId}*\x11\x65\x61gleTrainingJobs2\x10\x65\x61gleTrainingJob\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"0\n\x1aGetEagleTrainingJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x97\x01\n\x1d\x43reateEagleTrainingJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12;\n\x12\x65\x61gle_training_job\x18\x02 \x01(\x0b\x32\x19.gateway.EagleTrainingJobB\x04\xe2\x41\x01\x02\x12#\n\x15\x65\x61gle_training_job_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"\x95\x01\n\x1cListEagleTrainingJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\x84\x01\n\x1dListEagleTrainingJobsResponse\x12\x36\n\x13\x65\x61gle_training_jobs\x18\x01 \x03(\x0b\x32\x19.gateway.EagleTrainingJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x93\x01\n\x1dUpdateEagleTrainingJobRequest\x12;\n\x12\x65\x61gle_training_job\x18\x01 \x01(\x0b\x32\x19.gateway.EagleTrainingJobB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"3\n\x1d\x44\x65leteEagleTrainingJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.eagle_training_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_EAGLETRAININGJOB'].fields_by_name['name']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_EAGLETRAININGJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_EAGLETRAININGJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_EAGLETRAININGJOB'].fields_by_name['expire_time']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['expire_time']._serialized_options = b'\342A\001\003'
  _globals['_EAGLETRAININGJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_EAGLETRAININGJOB'].fields_by_name['state']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_EAGLETRAININGJOB'].fields_by_name['status']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_EAGLETRAININGJOB'].fields_by_name['input_draft_model']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['input_draft_model']._serialized_options = b'\342A\001\002'
  _globals['_EAGLETRAININGJOB'].fields_by_name['training_dataset']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['training_dataset']._serialized_options = b'\342A\001\002'
  _globals['_EAGLETRAININGJOB'].fields_by_name['base_model']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['base_model']._serialized_options = b'\342A\001\002'
  _globals['_EAGLETRAININGJOB'].fields_by_name['output_draft_model']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['output_draft_model']._serialized_options = b'\342A\001\002'
  _globals['_EAGLETRAININGJOB'].fields_by_name['epochs_count']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['epochs_count']._serialized_options = b'\342A\001\001\272H\014\n\n\035\000\000\310B-\000\000\000\000'
  _globals['_EAGLETRAININGJOB'].fields_by_name['learning_rate']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['learning_rate']._serialized_options = b'\342A\001\001\272H\014\n\n\035\315\314\314=-\000\000\000\000'
  _globals['_EAGLETRAININGJOB'].fields_by_name['wandb_config']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['wandb_config']._serialized_options = b'\342A\001\001'
  _globals['_EAGLETRAININGJOB'].fields_by_name['early_stop_config']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['early_stop_config']._serialized_options = b'\342A\001\001'
  _globals['_EAGLETRAININGJOB'].fields_by_name['accelerator_type']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['accelerator_type']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_EAGLETRAININGJOB'].fields_by_name['accelerator_count']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['accelerator_count']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_EAGLETRAININGJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_EAGLETRAININGJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_EAGLETRAININGJOB']._loaded_options = None
  _globals['_EAGLETRAININGJOB']._serialized_options = b'\352A\205\001\n!api.fireworks.ai/EagleTrainingJob\022;accounts/{AccountId}/eagleTrainingJobs/{EagleTrainingJobId}*\021eagleTrainingJobs2\020eagleTrainingJob\202\361\004\013\n\007Account\030\001'
  _globals['_GETEAGLETRAININGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETEAGLETRAININGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEAGLETRAININGJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEEAGLETRAININGJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEAGLETRAININGJOBREQUEST'].fields_by_name['eagle_training_job']._loaded_options = None
  _globals['_CREATEEAGLETRAININGJOBREQUEST'].fields_by_name['eagle_training_job']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEAGLETRAININGJOBREQUEST'].fields_by_name['eagle_training_job_id']._loaded_options = None
  _globals['_CREATEEAGLETRAININGJOBREQUEST'].fields_by_name['eagle_training_job_id']._serialized_options = b'\342A\001\001'
  _globals['_LISTEAGLETRAININGJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTEAGLETRAININGJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTEAGLETRAININGJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTEAGLETRAININGJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTEAGLETRAININGJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTEAGLETRAININGJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTEAGLETRAININGJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTEAGLETRAININGJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTEAGLETRAININGJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTEAGLETRAININGJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEEAGLETRAININGJOBREQUEST'].fields_by_name['eagle_training_job']._loaded_options = None
  _globals['_UPDATEEAGLETRAININGJOBREQUEST'].fields_by_name['eagle_training_job']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEEAGLETRAININGJOBREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEEAGLETRAININGJOBREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEEAGLETRAININGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEEAGLETRAININGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_EAGLETRAININGJOB']._serialized_start=347
  _globals['_EAGLETRAININGJOB']._serialized_end=1299
  _globals['_GETEAGLETRAININGJOBREQUEST']._serialized_start=1301
  _globals['_GETEAGLETRAININGJOBREQUEST']._serialized_end=1349
  _globals['_CREATEEAGLETRAININGJOBREQUEST']._serialized_start=1352
  _globals['_CREATEEAGLETRAININGJOBREQUEST']._serialized_end=1503
  _globals['_LISTEAGLETRAININGJOBSREQUEST']._serialized_start=1506
  _globals['_LISTEAGLETRAININGJOBSREQUEST']._serialized_end=1655
  _globals['_LISTEAGLETRAININGJOBSRESPONSE']._serialized_start=1658
  _globals['_LISTEAGLETRAININGJOBSRESPONSE']._serialized_end=1790
  _globals['_UPDATEEAGLETRAININGJOBREQUEST']._serialized_start=1793
  _globals['_UPDATEEAGLETRAININGJOBREQUEST']._serialized_end=1940
  _globals['_DELETEEAGLETRAININGJOBREQUEST']._serialized_start=1942
  _globals['_DELETEEAGLETRAININGJOBREQUEST']._serialized_end=1993
# @@protoc_insertion_point(module_scope)
