# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/deployment_template.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/deployment_template.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!gateway/deployment_template.proto\x12\x07gateway\x1a\x18gateway/deployment.proto\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x10\n\x12\x44\x65ploymentTemplate\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x19\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12$\n\x11min_replica_count\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00\x88\x01\x01\x12$\n\x11max_replica_count\x18\x07 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x01\x88\x01\x01\x12\x41\n\x12\x61utoscaling_policy\x18\x08 \x01(\x0b\x32\x1a.gateway.AutoscalingPolicyB\x04\xe2\x41\x01\x01H\x02\x88\x01\x01\x12\x1d\n\nbase_model\x18\t \x01(\tB\x04\xe2\x41\x01\x01H\x03\x88\x01\x01\x12$\n\x11\x61\x63\x63\x65lerator_count\x18\x19 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x04\x88\x01\x01\x12=\n\x10\x61\x63\x63\x65lerator_type\x18\x1a \x01(\x0e\x32\x18.gateway.AcceleratorTypeB\x04\xe2\x41\x01\x01H\x05\x88\x01\x01\x12\x1d\n\nworld_size\x18\n \x01(\x05\x42\x04\xe2\x41\x01\x01H\x06\x88\x01\x01\x12\"\n\x0fgenerator_count\x18\x10 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x07\x88\x01\x01\x12.\n\x1b\x64isaggregated_prefill_count\x18\x0b \x01(\x05\x42\x04\xe2\x41\x01\x01H\x08\x88\x01\x01\x12\x33\n disaggregated_prefill_world_size\x18\x0c \x01(\x05\x42\x04\xe2\x41\x01\x01H\t\x88\x01\x01\x12!\n\x0emax_batch_size\x18\r \x01(\x05\x42\x04\xe2\x41\x01\x01H\n\x88\x01\x01\x12&\n\x13max_peft_batch_size\x18\x0e \x01(\x05\x42\x04\xe2\x41\x01\x01H\x0b\x88\x01\x01\x12&\n\x13kv_cache_memory_pct\x18\x0f \x01(\x05\x42\x04\xe2\x41\x01\x01H\x0c\x88\x01\x01\x12 \n\renable_addons\x18\x1b \x01(\x08\x42\x04\xe2\x41\x01\x01H\r\x88\x01\x01\x12\x1e\n\x0b\x64raft_model\x18\x14 \x01(\tB\x04\xe2\x41\x01\x01H\x0e\x88\x01\x01\x12+\n\x18ngram_speculation_length\x18\x1d \x01(\x05\x42\x04\xe2\x41\x01\x01H\x0f\x88\x01\x01\x12$\n\x11\x64raft_token_count\x18\x15 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x10\x88\x01\x01\x12*\n\x17\x65nable_session_affinity\x18\x17 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x11\x88\x01\x01\x12\x1c\n\timage_tag\x18\x18 \x01(\tB\x04\xe2\x41\x01\x01H\x12\x88\x01\x01\x12*\n\x06region\x18\x1e \x01(\x0e\x32\x0f.gateway.RegionB\x04\xe2\x41\x01\x01H\x13\x88\x01\x01\x12#\n\x15\x64irect_route_api_keys\x18\x1f \x03(\tB\x04\xe2\x41\x01\x01\x12>\n\x11\x64irect_route_type\x18! \x01(\x0e\x32\x18.gateway.DirectRouteTypeB\x04\xe2\x41\x01\x01H\x14\x88\x01\x01\x12;\n\tprecision\x18\" \x01(\x0e\x32\x1d.gateway.Deployment.PrecisionB\x04\xe2\x41\x01\x01H\x15\x88\x01\x01\x12\x18\n\nextra_args\x18$ \x03(\tB\x04\xe2\x41\x01\x01\x12H\n\x0c\x65xtra_values\x18% \x03(\x0b\x32,.gateway.DeploymentTemplate.ExtraValuesEntryB\x04\xe2\x41\x01\x01\x12\x35\n\x0bupdate_time\x18# \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12%\n\x12max_context_length\x18& \x01(\x05\x42\x04\xe2\x41\x01\x01H\x16\x88\x01\x01\x1a\x32\n\x10\x45xtraValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:\xa0\x01\xea\x41\x8f\x01\n#api.fireworks.ai/DeploymentTemplate\x12?accounts/{AccountId}/deploymentTemplates/{DeploymentTemplateId}*\x13\x64\x65ploymentTemplates2\x12\x64\x65ploymentTemplate\x82\xf1\x04\t\n\x07\x41\x63\x63ountB\x14\n\x12_min_replica_countB\x14\n\x12_max_replica_countB\x15\n\x13_autoscaling_policyB\r\n\x0b_base_modelB\x14\n\x12_accelerator_countB\x13\n\x11_accelerator_typeB\r\n\x0b_world_sizeB\x12\n\x10_generator_countB\x1e\n\x1c_disaggregated_prefill_countB#\n!_disaggregated_prefill_world_sizeB\x11\n\x0f_max_batch_sizeB\x16\n\x14_max_peft_batch_sizeB\x16\n\x14_kv_cache_memory_pctB\x10\n\x0e_enable_addonsB\x0e\n\x0c_draft_modelB\x1b\n\x19_ngram_speculation_lengthB\x14\n\x12_draft_token_countB\x1a\n\x18_enable_session_affinityB\x0c\n\n_image_tagB\t\n\x07_regionB\x14\n\x12_direct_route_typeB\x0c\n\n_precisionB\x15\n\x13_max_context_length\"\x9d\x01\n\x1f\x43reateDeploymentTemplateRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12>\n\x13\x64\x65ployment_template\x18\x02 \x01(\x0b\x32\x1b.gateway.DeploymentTemplateB\x04\xe2\x41\x01\x02\x12$\n\x16\x64\x65ployment_template_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"2\n\x1cGetDeploymentTemplateRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x97\x01\n\x1eListDeploymentTemplatesRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\x89\x01\n\x1fListDeploymentTemplatesResponse\x12\x39\n\x14\x64\x65ployment_templates\x18\x01 \x03(\x0b\x32\x1b.gateway.DeploymentTemplate\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x98\x01\n\x1fUpdateDeploymentTemplateRequest\x12>\n\x13\x64\x65ployment_template\x18\x01 \x01(\x0b\x32\x1b.gateway.DeploymentTemplateB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"5\n\x1f\x44\x65leteDeploymentTemplateRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.deployment_template_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_DEPLOYMENTTEMPLATE_EXTRAVALUESENTRY']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE_EXTRAVALUESENTRY']._serialized_options = b'8\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['name']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['display_name']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['description']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['description']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['create_time']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['created_by']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['min_replica_count']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['min_replica_count']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['max_replica_count']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['max_replica_count']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['autoscaling_policy']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['autoscaling_policy']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['base_model']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['base_model']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['accelerator_count']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['accelerator_count']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['accelerator_type']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['accelerator_type']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['world_size']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['world_size']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['generator_count']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['generator_count']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['disaggregated_prefill_count']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['disaggregated_prefill_count']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['disaggregated_prefill_world_size']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['disaggregated_prefill_world_size']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['max_batch_size']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['max_batch_size']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['max_peft_batch_size']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['max_peft_batch_size']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['kv_cache_memory_pct']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['kv_cache_memory_pct']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['enable_addons']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['enable_addons']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['draft_model']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['draft_model']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['ngram_speculation_length']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['ngram_speculation_length']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['draft_token_count']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['draft_token_count']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['enable_session_affinity']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['enable_session_affinity']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['image_tag']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['image_tag']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['region']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['region']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['direct_route_api_keys']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['direct_route_api_keys']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['direct_route_type']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['direct_route_type']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['precision']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['precision']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['extra_args']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['extra_args']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['extra_values']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['extra_values']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['update_time']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['max_context_length']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE'].fields_by_name['max_context_length']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYMENTTEMPLATE']._loaded_options = None
  _globals['_DEPLOYMENTTEMPLATE']._serialized_options = b'\352A\217\001\n#api.fireworks.ai/DeploymentTemplate\022?accounts/{AccountId}/deploymentTemplates/{DeploymentTemplateId}*\023deploymentTemplates2\022deploymentTemplate\202\361\004\t\n\007Account'
  _globals['_CREATEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['deployment_template']._loaded_options = None
  _globals['_CREATEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['deployment_template']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['deployment_template_id']._loaded_options = None
  _globals['_CREATEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['deployment_template_id']._serialized_options = b'\342A\001\002'
  _globals['_GETDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['deployment_template']._loaded_options = None
  _globals['_UPDATEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['deployment_template']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEDEPLOYMENTTEMPLATEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DEPLOYMENTTEMPLATE']._serialized_start=223
  _globals['_DEPLOYMENTTEMPLATE']._serialized_end=2291
  _globals['_DEPLOYMENTTEMPLATE_EXTRAVALUESENTRY']._serialized_start=1585
  _globals['_DEPLOYMENTTEMPLATE_EXTRAVALUESENTRY']._serialized_end=1635
  _globals['_CREATEDEPLOYMENTTEMPLATEREQUEST']._serialized_start=2294
  _globals['_CREATEDEPLOYMENTTEMPLATEREQUEST']._serialized_end=2451
  _globals['_GETDEPLOYMENTTEMPLATEREQUEST']._serialized_start=2453
  _globals['_GETDEPLOYMENTTEMPLATEREQUEST']._serialized_end=2503
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST']._serialized_start=2506
  _globals['_LISTDEPLOYMENTTEMPLATESREQUEST']._serialized_end=2657
  _globals['_LISTDEPLOYMENTTEMPLATESRESPONSE']._serialized_start=2660
  _globals['_LISTDEPLOYMENTTEMPLATESRESPONSE']._serialized_end=2797
  _globals['_UPDATEDEPLOYMENTTEMPLATEREQUEST']._serialized_start=2800
  _globals['_UPDATEDEPLOYMENTTEMPLATEREQUEST']._serialized_end=2952
  _globals['_DELETEDEPLOYMENTTEMPLATEREQUEST']._serialized_start=2954
  _globals['_DELETEDEPLOYMENTTEMPLATEREQUEST']._serialized_end=3007
# @@protoc_insertion_point(module_scope)
