# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/reservation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/reservation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gateway/reservation.proto\x12\x07gateway\x1a\x18gateway/deployment.proto\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf8\x04\n\x0bReservation\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x19\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12%\n\x06region\x18\r \x01(\x0e\x32\x0f.gateway.RegionB\x04\xe2\x41\x01\x02\x12\x38\n\x10\x61\x63\x63\x65lerator_type\x18\x06 \x01(\x0e\x32\x18.gateway.AcceleratorTypeB\x04\xe2\x41\x01\x02\x12\x1c\n\x0ereserved_count\x18\x07 \x01(\x05\x42\x04\xe2\x41\x01\x02\x12\x34\n\nstart_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\x32\n\x08\x65nd_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12,\n\x08\x63ontract\x18\x0c \x01(\tB\x1a\xe2\x41\x01\x02\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x0bupdate_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03:|\xea\x41l\n\x1c\x61pi.fireworks.ai/Reservation\x12\x31\x61\x63\x63ounts/{AccountId}/reservations/{ReservationId}*\x0creservations2\x0breservation\x82\xf1\x04\t\n\x07\x41\x63\x63ount\"+\n\x15GetReservationRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x90\x01\n\x17ListReservationsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"s\n\x18ListReservationsResponse\x12*\n\x0creservations\x18\x01 \x03(\x0b\x32\x14.gateway.Reservation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.reservation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_RESERVATION'].fields_by_name['name']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_RESERVATION'].fields_by_name['display_name']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_RESERVATION'].fields_by_name['description']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['description']._serialized_options = b'\342A\001\001'
  _globals['_RESERVATION'].fields_by_name['create_time']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_RESERVATION'].fields_by_name['created_by']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_RESERVATION'].fields_by_name['region']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['region']._serialized_options = b'\342A\001\002'
  _globals['_RESERVATION'].fields_by_name['accelerator_type']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['accelerator_type']._serialized_options = b'\342A\001\002'
  _globals['_RESERVATION'].fields_by_name['reserved_count']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['reserved_count']._serialized_options = b'\342A\001\002'
  _globals['_RESERVATION'].fields_by_name['start_time']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['start_time']._serialized_options = b'\342A\001\001'
  _globals['_RESERVATION'].fields_by_name['end_time']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['end_time']._serialized_options = b'\342A\001\001'
  _globals['_RESERVATION'].fields_by_name['contract']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['contract']._serialized_options = b'\342A\001\002\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_RESERVATION'].fields_by_name['update_time']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_RESERVATION']._loaded_options = None
  _globals['_RESERVATION']._serialized_options = b'\352Al\n\034api.fireworks.ai/Reservation\0221accounts/{AccountId}/reservations/{ReservationId}*\014reservations2\013reservation\202\361\004\t\n\007Account'
  _globals['_GETRESERVATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETRESERVATIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_RESERVATION']._serialized_start=210
  _globals['_RESERVATION']._serialized_end=842
  _globals['_GETRESERVATIONREQUEST']._serialized_start=844
  _globals['_GETRESERVATIONREQUEST']._serialized_end=887
  _globals['_LISTRESERVATIONSREQUEST']._serialized_start=890
  _globals['_LISTRESERVATIONSREQUEST']._serialized_end=1034
  _globals['_LISTRESERVATIONSRESPONSE']._serialized_start=1036
  _globals['_LISTRESERVATIONSRESPONSE']._serialized_end=1151
# @@protoc_insertion_point(module_scope)
