# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/cluster.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8c\x06\n\x07\x43luster\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12*\n\x0b\x65ks_cluster\x18\x07 \x01(\x0b\x32\x13.gateway.EksClusterH\x00\x12,\n\x0c\x66\x61ke_cluster\x18\x03 \x01(\x0b\x32\x14.gateway.FakeClusterH\x00\x12M\n\x0b\x61nnotations\x18\n \x03(\x0b\x32!.gateway.Cluster.AnnotationsEntryB\x15\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12,\n\x05state\x18\x05 \x01(\x0e\x32\x16.gateway.Cluster.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12,\n\x07is_dlde\x18\x0b \x01(\x08\x42\x1b\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x31\n\x0cmetering_key\x18\r \x01(\tB\x1b\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x0bupdate_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04:j\xea\x41X\n\x18\x61pi.fireworks.ai/Cluster\x12)accounts/{AccountId}/clusters/{ClusterId}*\x08\x63lusters2\x07\x63luster\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\x42\x0e\n\x0c\x63luster_type\"\xf8\x04\n\nEksCluster\x12\x1d\n\x0e\x61ws_account_id\x18\t \x01(\tB\x05\xe2\x41\x02\x02\x05\x12%\n\x16\x66ireworks_manager_role\x18\x01 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x15\n\x06region\x18\x02 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12,\n\x0c\x63luster_role\x18\x04 \x01(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12\x37\n\x17\x63luster_autoscaler_role\x18\n \x01(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12\x30\n\x10system_node_role\x18\x07 \x01(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12*\n\nsubnet_ids\x18\x05 \x03(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12\x1b\n\x0c\x63luster_name\x18\x03 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12/\n\x0frepository_name\x18\x06 \x01(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12\"\n\x13storage_bucket_name\x18\x08 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x33\n\x13node_security_group\x18\x0b \x01(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12!\n\x12metric_writer_role\x18\x0c \x01(\tB\x05\xe2\x41\x02\x01\x05\x12,\n\x1dload_balancer_controller_role\x18\r \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x31\n\"workload_identity_pool_provider_id\x18\x0e \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x1d\n\x0einference_role\x18\x0f \x01(\tB\x05\xe2\x41\x02\x01\x05\"I\n\x0b\x46\x61keCluster\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x14\n\x0c\x63luster_name\x18\x03 \x01(\t\"o\n\x14\x43reateClusterRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\'\n\x07\x63luster\x18\x02 \x01(\x0b\x32\x10.gateway.ClusterB\x04\xe2\x41\x01\x02\x12\x18\n\ncluster_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"\'\n\x11GetClusterRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x8c\x01\n\x13ListClustersRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"g\n\x14ListClustersResponse\x12\"\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x10.gateway.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"v\n\x14UpdateClusterRequest\x12\'\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.gateway.ClusterB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"*\n\x14\x44\x65leteClusterRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"5\n\x1fGetClusterConnectionInfoRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\":\n\x15\x43lusterConnectionInfo\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61_data\x18\x02 \x01(\tBCZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_CLUSTER_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_CLUSTER_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER'].fields_by_name['name']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_CLUSTER'].fields_by_name['display_name']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_CLUSTER'].fields_by_name['create_time']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_CLUSTER'].fields_by_name['annotations']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['annotations']._serialized_options = b'\342A\001\001\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_CLUSTER'].fields_by_name['state']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_CLUSTER'].fields_by_name['status']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_CLUSTER'].fields_by_name['is_dlde']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['is_dlde']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_CLUSTER'].fields_by_name['metering_key']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['metering_key']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_CLUSTER'].fields_by_name['update_time']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_CLUSTER']._loaded_options = None
  _globals['_CLUSTER']._serialized_options = b'\352AX\n\030api.fireworks.ai/Cluster\022)accounts/{AccountId}/clusters/{ClusterId}*\010clusters2\007cluster\202\361\004\013\n\007Account\030\001'
  _globals['_EKSCLUSTER'].fields_by_name['aws_account_id']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['aws_account_id']._serialized_options = b'\342A\002\002\005'
  _globals['_EKSCLUSTER'].fields_by_name['fireworks_manager_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['fireworks_manager_role']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['region']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['region']._serialized_options = b'\342A\002\002\005'
  _globals['_EKSCLUSTER'].fields_by_name['cluster_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['cluster_role']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['cluster_autoscaler_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['cluster_autoscaler_role']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['system_node_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['system_node_role']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['subnet_ids']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['subnet_ids']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['cluster_name']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['cluster_name']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['repository_name']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['repository_name']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['storage_bucket_name']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['storage_bucket_name']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['node_security_group']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['node_security_group']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['metric_writer_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['metric_writer_role']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['load_balancer_controller_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['load_balancer_controller_role']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['workload_identity_pool_provider_id']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['workload_identity_pool_provider_id']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['inference_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['inference_role']._serialized_options = b'\342A\002\001\005'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['cluster']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['cluster']._serialized_options = b'\342A\001\002'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\342A\001\002'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster']._serialized_options = b'\342A\001\002'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETCLUSTERCONNECTIONINFOREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETCLUSTERCONNECTIONINFOREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CLUSTER']._serialized_start=236
  _globals['_CLUSTER']._serialized_end=1016
  _globals['_CLUSTER_ANNOTATIONSENTRY']._serialized_start=759
  _globals['_CLUSTER_ANNOTATIONSENTRY']._serialized_end=809
  _globals['_CLUSTER_STATE']._serialized_start=811
  _globals['_CLUSTER_STATE']._serialized_end=892
  _globals['_EKSCLUSTER']._serialized_start=1019
  _globals['_EKSCLUSTER']._serialized_end=1651
  _globals['_FAKECLUSTER']._serialized_start=1653
  _globals['_FAKECLUSTER']._serialized_end=1726
  _globals['_CREATECLUSTERREQUEST']._serialized_start=1728
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1839
  _globals['_GETCLUSTERREQUEST']._serialized_start=1841
  _globals['_GETCLUSTERREQUEST']._serialized_end=1880
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=1883
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=2023
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=2025
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=2128
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=2130
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2248
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2250
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2292
  _globals['_GETCLUSTERCONNECTIONINFOREQUEST']._serialized_start=2294
  _globals['_GETCLUSTERCONNECTIONINFOREQUEST']._serialized_end=2347
  _globals['_CLUSTERCONNECTIONINFO']._serialized_start=2349
  _globals['_CLUSTERCONNECTIONINFO']._serialized_end=2407
# @@protoc_insertion_point(module_scope)
