# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/evaluator.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/evaluator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/evaluator.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9c\x04\n\tEvaluator\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x36\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12-\n\x05state\x18\x07 \x01(\x0e\x32\x17.gateway.EvaluatorStateB\x05\xe2\x41\x02\x03\x05\x12\x1b\n\rmulti_metrics\x18\x08 \x01(\x08\x42\x04\xe2\x41\x01\x05\x12*\n\x08\x63riteria\x18\t \x03(\x0b\x32\x12.gateway.CriterionB\x04\xe2\x41\x01\x05\x12\x1a\n\x0crequirements\x18\n \x01(\tB\x04\xe2\x41\x01\x01\x12;\n\x0frollup_settings\x18\x0b \x01(\x0b\x32\x17.gateway.RollupSettingsB\t\xe2\x41\x02\x05\x01\xa0\xf1\x04\x01:t\xea\x41\x62\n\x1a\x61pi.fireworks.ai/Evaluator\x12-accounts/{AccountId}/evaluators/{EvaluatorId}*\nEvaluators2\tEvaluator\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"\xb4\x01\n\tCriterion\x12%\n\x04type\x18\x01 \x01(\x0e\x32\x17.gateway.Criterion.Type\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12,\n\rcode_snippets\x18\x04 \x01(\x0b\x32\x15.gateway.CodeSnippets\"/\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x11\n\rCODE_SNIPPETS\x10\x01\"\x95\x01\n\x0c\x43odeSnippets\x12\x10\n\x08language\x18\x01 \x01(\t\x12>\n\rfile_contents\x18\x02 \x03(\x0b\x32\'.gateway.CodeSnippets.FileContentsEntry\x1a\x33\n\x11\x46ileContentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xed\x01\n\x0eRollupSettings\x12L\n\x10\x63riteria_weights\x18\x01 \x03(\x0b\x32,.gateway.RollupSettings.CriteriaWeightsEntryB\x04\xe2\x41\x01\x01\x12\x19\n\x0bpython_code\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1f\n\x11success_threshold\x18\x03 \x01(\x02\x42\x04\xe2\x41\x01\x01\x12\x19\n\x0bskip_rollup\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x01\x1a\x36\n\x14\x43riteriaWeightsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\")\n\x13GetEvaluatorRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x8e\x01\n\x15ListEvaluatorsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"m\n\x16ListEvaluatorsResponse\x12&\n\nevaluators\x18\x01 \x03(\x0b\x32\x12.gateway.Evaluator\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"w\n\x16\x43reateEvaluatorRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12+\n\tevaluator\x18\x02 \x01(\x0b\x32\x12.gateway.EvaluatorB\x04\xe2\x41\x01\x02\x12\x1a\n\x0c\x65valuator_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\",\n\x16\x44\x65leteEvaluatorRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x92\x01\n\x17PreviewEvaluatorRequest\x12+\n\tevaluator\x18\x01 \x01(\x0b\x32\x12.gateway.EvaluatorB\x04\xe2\x41\x01\x02\x12\x19\n\x0bsample_data\x18\x02 \x03(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0bmax_samples\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x14\n\x06parent\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02\"\xe3\x01\n\x1cPreviewEvaluatorSampleResult\x12\x0f\n\x07success\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x01\x12S\n\x10per_metric_evals\x18\x03 \x03(\x0b\x32\x39.gateway.PreviewEvaluatorSampleResult.PerMetricEvalsEntry\x1aN\n\x13PerMetricEvalsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\"\xa3\x01\n\x18PreviewEvaluatorResponse\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.gateway.PreviewEvaluatorSampleResult\x12\x15\n\rtotal_samples\x18\x02 \x01(\x05\x12\x18\n\x10total_runtime_ms\x18\x03 \x01(\x03\x12\x0e\n\x06stdout\x18\x04 \x03(\t\x12\x0e\n\x06stderr\x18\x05 \x03(\t*3\n\x0e\x45valuatorState\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.evaluator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_EVALUATOR'].fields_by_name['name']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATOR'].fields_by_name['create_time']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATOR'].fields_by_name['created_by']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATOR'].fields_by_name['update_time']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_EVALUATOR'].fields_by_name['state']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATOR'].fields_by_name['multi_metrics']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['multi_metrics']._serialized_options = b'\342A\001\005'
  _globals['_EVALUATOR'].fields_by_name['criteria']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['criteria']._serialized_options = b'\342A\001\005'
  _globals['_EVALUATOR'].fields_by_name['requirements']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['requirements']._serialized_options = b'\342A\001\001'
  _globals['_EVALUATOR'].fields_by_name['rollup_settings']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['rollup_settings']._serialized_options = b'\342A\002\005\001\240\361\004\001'
  _globals['_EVALUATOR']._loaded_options = None
  _globals['_EVALUATOR']._serialized_options = b'\352Ab\n\032api.fireworks.ai/Evaluator\022-accounts/{AccountId}/evaluators/{EvaluatorId}*\nEvaluators2\tEvaluator\202\361\004\013\n\007Account\030\001'
  _globals['_CODESNIPPETS_FILECONTENTSENTRY']._loaded_options = None
  _globals['_CODESNIPPETS_FILECONTENTSENTRY']._serialized_options = b'8\001'
  _globals['_ROLLUPSETTINGS_CRITERIAWEIGHTSENTRY']._loaded_options = None
  _globals['_ROLLUPSETTINGS_CRITERIAWEIGHTSENTRY']._serialized_options = b'8\001'
  _globals['_ROLLUPSETTINGS'].fields_by_name['criteria_weights']._loaded_options = None
  _globals['_ROLLUPSETTINGS'].fields_by_name['criteria_weights']._serialized_options = b'\342A\001\001'
  _globals['_ROLLUPSETTINGS'].fields_by_name['python_code']._loaded_options = None
  _globals['_ROLLUPSETTINGS'].fields_by_name['python_code']._serialized_options = b'\342A\001\001'
  _globals['_ROLLUPSETTINGS'].fields_by_name['success_threshold']._loaded_options = None
  _globals['_ROLLUPSETTINGS'].fields_by_name['success_threshold']._serialized_options = b'\342A\001\001'
  _globals['_ROLLUPSETTINGS'].fields_by_name['skip_rollup']._loaded_options = None
  _globals['_ROLLUPSETTINGS'].fields_by_name['skip_rollup']._serialized_options = b'\342A\001\001'
  _globals['_GETEVALUATORREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETEVALUATORREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['evaluator']._loaded_options = None
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['evaluator']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['evaluator_id']._loaded_options = None
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['evaluator_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEEVALUATORREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEEVALUATORREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['evaluator']._loaded_options = None
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['evaluator']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['sample_data']._loaded_options = None
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['sample_data']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['max_samples']._loaded_options = None
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['max_samples']._serialized_options = b'\342A\001\001'
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATORSAMPLERESULT_PERMETRICEVALSENTRY']._loaded_options = None
  _globals['_PREVIEWEVALUATORSAMPLERESULT_PERMETRICEVALSENTRY']._serialized_options = b'8\001'
  _globals['_EVALUATORSTATE']._serialized_start=2311
  _globals['_EVALUATORSTATE']._serialized_end=2362
  _globals['_EVALUATOR']._serialized_start=183
  _globals['_EVALUATOR']._serialized_end=723
  _globals['_CRITERION']._serialized_start=726
  _globals['_CRITERION']._serialized_end=906
  _globals['_CRITERION_TYPE']._serialized_start=859
  _globals['_CRITERION_TYPE']._serialized_end=906
  _globals['_CODESNIPPETS']._serialized_start=909
  _globals['_CODESNIPPETS']._serialized_end=1058
  _globals['_CODESNIPPETS_FILECONTENTSENTRY']._serialized_start=1007
  _globals['_CODESNIPPETS_FILECONTENTSENTRY']._serialized_end=1058
  _globals['_ROLLUPSETTINGS']._serialized_start=1061
  _globals['_ROLLUPSETTINGS']._serialized_end=1298
  _globals['_ROLLUPSETTINGS_CRITERIAWEIGHTSENTRY']._serialized_start=1244
  _globals['_ROLLUPSETTINGS_CRITERIAWEIGHTSENTRY']._serialized_end=1298
  _globals['_GETEVALUATORREQUEST']._serialized_start=1300
  _globals['_GETEVALUATORREQUEST']._serialized_end=1341
  _globals['_LISTEVALUATORSREQUEST']._serialized_start=1344
  _globals['_LISTEVALUATORSREQUEST']._serialized_end=1486
  _globals['_LISTEVALUATORSRESPONSE']._serialized_start=1488
  _globals['_LISTEVALUATORSRESPONSE']._serialized_end=1597
  _globals['_CREATEEVALUATORREQUEST']._serialized_start=1599
  _globals['_CREATEEVALUATORREQUEST']._serialized_end=1718
  _globals['_DELETEEVALUATORREQUEST']._serialized_start=1720
  _globals['_DELETEEVALUATORREQUEST']._serialized_end=1764
  _globals['_PREVIEWEVALUATORREQUEST']._serialized_start=1767
  _globals['_PREVIEWEVALUATORREQUEST']._serialized_end=1913
  _globals['_PREVIEWEVALUATORSAMPLERESULT']._serialized_start=1916
  _globals['_PREVIEWEVALUATORSAMPLERESULT']._serialized_end=2143
  _globals['_PREVIEWEVALUATORSAMPLERESULT_PERMETRICEVALSENTRY']._serialized_start=2065
  _globals['_PREVIEWEVALUATORSAMPLERESULT_PERMETRICEVALSENTRY']._serialized_end=2143
  _globals['_PREVIEWEVALUATORRESPONSE']._serialized_start=2146
  _globals['_PREVIEWEVALUATORRESPONSE']._serialized_end=2309
# @@protoc_insertion_point(module_scope)
