# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/alert_rule.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/alert_rule.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gateway/alert_rule.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe1\x03\n\tAlertRule\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\'\n\x18\x61lert_rule_configuration\x18\x02 \x01(\tB\x05\xe2\x41\x02\x05\x02\x12\x17\n\tthreshold\x18\x03 \x01(\x01\x42\x04\xe2\x41\x01\x02\x12\x16\n\x08\x64uration\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02\x12\x15\n\x07\x65nabled\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x02\x12&\n\x07\x66ilters\x18\x06 \x03(\x0b\x32\x0f.gateway.FilterB\x04\xe2\x41\x01\x01\x12#\n\x15notification_channels\x18\x07 \x03(\tB\x04\xe2\x41\x01\x01\x12\x35\n\x0b\x63reate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x35\n\x0bupdate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03:\x92\x01\xea\x41}\n\x1a\x61pi.fireworks.ai/AlertRule\x12Haccounts/{AccountId}/deployments/{DeploymentId}/alertRules/{AlertRuleId}*\nalertRules2\talertRule\x82\xf1\x04\x0e\n\nDeployment\x18\x01\"\xe9\x01\n\x06\x46ilter\x12\x11\n\x03key\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05value\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x30\n\x08operator\x18\x03 \x01(\x0e\x32\x18.gateway.Filter.OperatorB\x04\xe2\x41\x01\x02\"\x84\x01\n\x08Operator\x12\x18\n\x14OPERATOR_UNSPECIFIED\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x0f\n\x0b\x45QUAL_REGEX\x10\x03\x12\x13\n\x0fNOT_EQUAL_REGEX\x10\x04\x12\x0c\n\x08\x43ONTAINS\x10\x05\x12\x10\n\x0cNOT_CONTAINS\x10\x06\"\x85\x07\n\x16\x41lertRuleConfiguration\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x38\n\x04kind\x18\x02 \x01(\x0e\x32$.gateway.AlertRuleConfiguration.KindB\x04\xe2\x41\x01\x02\x12p\n\x1fmonitoring_policy_configuration\x18\x03 \x01(\x0b\x32=.gateway.AlertRuleConfiguration.MonitoringPolicyConfigurationB\x08\xe2\x41\x01\x02\xa0\xf1\x04\x01\x12\x35\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x35\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a\xbc\x02\n\x1dMonitoringPolicyConfiguration\x12\x1b\n\rdocumentation\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x16\n\x08\x63ombiner\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\x12\x15\n\x07\x61ligner\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02\x12\x18\n\ncomparison\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1e\n\x10\x61lignment_period\x18\x06 \x01(\tB\x04\xe2\x41\x01\x02\x12\x18\n\nexpression\x18\x07 \x01(\tB\x04\xe2\x41\x01\x02\x12\x16\n\x08severity\x18\x08 \x01(\tB\x04\xe2\x41\x01\x01\x12#\n\x15notification_channels\x18\t \x03(\tB\x04\xe2\x41\x01\x01\x12\"\n\x14\x64\x65ployment_label_key\x18\n \x01(\tB\x04\xe2\x41\x01\x01\"d\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x14\n\x10MISSING_REPLICAS\x10\x01\x12\x14\n\x10HIGH_ERROR_COUNT\x10\x02\x12\x1a\n\x16HIGH_PERPLEXITY_OUTPUT\x10\x03:\x96\x01\xea\x41\x8e\x01\n\'api.fireworks.ai/AlertRuleConfiguration\x12\x32\x61lertRuleConfigurations/{AlertRuleConfigurationId}*\x17\x61lertRuleConfigurations2\x16\x61lertRuleConfiguration\x82\xf1\x04\x00\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.alert_rule_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_ALERTRULE'].fields_by_name['name']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_ALERTRULE'].fields_by_name['alert_rule_configuration']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['alert_rule_configuration']._serialized_options = b'\342A\002\005\002'
  _globals['_ALERTRULE'].fields_by_name['threshold']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['threshold']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULE'].fields_by_name['duration']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['duration']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULE'].fields_by_name['enabled']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['enabled']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULE'].fields_by_name['filters']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['filters']._serialized_options = b'\342A\001\001'
  _globals['_ALERTRULE'].fields_by_name['notification_channels']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['notification_channels']._serialized_options = b'\342A\001\001'
  _globals['_ALERTRULE'].fields_by_name['create_time']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_ALERTRULE'].fields_by_name['update_time']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_ALERTRULE']._loaded_options = None
  _globals['_ALERTRULE']._serialized_options = b'\352A}\n\032api.fireworks.ai/AlertRule\022Haccounts/{AccountId}/deployments/{DeploymentId}/alertRules/{AlertRuleId}*\nalertRules2\talertRule\202\361\004\016\n\nDeployment\030\001'
  _globals['_FILTER'].fields_by_name['key']._loaded_options = None
  _globals['_FILTER'].fields_by_name['key']._serialized_options = b'\342A\001\002'
  _globals['_FILTER'].fields_by_name['value']._loaded_options = None
  _globals['_FILTER'].fields_by_name['value']._serialized_options = b'\342A\001\002'
  _globals['_FILTER'].fields_by_name['operator']._loaded_options = None
  _globals['_FILTER'].fields_by_name['operator']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['documentation']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['documentation']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['display_name']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['display_name']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['combiner']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['combiner']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['aligner']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['aligner']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['comparison']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['comparison']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['alignment_period']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['alignment_period']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['expression']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['expression']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['severity']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['severity']._serialized_options = b'\342A\001\001'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['notification_channels']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['notification_channels']._serialized_options = b'\342A\001\001'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['deployment_label_key']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['deployment_label_key']._serialized_options = b'\342A\001\001'
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['name']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['kind']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['kind']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['monitoring_policy_configuration']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['monitoring_policy_configuration']._serialized_options = b'\342A\001\002\240\361\004\001'
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['create_time']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['update_time']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_ALERTRULECONFIGURATION']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION']._serialized_options = b'\352A\216\001\n\'api.fireworks.ai/AlertRuleConfiguration\0222alertRuleConfigurations/{AlertRuleConfigurationId}*\027alertRuleConfigurations2\026alertRuleConfiguration\202\361\004\000'
  _globals['_ALERTRULE']._serialized_start=154
  _globals['_ALERTRULE']._serialized_end=635
  _globals['_FILTER']._serialized_start=638
  _globals['_FILTER']._serialized_end=871
  _globals['_FILTER_OPERATOR']._serialized_start=739
  _globals['_FILTER_OPERATOR']._serialized_end=871
  _globals['_ALERTRULECONFIGURATION']._serialized_start=874
  _globals['_ALERTRULECONFIGURATION']._serialized_end=1775
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION']._serialized_start=1204
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION']._serialized_end=1520
  _globals['_ALERTRULECONFIGURATION_KIND']._serialized_start=1522
  _globals['_ALERTRULECONFIGURATION_KIND']._serialized_end=1622
# @@protoc_insertion_point(module_scope)
