# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/dataset_validation_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/dataset_validation_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$gateway/dataset_validation_job.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xba\x05\n\x14\x44\x61tasetValidationJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x04 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\'\n\x05state\x18\x05 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x1b\n\x0c\x64\x61taset_name\x18\x07 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x37\n\x06\x66ormat\x18\x08 \x01(\x0e\x32 .gateway.DatasetValidationFormatB\x05\xe2\x41\x02\x02\x05\x12:\n\x06result\x18\t \x01(\x0e\x32#.gateway.DatasetValidationJobResultB\x05\xe2\x41\x02\x03\x05\x12\x1f\n\x10validation_error\x18\n \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1c\n\rdataset_names\x18\x0b \x03(\tB\x05\xe2\x41\x02\x01\x05\x12\x35\n\x0bupdate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x16\n\x07rewards\x18\x18 \x03(\tB\x05\xe2\x41\x02\x01\x05:\xac\x01\xea\x41\x99\x01\n%api.fireworks.ai/DatasetValidationJob\x12\x43\x61\x63\x63ounts/{AccountId}/DatasetValidationJobs/{DatasetValidationJobId}*\x15\x44\x61tasetValidationJobs2\x14\x44\x61tasetValidationJob\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"4\n\x1eGetDatasetValidationJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xa7\x01\n!CreateDatasetValidationJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x43\n\x16\x64\x61taset_validation_job\x18\x02 \x01(\x0b\x32\x1d.gateway.DatasetValidationJobB\x04\xe2\x41\x01\x02\x12\'\n\x19\x64\x61taset_validation_job_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"\x99\x01\n ListDatasetValidationJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\x90\x01\n!ListDatasetValidationJobsResponse\x12>\n\x17\x64\x61taset_validation_jobs\x18\x01 \x03(\x0b\x32\x1d.gateway.DatasetValidationJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"7\n!DeleteDatasetValidationJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02*\xb6\x02\n\x17\x44\x61tasetValidationFormat\x12)\n%DATASET_VALIDATION_FORMAT_UNSPECIFIED\x10\x00\x12\"\n\x1e\x44\x41TASET_VALIDATION_FORMAT_CHAT\x10\x01\x12*\n&DATASET_VALIDATION_FORMAT_CHAT_RELAXED\x10\x02\x12\"\n\x1e\x44\x41TASET_VALIDATION_FORMAT_RLOR\x10\x03\x12\x34\n0DATASET_VALIDATION_FORMAT_BATCH_INFERENCE_STRICT\x10\x04\x12\x46\nBDATASET_VALIDATION_FORMAT_BATCH_INFERENCE_ALLOW_TRAILING_ASSISTANT\x10\x05*\xa1\x01\n\x1a\x44\x61tasetValidationJobResult\x12-\n)DATASET_VALIDATION_JOB_RESULT_UNSPECIFIED\x10\x00\x12)\n%DATASET_VALIDATION_JOB_RESULT_SUCCESS\x10\x01\x12)\n%DATASET_VALIDATION_JOB_RESULT_FAILURE\x10\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.dataset_validation_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['name']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['state']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['status']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['dataset_name']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['dataset_name']._serialized_options = b'\342A\002\002\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['format']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['format']._serialized_options = b'\342A\002\002\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['result']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['result']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['validation_error']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['validation_error']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['dataset_names']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['dataset_names']._serialized_options = b'\342A\002\001\005'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['rewards']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB'].fields_by_name['rewards']._serialized_options = b'\342A\002\001\005'
  _globals['_DATASETVALIDATIONJOB']._loaded_options = None
  _globals['_DATASETVALIDATIONJOB']._serialized_options = b'\352A\231\001\n%api.fireworks.ai/DatasetValidationJob\022Caccounts/{AccountId}/DatasetValidationJobs/{DatasetValidationJobId}*\025DatasetValidationJobs2\024DatasetValidationJob\202\361\004\013\n\007Account\030\001'
  _globals['_GETDATASETVALIDATIONJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDATASETVALIDATIONJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['dataset_validation_job']._loaded_options = None
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['dataset_validation_job']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['dataset_validation_job_id']._loaded_options = None
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST'].fields_by_name['dataset_validation_job_id']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETEDATASETVALIDATIONJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEDATASETVALIDATIONJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DATASETVALIDATIONFORMAT']._serialized_start=1473
  _globals['_DATASETVALIDATIONFORMAT']._serialized_end=1783
  _globals['_DATASETVALIDATIONJOBRESULT']._serialized_start=1786
  _globals['_DATASETVALIDATIONJOBRESULT']._serialized_end=1947
  _globals['_DATASETVALIDATIONJOB']._serialized_start=188
  _globals['_DATASETVALIDATIONJOB']._serialized_end=886
  _globals['_GETDATASETVALIDATIONJOBREQUEST']._serialized_start=888
  _globals['_GETDATASETVALIDATIONJOBREQUEST']._serialized_end=940
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST']._serialized_start=943
  _globals['_CREATEDATASETVALIDATIONJOBREQUEST']._serialized_end=1110
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST']._serialized_start=1113
  _globals['_LISTDATASETVALIDATIONJOBSREQUEST']._serialized_end=1266
  _globals['_LISTDATASETVALIDATIONJOBSRESPONSE']._serialized_start=1269
  _globals['_LISTDATASETVALIDATIONJOBSRESPONSE']._serialized_end=1413
  _globals['_DELETEDATASETVALIDATIONJOBREQUEST']._serialized_start=1415
  _globals['_DELETEDATASETVALIDATIONJOBREQUEST']._serialized_end=1470
# @@protoc_insertion_point(module_scope)
