# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/rlor_trainer_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/rlor_trainer_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import job_progress_pb2 as gateway_dot_job__progress__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from . import training_pb2 as gateway_dot_training__pb2
from . import wandb_pb2 as gateway_dot_wandb__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egateway/rlor_trainer_job.proto\x12\x07gateway\x1a\x1agateway/job_progress.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x16gateway/training.proto\x1a\x13gateway/wandb.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa6\x06\n\x0eRlorTrainerJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x39\n\x0e\x63ompleted_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x15\n\x07\x64\x61taset\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02\x12 \n\x12\x65valuation_dataset\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01\x12 \n\x12\x65val_auto_carveout\x18\x07 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\'\n\x05state\x18\x08 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\t \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\n \x01(\tB\x05\xe2\x41\x02\x03\x05\x12:\n\x0ftraining_config\x18\x0b \x01(\x0b\x32\x1b.gateway.BaseTrainingConfigB\x04\xe2\x41\x01\x01\x12\x1a\n\x0ereward_weights\x18\x0c \x03(\tB\x02\x18\x01\x12\x30\n\x0cwandb_config\x18\r \x01(\x0b\x32\x14.gateway.WandbConfigB\x04\xe2\x41\x01\x01\x12\x46\n\"reinforcement_fine_tuning_epoch_id\x18\x0e \x01(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12G\n\x0cjob_progress\x18\x0f \x01(\x0b\x32\x14.gateway.JobProgressB\x1b\xe2\x41\x02\x03\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY:\x8d\x01\xea\x41{\n\x1f\x61pi.fireworks.ai/RlorTrainerJob\x12\x37\x61\x63\x63ounts/{AccountId}/rlorTrainerJobs/{RlorTrainerJobId}*\x0frlorTrainerJobs2\x0erlorTrainerJob\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\".\n\x18GetRlorTrainerJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xba\x01\n\x1b\x43reateRlorTrainerJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x37\n\x10rlor_trainer_job\x18\x02 \x01(\x0b\x32\x17.gateway.RlorTrainerJobB\x04\xe2\x41\x01\x02\x12)\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12!\n\x13rlor_trainer_job_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\"\x93\x01\n\x1aListRlorTrainerJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"~\n\x1bListRlorTrainerJobsResponse\x12\x32\n\x11rlor_trainer_jobs\x18\x01 \x03(\x0b\x32\x17.gateway.RlorTrainerJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"1\n\x1b\x44\x65leteRlorTrainerJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.rlor_trainer_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_RLORTRAINERJOB'].fields_by_name['name']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['completed_time']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['completed_time']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['dataset']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['dataset']._serialized_options = b'\342A\001\002'
  _globals['_RLORTRAINERJOB'].fields_by_name['evaluation_dataset']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['evaluation_dataset']._serialized_options = b'\342A\001\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['eval_auto_carveout']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['eval_auto_carveout']._serialized_options = b'\342A\001\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['state']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['status']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_RLORTRAINERJOB'].fields_by_name['training_config']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['training_config']._serialized_options = b'\342A\001\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['reward_weights']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['reward_weights']._serialized_options = b'\030\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['wandb_config']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['wandb_config']._serialized_options = b'\342A\001\001'
  _globals['_RLORTRAINERJOB'].fields_by_name['reinforcement_fine_tuning_epoch_id']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['reinforcement_fine_tuning_epoch_id']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_RLORTRAINERJOB'].fields_by_name['job_progress']._loaded_options = None
  _globals['_RLORTRAINERJOB'].fields_by_name['job_progress']._serialized_options = b'\342A\002\003\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_RLORTRAINERJOB']._loaded_options = None
  _globals['_RLORTRAINERJOB']._serialized_options = b'\352A{\n\037api.fireworks.ai/RlorTrainerJob\0227accounts/{AccountId}/rlorTrainerJobs/{RlorTrainerJobId}*\017rlorTrainerJobs2\016rlorTrainerJob\202\361\004\013\n\007Account\030\001'
  _globals['_GETRLORTRAINERJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETRLORTRAINERJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['rlor_trainer_job']._loaded_options = None
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['rlor_trainer_job']._serialized_options = b'\342A\001\002'
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['debug']._loaded_options = None
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['debug']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['rlor_trainer_job_id']._loaded_options = None
  _globals['_CREATERLORTRAINERJOBREQUEST'].fields_by_name['rlor_trainer_job_id']._serialized_options = b'\342A\001\001'
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTRLORTRAINERJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETERLORTRAINERJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETERLORTRAINERJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_RLORTRAINERJOB']._serialized_start=284
  _globals['_RLORTRAINERJOB']._serialized_end=1090
  _globals['_GETRLORTRAINERJOBREQUEST']._serialized_start=1092
  _globals['_GETRLORTRAINERJOBREQUEST']._serialized_end=1138
  _globals['_CREATERLORTRAINERJOBREQUEST']._serialized_start=1141
  _globals['_CREATERLORTRAINERJOBREQUEST']._serialized_end=1327
  _globals['_LISTRLORTRAINERJOBSREQUEST']._serialized_start=1330
  _globals['_LISTRLORTRAINERJOBSREQUEST']._serialized_end=1477
  _globals['_LISTRLORTRAINERJOBSRESPONSE']._serialized_start=1479
  _globals['_LISTRLORTRAINERJOBSRESPONSE']._serialized_end=1605
  _globals['_DELETERLORTRAINERJOBREQUEST']._serialized_start=1607
  _globals['_DELETERLORTRAINERJOBREQUEST']._serialized_end=1656
# @@protoc_insertion_point(module_scope)
