# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/node_pool_binding.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/node_pool_binding.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgateway/node_pool_binding.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x01\n\x0fNodePoolBinding\x12\x19\n\naccount_id\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncluster_id\x18\x02 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1b\n\x0cnode_pool_id\x18\x03 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x36\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x17\n\tprincipal\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02\"o\n\x1c\x43reateNodePoolBindingRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x39\n\x11node_pool_binding\x18\x02 \x01(\x0b\x32\x18.gateway.NodePoolBindingB\x04\xe2\x41\x01\x02\"\x94\x01\n\x1bListNodePoolBindingsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\x81\x01\n\x1cListNodePoolBindingsResponse\x12\x34\n\x12node_pool_bindings\x18\x01 \x03(\x0b\x32\x18.gateway.NodePoolBinding\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"Y\n\x1c\x44\x65leteNodePoolBindingRequest\x12\x39\n\x11node_pool_binding\x18\x02 \x01(\x0b\x32\x18.gateway.NodePoolBindingB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.node_pool_binding_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_NODEPOOLBINDING'].fields_by_name['account_id']._loaded_options = None
  _globals['_NODEPOOLBINDING'].fields_by_name['account_id']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOLBINDING'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_NODEPOOLBINDING'].fields_by_name['cluster_id']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOLBINDING'].fields_by_name['node_pool_id']._loaded_options = None
  _globals['_NODEPOOLBINDING'].fields_by_name['node_pool_id']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOLBINDING'].fields_by_name['create_time']._loaded_options = None
  _globals['_NODEPOOLBINDING'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOLBINDING'].fields_by_name['principal']._loaded_options = None
  _globals['_NODEPOOLBINDING'].fields_by_name['principal']._serialized_options = b'\342A\001\002'
  _globals['_CREATENODEPOOLBINDINGREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATENODEPOOLBINDINGREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATENODEPOOLBINDINGREQUEST'].fields_by_name['node_pool_binding']._loaded_options = None
  _globals['_CREATENODEPOOLBINDINGREQUEST'].fields_by_name['node_pool_binding']._serialized_options = b'\342A\001\002'
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTNODEPOOLBINDINGSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETENODEPOOLBINDINGREQUEST'].fields_by_name['node_pool_binding']._loaded_options = None
  _globals['_DELETENODEPOOLBINDINGREQUEST'].fields_by_name['node_pool_binding']._serialized_options = b'\342A\001\002'
  _globals['_NODEPOOLBINDING']._serialized_start=111
  _globals['_NODEPOOLBINDING']._serialized_end=292
  _globals['_CREATENODEPOOLBINDINGREQUEST']._serialized_start=294
  _globals['_CREATENODEPOOLBINDINGREQUEST']._serialized_end=405
  _globals['_LISTNODEPOOLBINDINGSREQUEST']._serialized_start=408
  _globals['_LISTNODEPOOLBINDINGSREQUEST']._serialized_end=556
  _globals['_LISTNODEPOOLBINDINGSRESPONSE']._serialized_start=559
  _globals['_LISTNODEPOOLBINDINGSRESPONSE']._serialized_end=688
  _globals['_DELETENODEPOOLBINDINGREQUEST']._serialized_start=690
  _globals['_DELETENODEPOOLBINDINGREQUEST']._serialized_end=779
# @@protoc_insertion_point(module_scope)
