# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/feature_flag.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/feature_flag.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agateway/feature_flag.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xed\x01\n\x0b\x46\x65\x61tureFlag\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x13\n\x05value\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05:|\xea\x41l\n\x1c\x61pi.fireworks.ai/FeatureFlag\x12\x31\x61\x63\x63ounts/{AccountId}/featureFlags/{FeatureFlagId}*\x0c\x66\x65\x61tureFlags2\x0b\x66\x65\x61tureFlag\x82\xf1\x04\t\n\x07\x41\x63\x63ount\"\x81\x01\n\x18\x43reateFeatureFlagRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x30\n\x0c\x66\x65\x61ture_flag\x18\x02 \x01(\x0b\x32\x14.gateway.FeatureFlagB\x04\xe2\x41\x01\x02\x12\x1d\n\x0f\x66\x65\x61ture_flag_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"+\n\x15GetFeatureFlagRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x90\x01\n\x17ListFeatureFlagsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"t\n\x18ListFeatureFlagsResponse\x12+\n\rfeature_flags\x18\x01 \x03(\x0b\x32\x14.gateway.FeatureFlag\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x83\x01\n\x18UpdateFeatureFlagRequest\x12\x30\n\x0c\x66\x65\x61ture_flag\x18\x01 \x01(\x0b\x32\x14.gateway.FeatureFlagB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\".\n\x18\x44\x65leteFeatureFlagRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.feature_flag_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_FEATUREFLAG'].fields_by_name['name']._loaded_options = None
  _globals['_FEATUREFLAG'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_FEATUREFLAG'].fields_by_name['value']._loaded_options = None
  _globals['_FEATUREFLAG'].fields_by_name['value']._serialized_options = b'\342A\001\001'
  _globals['_FEATUREFLAG'].fields_by_name['create_time']._loaded_options = None
  _globals['_FEATUREFLAG'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_FEATUREFLAG']._loaded_options = None
  _globals['_FEATUREFLAG']._serialized_options = b'\352Al\n\034api.fireworks.ai/FeatureFlag\0221accounts/{AccountId}/featureFlags/{FeatureFlagId}*\014featureFlags2\013featureFlag\202\361\004\t\n\007Account'
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag']._loaded_options = None
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag']._serialized_options = b'\342A\001\002'
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag_id']._loaded_options = None
  _globals['_CREATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag_id']._serialized_options = b'\342A\001\002'
  _globals['_GETFEATUREFLAGREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETFEATUREFLAGREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTFEATUREFLAGSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag']._loaded_options = None
  _globals['_UPDATEFEATUREFLAGREQUEST'].fields_by_name['feature_flag']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEFEATUREFLAGREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEFEATUREFLAGREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEFEATUREFLAGREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEFEATUREFLAGREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_FEATUREFLAG']._serialized_start=190
  _globals['_FEATUREFLAG']._serialized_end=427
  _globals['_CREATEFEATUREFLAGREQUEST']._serialized_start=430
  _globals['_CREATEFEATUREFLAGREQUEST']._serialized_end=559
  _globals['_GETFEATUREFLAGREQUEST']._serialized_start=561
  _globals['_GETFEATUREFLAGREQUEST']._serialized_end=604
  _globals['_LISTFEATUREFLAGSREQUEST']._serialized_start=607
  _globals['_LISTFEATUREFLAGSREQUEST']._serialized_end=751
  _globals['_LISTFEATUREFLAGSRESPONSE']._serialized_start=753
  _globals['_LISTFEATUREFLAGSRESPONSE']._serialized_end=869
  _globals['_UPDATEFEATUREFLAGREQUEST']._serialized_start=872
  _globals['_UPDATEFEATUREFLAGREQUEST']._serialized_end=1003
  _globals['_DELETEFEATUREFLAGREQUEST']._serialized_start=1005
  _globals['_DELETEFEATUREFLAGREQUEST']._serialized_end=1051
# @@protoc_insertion_point(module_scope)
