# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/node_pool.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/node_pool.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17gateway/node_pool.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfc\x05\n\x08NodePool\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x06 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1b\n\x0emin_node_count\x18\n \x01(\x05\x42\x03\xe0\x41\x01\x12\x1b\n\x0emax_node_count\x18\x0b \x01(\x05\x42\x03\xe0\x41\x01\x12%\n\x18overprovision_node_count\x18\x0c \x01(\x05\x42\x03\xe0\x41\x01\x12-\n\rgke_node_pool\x18\x02 \x01(\x0b\x32\x14.gateway.GkeNodePoolH\x00\x12-\n\reks_node_pool\x18\x07 \x01(\x0b\x32\x14.gateway.EksNodePoolH\x00\x12/\n\x0e\x66\x61ke_node_pool\x18\x03 \x01(\x0b\x32\x15.gateway.FakeNodePoolH\x00\x12\x37\n\x12minikube_node_pool\x18\x04 \x01(\x0b\x32\x19.gateway.MinikubeNodePoolH\x00\x12<\n\x0b\x61nnotations\x18\x0e \x03(\x0b\x32\".gateway.NodePool.AnnotationsEntryB\x03\xe0\x41\x01\x12.\n\x05state\x18\x05 \x01(\x0e\x32\x17.gateway.NodePool.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12-\n\x05stats\x18\r \x01(\x0b\x32\x16.gateway.NodePoolStatsB\x06\xe0\x41\x03\xe0\x41\x05\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\x10\n\x0enode_pool_type\"\xdd\x01\n\x0bGkeNodePool\x12\x1c\n\x0cmachine_type\x18\x01 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12 \n\x10\x61\x63\x63\x65lerator_type\x18\x04 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12!\n\x11\x61\x63\x63\x65lerator_count\x18\x05 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04spot\x18\x06 \x01(\x08\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fservice_account\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04zone\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1e\n\x0enode_pool_name\x18\x08 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"\xf2\x01\n\x0b\x45ksNodePool\x12\x19\n\tnode_role\x18\x01 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1d\n\rinstance_type\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x14\n\x04spot\x18\x04 \x01(\x08\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fnode_group_name\x18\x05 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1a\n\nsubnet_ids\x18\x06 \x03(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04zone\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fplacement_group\x18\x08 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0flaunch_template\x18\t \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"P\n\x0c\x46\x61keNodePool\x12\x14\n\x0cmachine_type\x18\x01 \x01(\t\x12\x11\n\tnum_nodes\x18\x02 \x01(\x05\x12\x17\n\x0fservice_account\x18\x03 \x01(\t\"\x12\n\x10MinikubeNodePool\"\xe5\x02\n\rNodePoolStats\x12\x12\n\nnode_count\x18\x01 \x01(\x05\x12\x16\n\x0eranks_per_node\x18\x02 \x01(\x05\x12\x19\n\x11\x65nvironment_count\x18\x03 \x01(\x05\x12\x19\n\x11\x65nvironment_ranks\x18\x04 \x01(\x05\x12\x42\n\x0f\x62\x61tch_job_count\x18\x05 \x03(\x0b\x32).gateway.NodePoolStats.BatchJobCountEntry\x12\x42\n\x0f\x62\x61tch_job_ranks\x18\x06 \x03(\x0b\x32).gateway.NodePoolStats.BatchJobRanksEntry\x1a\x34\n\x12\x42\x61tchJobCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x34\n\x12\x42\x61tchJobRanksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"r\n\x15\x43reateNodePoolRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12)\n\tnode_pool\x18\x02 \x01(\x0b\x32\x11.gateway.NodePoolB\x03\xe0\x41\x02\x12\x19\n\x0cnode_pool_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\'\n\x12GetNodePoolRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"-\n\x18ReconcileNodePoolRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x88\x01\n\x14ListNodePoolsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"k\n\x15ListNodePoolsResponse\x12%\n\nnode_pools\x18\x01 \x03(\x0b\x32\x11.gateway.NodePool\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"B\n\x15UpdateNodePoolRequest\x12)\n\tnode_pool\x18\x01 \x01(\x0b\x32\x11.gateway.NodePoolB\x03\xe0\x41\x02\"*\n\x15\x44\x65leteNodePoolRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"F\n\x1b\x42\x61tchDeleteNodePoolsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05names\x18\x02 \x03(\tB\x03\xe0\x41\x02\",\n\x17GetNodePoolStatsRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[gateway_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_NODEPOOL_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='gateway.NodePool.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=790,
  serialized_end=871,
)
_sym_db.RegisterEnumDescriptor(_NODEPOOL_STATE)


_NODEPOOL_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='gateway.NodePool.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.NodePool.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.NodePool.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=788,
)

_NODEPOOL = _descriptor.Descriptor(
  name='NodePool',
  full_name='gateway.NodePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.NodePool.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.NodePool.display_name', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.NodePool.create_time', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_node_count', full_name='gateway.NodePool.min_node_count', index=3,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_node_count', full_name='gateway.NodePool.max_node_count', index=4,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overprovision_node_count', full_name='gateway.NodePool.overprovision_node_count', index=5,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gke_node_pool', full_name='gateway.NodePool.gke_node_pool', index=6,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eks_node_pool', full_name='gateway.NodePool.eks_node_pool', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fake_node_pool', full_name='gateway.NodePool.fake_node_pool', index=8,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minikube_node_pool', full_name='gateway.NodePool.minikube_node_pool', index=9,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='gateway.NodePool.annotations', index=10,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='gateway.NodePool.state', index=11,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.NodePool.status', index=12,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats', full_name='gateway.NodePool.stats', index=13,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODEPOOL_ANNOTATIONSENTRY, ],
  enum_types=[
    _NODEPOOL_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='node_pool_type', full_name='gateway.NodePool.node_pool_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=125,
  serialized_end=889,
)


_GKENODEPOOL = _descriptor.Descriptor(
  name='GkeNodePool',
  full_name='gateway.GkeNodePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='machine_type', full_name='gateway.GkeNodePool.machine_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerator_type', full_name='gateway.GkeNodePool.accelerator_type', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerator_count', full_name='gateway.GkeNodePool.accelerator_count', index=2,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot', full_name='gateway.GkeNodePool.spot', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account', full_name='gateway.GkeNodePool.service_account', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='gateway.GkeNodePool.zone', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_pool_name', full_name='gateway.GkeNodePool.node_pool_name', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=892,
  serialized_end=1113,
)


_EKSNODEPOOL = _descriptor.Descriptor(
  name='EksNodePool',
  full_name='gateway.EksNodePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_role', full_name='gateway.EksNodePool.node_role', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_type', full_name='gateway.EksNodePool.instance_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot', full_name='gateway.EksNodePool.spot', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_group_name', full_name='gateway.EksNodePool.node_group_name', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_ids', full_name='gateway.EksNodePool.subnet_ids', index=4,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='gateway.EksNodePool.zone', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_group', full_name='gateway.EksNodePool.placement_group', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='launch_template', full_name='gateway.EksNodePool.launch_template', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1116,
  serialized_end=1358,
)


_FAKENODEPOOL = _descriptor.Descriptor(
  name='FakeNodePool',
  full_name='gateway.FakeNodePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='machine_type', full_name='gateway.FakeNodePool.machine_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_nodes', full_name='gateway.FakeNodePool.num_nodes', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account', full_name='gateway.FakeNodePool.service_account', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1360,
  serialized_end=1440,
)


_MINIKUBENODEPOOL = _descriptor.Descriptor(
  name='MinikubeNodePool',
  full_name='gateway.MinikubeNodePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1442,
  serialized_end=1460,
)


_NODEPOOLSTATS_BATCHJOBCOUNTENTRY = _descriptor.Descriptor(
  name='BatchJobCountEntry',
  full_name='gateway.NodePoolStats.BatchJobCountEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.NodePoolStats.BatchJobCountEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.NodePoolStats.BatchJobCountEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1714,
  serialized_end=1766,
)

_NODEPOOLSTATS_BATCHJOBRANKSENTRY = _descriptor.Descriptor(
  name='BatchJobRanksEntry',
  full_name='gateway.NodePoolStats.BatchJobRanksEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.NodePoolStats.BatchJobRanksEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.NodePoolStats.BatchJobRanksEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1768,
  serialized_end=1820,
)

_NODEPOOLSTATS = _descriptor.Descriptor(
  name='NodePoolStats',
  full_name='gateway.NodePoolStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_count', full_name='gateway.NodePoolStats.node_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ranks_per_node', full_name='gateway.NodePoolStats.ranks_per_node', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment_count', full_name='gateway.NodePoolStats.environment_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment_ranks', full_name='gateway.NodePoolStats.environment_ranks', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_job_count', full_name='gateway.NodePoolStats.batch_job_count', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_job_ranks', full_name='gateway.NodePoolStats.batch_job_ranks', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODEPOOLSTATS_BATCHJOBCOUNTENTRY, _NODEPOOLSTATS_BATCHJOBRANKSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1463,
  serialized_end=1820,
)


_CREATENODEPOOLREQUEST = _descriptor.Descriptor(
  name='CreateNodePoolRequest',
  full_name='gateway.CreateNodePoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateNodePoolRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_pool', full_name='gateway.CreateNodePoolRequest.node_pool', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_pool_id', full_name='gateway.CreateNodePoolRequest.node_pool_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=1936,
)


_GETNODEPOOLREQUEST = _descriptor.Descriptor(
  name='GetNodePoolRequest',
  full_name='gateway.GetNodePoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetNodePoolRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1938,
  serialized_end=1977,
)


_RECONCILENODEPOOLREQUEST = _descriptor.Descriptor(
  name='ReconcileNodePoolRequest',
  full_name='gateway.ReconcileNodePoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.ReconcileNodePoolRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1979,
  serialized_end=2024,
)


_LISTNODEPOOLSREQUEST = _descriptor.Descriptor(
  name='ListNodePoolsRequest',
  full_name='gateway.ListNodePoolsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListNodePoolsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListNodePoolsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListNodePoolsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListNodePoolsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListNodePoolsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2027,
  serialized_end=2163,
)


_LISTNODEPOOLSRESPONSE = _descriptor.Descriptor(
  name='ListNodePoolsResponse',
  full_name='gateway.ListNodePoolsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_pools', full_name='gateway.ListNodePoolsResponse.node_pools', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListNodePoolsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListNodePoolsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2165,
  serialized_end=2272,
)


_UPDATENODEPOOLREQUEST = _descriptor.Descriptor(
  name='UpdateNodePoolRequest',
  full_name='gateway.UpdateNodePoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_pool', full_name='gateway.UpdateNodePoolRequest.node_pool', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2274,
  serialized_end=2340,
)


_DELETENODEPOOLREQUEST = _descriptor.Descriptor(
  name='DeleteNodePoolRequest',
  full_name='gateway.DeleteNodePoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteNodePoolRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2342,
  serialized_end=2384,
)


_BATCHDELETENODEPOOLSREQUEST = _descriptor.Descriptor(
  name='BatchDeleteNodePoolsRequest',
  full_name='gateway.BatchDeleteNodePoolsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.BatchDeleteNodePoolsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='gateway.BatchDeleteNodePoolsRequest.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2386,
  serialized_end=2456,
)


_GETNODEPOOLSTATSREQUEST = _descriptor.Descriptor(
  name='GetNodePoolStatsRequest',
  full_name='gateway.GetNodePoolStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetNodePoolStatsRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2458,
  serialized_end=2502,
)

_NODEPOOL_ANNOTATIONSENTRY.containing_type = _NODEPOOL
_NODEPOOL.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NODEPOOL.fields_by_name['gke_node_pool'].message_type = _GKENODEPOOL
_NODEPOOL.fields_by_name['eks_node_pool'].message_type = _EKSNODEPOOL
_NODEPOOL.fields_by_name['fake_node_pool'].message_type = _FAKENODEPOOL
_NODEPOOL.fields_by_name['minikube_node_pool'].message_type = _MINIKUBENODEPOOL
_NODEPOOL.fields_by_name['annotations'].message_type = _NODEPOOL_ANNOTATIONSENTRY
_NODEPOOL.fields_by_name['state'].enum_type = _NODEPOOL_STATE
_NODEPOOL.fields_by_name['status'].message_type = gateway_dot_status__pb2._STATUS
_NODEPOOL.fields_by_name['stats'].message_type = _NODEPOOLSTATS
_NODEPOOL_STATE.containing_type = _NODEPOOL
_NODEPOOL.oneofs_by_name['node_pool_type'].fields.append(
  _NODEPOOL.fields_by_name['gke_node_pool'])
_NODEPOOL.fields_by_name['gke_node_pool'].containing_oneof = _NODEPOOL.oneofs_by_name['node_pool_type']
_NODEPOOL.oneofs_by_name['node_pool_type'].fields.append(
  _NODEPOOL.fields_by_name['eks_node_pool'])
_NODEPOOL.fields_by_name['eks_node_pool'].containing_oneof = _NODEPOOL.oneofs_by_name['node_pool_type']
_NODEPOOL.oneofs_by_name['node_pool_type'].fields.append(
  _NODEPOOL.fields_by_name['fake_node_pool'])
_NODEPOOL.fields_by_name['fake_node_pool'].containing_oneof = _NODEPOOL.oneofs_by_name['node_pool_type']
_NODEPOOL.oneofs_by_name['node_pool_type'].fields.append(
  _NODEPOOL.fields_by_name['minikube_node_pool'])
_NODEPOOL.fields_by_name['minikube_node_pool'].containing_oneof = _NODEPOOL.oneofs_by_name['node_pool_type']
_NODEPOOLSTATS_BATCHJOBCOUNTENTRY.containing_type = _NODEPOOLSTATS
_NODEPOOLSTATS_BATCHJOBRANKSENTRY.containing_type = _NODEPOOLSTATS
_NODEPOOLSTATS.fields_by_name['batch_job_count'].message_type = _NODEPOOLSTATS_BATCHJOBCOUNTENTRY
_NODEPOOLSTATS.fields_by_name['batch_job_ranks'].message_type = _NODEPOOLSTATS_BATCHJOBRANKSENTRY
_CREATENODEPOOLREQUEST.fields_by_name['node_pool'].message_type = _NODEPOOL
_LISTNODEPOOLSRESPONSE.fields_by_name['node_pools'].message_type = _NODEPOOL
_UPDATENODEPOOLREQUEST.fields_by_name['node_pool'].message_type = _NODEPOOL
DESCRIPTOR.message_types_by_name['NodePool'] = _NODEPOOL
DESCRIPTOR.message_types_by_name['GkeNodePool'] = _GKENODEPOOL
DESCRIPTOR.message_types_by_name['EksNodePool'] = _EKSNODEPOOL
DESCRIPTOR.message_types_by_name['FakeNodePool'] = _FAKENODEPOOL
DESCRIPTOR.message_types_by_name['MinikubeNodePool'] = _MINIKUBENODEPOOL
DESCRIPTOR.message_types_by_name['NodePoolStats'] = _NODEPOOLSTATS
DESCRIPTOR.message_types_by_name['CreateNodePoolRequest'] = _CREATENODEPOOLREQUEST
DESCRIPTOR.message_types_by_name['GetNodePoolRequest'] = _GETNODEPOOLREQUEST
DESCRIPTOR.message_types_by_name['ReconcileNodePoolRequest'] = _RECONCILENODEPOOLREQUEST
DESCRIPTOR.message_types_by_name['ListNodePoolsRequest'] = _LISTNODEPOOLSREQUEST
DESCRIPTOR.message_types_by_name['ListNodePoolsResponse'] = _LISTNODEPOOLSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateNodePoolRequest'] = _UPDATENODEPOOLREQUEST
DESCRIPTOR.message_types_by_name['DeleteNodePoolRequest'] = _DELETENODEPOOLREQUEST
DESCRIPTOR.message_types_by_name['BatchDeleteNodePoolsRequest'] = _BATCHDELETENODEPOOLSREQUEST
DESCRIPTOR.message_types_by_name['GetNodePoolStatsRequest'] = _GETNODEPOOLSTATSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NodePool = _reflection.GeneratedProtocolMessageType('NodePool', (_message.Message,), {

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODEPOOL_ANNOTATIONSENTRY,
    '__module__' : 'gateway.node_pool_pb2'
    # @@protoc_insertion_point(class_scope:gateway.NodePool.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _NODEPOOL,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.NodePool)
  })
_sym_db.RegisterMessage(NodePool)
_sym_db.RegisterMessage(NodePool.AnnotationsEntry)

GkeNodePool = _reflection.GeneratedProtocolMessageType('GkeNodePool', (_message.Message,), {
  'DESCRIPTOR' : _GKENODEPOOL,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GkeNodePool)
  })
_sym_db.RegisterMessage(GkeNodePool)

EksNodePool = _reflection.GeneratedProtocolMessageType('EksNodePool', (_message.Message,), {
  'DESCRIPTOR' : _EKSNODEPOOL,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.EksNodePool)
  })
_sym_db.RegisterMessage(EksNodePool)

FakeNodePool = _reflection.GeneratedProtocolMessageType('FakeNodePool', (_message.Message,), {
  'DESCRIPTOR' : _FAKENODEPOOL,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.FakeNodePool)
  })
_sym_db.RegisterMessage(FakeNodePool)

MinikubeNodePool = _reflection.GeneratedProtocolMessageType('MinikubeNodePool', (_message.Message,), {
  'DESCRIPTOR' : _MINIKUBENODEPOOL,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.MinikubeNodePool)
  })
_sym_db.RegisterMessage(MinikubeNodePool)

NodePoolStats = _reflection.GeneratedProtocolMessageType('NodePoolStats', (_message.Message,), {

  'BatchJobCountEntry' : _reflection.GeneratedProtocolMessageType('BatchJobCountEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODEPOOLSTATS_BATCHJOBCOUNTENTRY,
    '__module__' : 'gateway.node_pool_pb2'
    # @@protoc_insertion_point(class_scope:gateway.NodePoolStats.BatchJobCountEntry)
    })
  ,

  'BatchJobRanksEntry' : _reflection.GeneratedProtocolMessageType('BatchJobRanksEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODEPOOLSTATS_BATCHJOBRANKSENTRY,
    '__module__' : 'gateway.node_pool_pb2'
    # @@protoc_insertion_point(class_scope:gateway.NodePoolStats.BatchJobRanksEntry)
    })
  ,
  'DESCRIPTOR' : _NODEPOOLSTATS,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.NodePoolStats)
  })
_sym_db.RegisterMessage(NodePoolStats)
_sym_db.RegisterMessage(NodePoolStats.BatchJobCountEntry)
_sym_db.RegisterMessage(NodePoolStats.BatchJobRanksEntry)

CreateNodePoolRequest = _reflection.GeneratedProtocolMessageType('CreateNodePoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENODEPOOLREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateNodePoolRequest)
  })
_sym_db.RegisterMessage(CreateNodePoolRequest)

GetNodePoolRequest = _reflection.GeneratedProtocolMessageType('GetNodePoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEPOOLREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetNodePoolRequest)
  })
_sym_db.RegisterMessage(GetNodePoolRequest)

ReconcileNodePoolRequest = _reflection.GeneratedProtocolMessageType('ReconcileNodePoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _RECONCILENODEPOOLREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ReconcileNodePoolRequest)
  })
_sym_db.RegisterMessage(ReconcileNodePoolRequest)

ListNodePoolsRequest = _reflection.GeneratedProtocolMessageType('ListNodePoolsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNODEPOOLSREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListNodePoolsRequest)
  })
_sym_db.RegisterMessage(ListNodePoolsRequest)

ListNodePoolsResponse = _reflection.GeneratedProtocolMessageType('ListNodePoolsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNODEPOOLSRESPONSE,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListNodePoolsResponse)
  })
_sym_db.RegisterMessage(ListNodePoolsResponse)

UpdateNodePoolRequest = _reflection.GeneratedProtocolMessageType('UpdateNodePoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENODEPOOLREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UpdateNodePoolRequest)
  })
_sym_db.RegisterMessage(UpdateNodePoolRequest)

DeleteNodePoolRequest = _reflection.GeneratedProtocolMessageType('DeleteNodePoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENODEPOOLREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteNodePoolRequest)
  })
_sym_db.RegisterMessage(DeleteNodePoolRequest)

BatchDeleteNodePoolsRequest = _reflection.GeneratedProtocolMessageType('BatchDeleteNodePoolsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHDELETENODEPOOLSREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.BatchDeleteNodePoolsRequest)
  })
_sym_db.RegisterMessage(BatchDeleteNodePoolsRequest)

GetNodePoolStatsRequest = _reflection.GeneratedProtocolMessageType('GetNodePoolStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEPOOLSTATSREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetNodePoolStatsRequest)
  })
_sym_db.RegisterMessage(GetNodePoolStatsRequest)


DESCRIPTOR._options = None
_NODEPOOL_ANNOTATIONSENTRY._options = None
_NODEPOOL.fields_by_name['name']._options = None
_NODEPOOL.fields_by_name['display_name']._options = None
_NODEPOOL.fields_by_name['create_time']._options = None
_NODEPOOL.fields_by_name['min_node_count']._options = None
_NODEPOOL.fields_by_name['max_node_count']._options = None
_NODEPOOL.fields_by_name['overprovision_node_count']._options = None
_NODEPOOL.fields_by_name['annotations']._options = None
_NODEPOOL.fields_by_name['state']._options = None
_NODEPOOL.fields_by_name['status']._options = None
_NODEPOOL.fields_by_name['stats']._options = None
_GKENODEPOOL.fields_by_name['machine_type']._options = None
_GKENODEPOOL.fields_by_name['accelerator_type']._options = None
_GKENODEPOOL.fields_by_name['accelerator_count']._options = None
_GKENODEPOOL.fields_by_name['spot']._options = None
_GKENODEPOOL.fields_by_name['service_account']._options = None
_GKENODEPOOL.fields_by_name['zone']._options = None
_GKENODEPOOL.fields_by_name['node_pool_name']._options = None
_EKSNODEPOOL.fields_by_name['node_role']._options = None
_EKSNODEPOOL.fields_by_name['instance_type']._options = None
_EKSNODEPOOL.fields_by_name['spot']._options = None
_EKSNODEPOOL.fields_by_name['node_group_name']._options = None
_EKSNODEPOOL.fields_by_name['subnet_ids']._options = None
_EKSNODEPOOL.fields_by_name['zone']._options = None
_EKSNODEPOOL.fields_by_name['placement_group']._options = None
_EKSNODEPOOL.fields_by_name['launch_template']._options = None
_NODEPOOLSTATS_BATCHJOBCOUNTENTRY._options = None
_NODEPOOLSTATS_BATCHJOBRANKSENTRY._options = None
_CREATENODEPOOLREQUEST.fields_by_name['parent']._options = None
_CREATENODEPOOLREQUEST.fields_by_name['node_pool']._options = None
_CREATENODEPOOLREQUEST.fields_by_name['node_pool_id']._options = None
_GETNODEPOOLREQUEST.fields_by_name['name']._options = None
_RECONCILENODEPOOLREQUEST.fields_by_name['name']._options = None
_LISTNODEPOOLSREQUEST.fields_by_name['parent']._options = None
_LISTNODEPOOLSREQUEST.fields_by_name['page_size']._options = None
_LISTNODEPOOLSREQUEST.fields_by_name['page_token']._options = None
_LISTNODEPOOLSREQUEST.fields_by_name['filter']._options = None
_LISTNODEPOOLSREQUEST.fields_by_name['order_by']._options = None
_UPDATENODEPOOLREQUEST.fields_by_name['node_pool']._options = None
_DELETENODEPOOLREQUEST.fields_by_name['name']._options = None
_BATCHDELETENODEPOOLSREQUEST.fields_by_name['parent']._options = None
_BATCHDELETENODEPOOLSREQUEST.fields_by_name['names']._options = None
_GETNODEPOOLSTATSREQUEST.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)
